/**
 * <copyright>
 * 
 * Copyright (c) 2013 itemis and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.common.util;

public class ISAFEConstants {
	/**
	 * Depth constant (value 2) indicating this resource and its direct and indirect members at any depth.
	 */
	public static final int DEPTH_INFINITE = 2;
	/**
	 * Depth constant (value 1) indicating this resource and its direct members.
	 */
	public static final int DEPTH_ONE = 1;
	/**
	 * Depth constant (value 0) indicating this resource, but not any of its members.
	 */
	public static final int DEPTH_ZERO = 0;

	/**
	 * Arbitrary scheme for SAFE URIs enabling to reference SAFE elements without having to precise the files in which
	 * they are located.
	 */
	public static final String SAFE_SCHEME = "safe"; //$NON-NLS-1$

	/**
	 * Separator separating the schema within an SAFE URI.
	 */
	public static final String SCHEME_SEPARATOR = ":"; //$NON-NLS-1$

	/**
	 * Separator separating segments within an SAFE URI.
	 */
	public static final String SEGMENT_SEPARATOR = "/"; //$NON-NLS-1$

	/**
	 * Separator separating a query within an SAFE URI.
	 */
	public static final String QUERY_SEPARATOR = "?"; //$NON-NLS-1$

	/**
	 * Separator separating a fragments within an SAFE URI.
	 */
	public static final String FRAGMENT_SEPARATOR = "#"; //$NON-NLS-1$

	/**
	 * Separator separating a keys from values within an SAFE URI.
	 */
	public static final String KEY_VALUE_SEPARATOR = "="; //$NON-NLS-1$

	/**
	 * The name of the query string key used for encoding the destination type of referenced SAFE elements in SAFE URIs.
	 */
	public static final String DESTINATION_TYPE_KEY = "type"; //$NON-NLS-1$

	/**
	 * The prefix in absolute qualified name segments of EObjects which are no Identifiables and don't have a shortName.
	 */
	public static final String NON_IDENTIFIABLE_SEGMENT_PREFIX = "@"; //$NON-NLS-1$

	/**
	 * Absolute qualified name segment of EAXML objects which are at the root of SAFE resources.
	 */
	public static final String SAFE_ABSOLUTE_QUALIFIED_NAME_SEGMENT = "/"; //$NON-NLS-1$
	/**
	 * Type name of SAFE objects which are at the root of SAFE resources.
	 */
	public static final String SAFE_TYPE_NAME = "SAFE"; //$NON-NLS-1$

	/**
	 * Class name of Referrable EClass.
	 */
	public static final String REFERRABLE_CLASS_NAME = "Referrable"; //$NON-NLS-1$

	/**
	 * Class name of SAFEPackage EClass
	 */
	public static final String SAFEPACKAGE_CLASS_NAME = "SAFEPackage"; //$NON-NLS-1$

	/**
	 * Name of "shortName" feature
	 */
	public static final String SHORTNAME_FEATURE_NAME = "shortName"; //$NON-NLS-1$

	/**
	 * Name of "topLevelPackage" feature of SAFE objects
	 */
	public static final String TOPLEVELPACKAGE_FEATURE_NAME = "topLevelPackage"; //$NON-NLS-1$

	/**
	 * Name of "element" feature of PackageableElement objects
	 */
	public static final String ELEMENT_FEATURE_NAME = "element"; //$NON-NLS-1$

	/**
	 * Name of "subPackage" feature of SAFEPackage objects
	 */
	public static final String SUBPACKAGE_FEATURE_NAME = "subPackage"; //$NON-NLS-1$

	/**
	 * Namespace of AUTOSAR root package
	 */
	public static final String AUTOSAR_ROOT_PACKAGE_NSURI = "http://autosar.org/schema/r4.0/autosar40"; //$NON-NLS-1$

	/**
	 * Namespace of AUTOSAR
	 */
	public static final String AUTOSAR_NSURI = "http://autosar.org/schema/r4.0"; //$NON-NLS-1$

	/**
	 * Namespace of SAFE package
	 */
	public static final String SAFE_PACKAGE_NSURI = "http://safe-project.eu"; //$NON-NLS-1$

	/**
	 * Prefix for package XMLTypePackage
	 */
	public static final String PACKAGE_PREFIX_XSD = "xsd"; //$NON-NLS-1$

}
