/**
 * <copyright>
 * 
 * Copyright (c) 2013 itemis and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.examples.common.ui.perspectives;

import org.safe.examples.common.ui.perspectives.ISAFEPerspectiveConstants;
import org.eclipse.ui.IFolderLayout;
import org.eclipse.ui.IPageLayout;
import org.eclipse.ui.IPerspectiveFactory;

public class SAFEPerspectiveFactory implements IPerspectiveFactory {

	private IPageLayout layout;

	public void createInitialLayout(IPageLayout layout) {
		this.layout = layout;

		createLayout(layout);
		addNewWizardShortcuts();
		addShowViewShortcuts();
		addPerspectiveShortcuts();
		addActionSets();
	}

	private void createLayout(IPageLayout layout) {

		// Editors are placed for free.
		String editorArea = layout.getEditorArea();

		int relativePos = IPageLayout.LEFT;

		IFolderLayout topLeft = layout.createFolder(ISAFEPerspectiveConstants.TOP_LEFT, relativePos, 0.2f, editorArea);
		topLeft.addView(ISAFEPerspectiveConstants.ID_SAFE_EXPLORER);
		topLeft.addView(IPageLayout.ID_PROJECT_EXPLORER);

		relativePos = IPageLayout.BOTTOM;

		IFolderLayout bottomRight = layout.createFolder(ISAFEPerspectiveConstants.BOTTOM_RIGHT, relativePos, 0.65f, editorArea);
		bottomRight.addView(IPageLayout.ID_PROP_SHEET);
		bottomRight.addView(ISAFEPerspectiveConstants.ID_ERROR_LOG_VIEW);
		bottomRight.addPlaceholder(ISAFEPerspectiveConstants.ID_PROBLEMS_VIEW);
		bottomRight.addPlaceholder(ISAFEPerspectiveConstants.ID_CONSOLE_VIEW);
	}

	// New actions - SAFE project creation wizard
	private void addNewWizardShortcuts() {
		layout.addNewWizardShortcut(ISAFEPerspectiveConstants.ID_SAFE_NEW_PROJECT);
		layout.addNewWizardShortcut(ISAFEPerspectiveConstants.ID_SAFE_NEW_FILE);
		layout.addNewWizardShortcut(ISAFEPerspectiveConstants.ID_ECLIPSE_NEW_FOLDER);
		layout.addNewWizardShortcut(ISAFEPerspectiveConstants.ID_ECLIPSE_NEW_FILE);
	}

	// Add "show views".
	private void addShowViewShortcuts() {
		layout.addShowViewShortcut(ISAFEPerspectiveConstants.ID_SAFE_EXPLORER);
		layout.addShowViewShortcut(IPageLayout.ID_PROJECT_EXPLORER);
		layout.addShowViewShortcut(IPageLayout.ID_OUTLINE);
		layout.addShowViewShortcut(IPageLayout.ID_PROP_SHEET);
		layout.addShowViewShortcut(ISAFEPerspectiveConstants.ID_ERROR_LOG_VIEW);
		layout.addShowViewShortcut(ISAFEPerspectiveConstants.ID_PROBLEMS_VIEW);
		layout.addShowViewShortcut(ISAFEPerspectiveConstants.ID_CONSOLE_VIEW);
	}

	private void addPerspectiveShortcuts() {
		layout.addPerspectiveShortcut(ISAFEPerspectiveConstants.ID_RESOURCE_PERSPECTIVE);
	}

	private void addActionSets() {
		layout.addActionSet(ISAFEPerspectiveConstants.ID_LAUNCH_ACTIONSET);
		layout.addActionSet(ISAFEPerspectiveConstants.ID_TEAM_ACTIONSET);
	}
}
