/**
 * <copyright>
 * 
 * Copyright (c) 2013 itemis and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.examples.editor.sections;

import org.safe.examples.editor.internal.messages.Messages;
import org.eclipse.core.runtime.Assert;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.util.EcoreUtil;
import org.eclipse.sphinx.emf.editors.forms.pages.AbstractFormPage;
import org.eclipse.sphinx.emf.editors.forms.sections.AbstractFieldFormSection;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.forms.IManagedForm;
import org.eclipse.ui.forms.SectionPart;
import org.eclipse.ui.forms.widgets.ExpandableComposite;
import org.eclipse.ui.forms.widgets.FormText;
import org.eclipse.ui.forms.widgets.FormToolkit;
import org.eclipse.ui.forms.widgets.TableWrapData;

public class SAFEDocumentationSection extends AbstractFieldFormSection {

	protected FormText safeDocumentationWidget;

	public SAFEDocumentationSection(AbstractFormPage formPage, Object sectionInput) {
		this(formPage, sectionInput, SWT.NONE);
	}

	public SAFEDocumentationSection(AbstractFormPage formPage, Object sectionInput, int style) {
		super(formPage, sectionInput, style);

		title = Messages.SAFEDocumentationSection_title;
		description = Messages.SAFEDocumentationSection_description;
	}

	@Override
	protected int getDefaultSectionStyle() {
		return super.getDefaultSectionStyle() | ExpandableComposite.TWISTIE;
	}

	@Override
	protected void createSectionClientContent(IManagedForm managedForm, SectionPart sectionPart, Composite sectionClient) {
		Assert.isNotNull(managedForm);
		Assert.isNotNull(sectionPart);
		Assert.isNotNull(sectionClient);

		FormToolkit toolkit = managedForm.getToolkit();
		createSAFEDocumentationField(sectionInput, toolkit, sectionClient);
	}

	private void createSAFEDocumentationField(final Object sectionInput, FormToolkit toolkit, Composite sectionClient) {
		safeDocumentationWidget = toolkit.createFormText(sectionClient, true);

		TableWrapData data = new TableWrapData(TableWrapData.FILL);
		data.colspan = 1;
		data.grabHorizontal = true;
		safeDocumentationWidget.setLayoutData(data);
		safeDocumentationWidget.setText(getTypeDocumentation(sectionInput), false, true);
	}

	private void refreshSAFEDocumentationField() {
		if (isControlAccessible(safeDocumentationWidget)) {
			safeDocumentationWidget.setText(getTypeDocumentation(sectionInput), false, true);
		}
	}

	private String getTypeDocumentation(Object object) {
		return object instanceof EObject ? EcoreUtil.getDocumentation(((EObject) object).eClass()) : ""; //$NON-NLS-1$
	}

	@Override
	public void refreshSection() {
		// Refresh section client fields
		refreshSAFEDocumentationField();
	}
}
