/**
 * <copyright>
 * 
 * Copyright (c) 2013 itemis and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.ide.ui.wizards;

import java.net.URI;

import org.artop.aal.common.metamodel.AutosarReleaseDescriptor;
import org.artop.aal.common.preferences.IAutosarPreferenceConstants;
import org.artop.aal.workspace.preferences.IAutosarWorkspacePreferences;
import org.eatop.eel.common.metamodel.EastADLReleaseDescriptor;
import org.eatop.eel.workspace.preferences.IEastADLWorkspacePreferenceConstants;
import org.eatop.eel.workspace.preferences.IEastADLWorkspacePreferences;
import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.sphinx.emf.workspace.jobs.CreateNewModelProjectJob;
import org.eclipse.sphinx.emf.workspace.ui.wizards.AbstractNewModelProjectWizard;
import org.eclipse.ui.dialogs.WizardNewProjectCreationPage;
import org.safe.common.metamodel.SAFEReleaseDescriptor;
import org.safe.ide.jobs.CreateNewSAFEProjectJob;
import org.safe.ide.preferences.ISAFEWorkspacePreferenceConstants;
import org.safe.ide.preferences.ISAFEWorkspacePreferences;
import org.safe.ide.ui.internal.Activator;
import org.safe.ide.ui.messages.WorkspaceUIMessages;
import org.safe.ide.ui.wizards.pages.NewModelProjectNaturePage;
import org.safe.ide.ui.wizards.pages.NewSAFEProjectCreationPage;

public class NewSAFEProjectWizard extends AbstractNewModelProjectWizard<SAFEReleaseDescriptor> {
	protected NewModelProjectNaturePage<AutosarReleaseDescriptor> autosarNaturePage;
	protected NewModelProjectNaturePage<EastADLReleaseDescriptor> eastADLNaturePage;

	/**
	 * The project-relative path of the wizard banner file.
	 */
	private static final String WIZBAN_ICON_FILE = "full/wizban/newsafeprj_wiz.png"; //$NON-NLS-1$

	public NewSAFEProjectWizard() {
		super(false, SAFEReleaseDescriptor.INSTANCE, ISAFEWorkspacePreferences.SAFE_RELEASE,
				ISAFEWorkspacePreferenceConstants.SAFE_PREFERENCE_PAGE_ID);
	}

	/*
	 * @see org.eclipse.ui.wizards.newresource.BasicNewProjectResourceWizard#initializeDefaultPageImageDescriptor()
	 */
	@Override
	protected void initializeDefaultPageImageDescriptor() {
		ImageDescriptor descriptor = Activator.getPlugin().getImageDescriptor(WIZBAN_ICON_FILE);
		setDefaultPageImageDescriptor(descriptor);
	}

	/*
	 * (non-Javadoc) Method declared on IWizard.
	 */
	@Override
	public void addPages() {
		mainPage = createMainPage();
		addPage(mainPage);

		autosarNaturePage = createAutosarNaturePage();
		addPage(autosarNaturePage);

		eastADLNaturePage = createEastADLNaturePage();
		addPage(eastADLNaturePage);

		// Only add page if there are already projects in the workspace
		if (ResourcesPlugin.getWorkspace().getRoot().getProjects().length > 0) {
			referencePage = createReferencePage();
			addPage(referencePage);
		}
	}

	@Override
	protected WizardNewProjectCreationPage createMainPage() {
		NewSAFEProjectCreationPage mainPage = new NewSAFEProjectCreationPage("NewSAFEProjectCreationPage"); //$NON-NLS-1$
		return mainPage;
	}

	protected NewModelProjectNaturePage<AutosarReleaseDescriptor> createAutosarNaturePage() {
		NewModelProjectNaturePage<AutosarReleaseDescriptor> autosarNaturePage = new NewModelProjectNaturePage<AutosarReleaseDescriptor>(
				"autosarNewProjectNaturePage", IAutosarWorkspacePreferences.AUTOSAR_RELEASE, AutosarReleaseDescriptor.INSTANCE, IAutosarPreferenceConstants.AUTOSAR_RELEASE_PREFERENCE_PAGE_ID); //$NON-NLS-1$
		autosarNaturePage.setTitle(WorkspaceUIMessages.page_createAutosarNature_title);
		autosarNaturePage.setDescription(WorkspaceUIMessages.page_createAutosarNature_description);

		return autosarNaturePage;
	}

	protected NewModelProjectNaturePage<EastADLReleaseDescriptor> createEastADLNaturePage() {
		NewModelProjectNaturePage<EastADLReleaseDescriptor> eastADLNaturePage = new NewModelProjectNaturePage<EastADLReleaseDescriptor>(
				"eastADLNewProjectNaturePage", IEastADLWorkspacePreferences.EAST_ADL_RELEASE, EastADLReleaseDescriptor.INSTANCE, IEastADLWorkspacePreferenceConstants.EAST_ADL_PREFERENCE_PAGE_ID); //$NON-NLS-1$
		eastADLNaturePage.setTitle(WorkspaceUIMessages.page_createEastADLNature_title);
		eastADLNaturePage.setDescription(WorkspaceUIMessages.page_createEastADLNature_description);

		return eastADLNaturePage;
	}

	/*
	 * @see
	 * org.eclipse.sphinx.emf.workspace.ui.wizards.BasicNewModelProjectWizard#createCreateNewProjectJob(java.lang.String
	 * , org.eclipse.core.resources.IProject, java.net.URI)
	 */
	@Override
	protected CreateNewModelProjectJob<SAFEReleaseDescriptor> createCreateNewModelProjectJob(String jobName, IProject project, URI location) {
		CreateNewSAFEProjectJob job = new CreateNewSAFEProjectJob(jobName, project, location,
				((NewSAFEProjectCreationPage) mainPage).getMetaModelVersionDescriptor(), autosarNaturePage.getRelease(),
				eastADLNaturePage.getRelease());
		return job;
	}
}
