/**
 * <copyright>
 * 
 * Copyright (c) 2013 itemis and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.ide.jobs;

import java.net.URI;

import org.artop.aal.workspace.natures.AutosarNature;
import org.artop.aal.workspace.preferences.IAutosarWorkspacePreferences;
import org.eclipse.core.resources.IProject;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.OperationCanceledException;
import org.eclipse.core.runtime.Status;
import org.eclipse.core.runtime.SubMonitor;
import org.eclipse.sphinx.emf.metamodel.AbstractMetaModelDescriptor;
import org.eclipse.sphinx.emf.metamodel.IMetaModelDescriptor;
import org.eclipse.sphinx.emf.workspace.jobs.CreateNewModelProjectJob;
import org.eclipse.sphinx.platform.preferences.IProjectWorkspacePreference;
import org.eclipse.sphinx.platform.util.ExtendedPlatform;
import org.safe.common.metamodel.SAFEReleaseDescriptor;
import org.safe.ide.internal.messages.Messages;
import org.safe.ide.natures.SAFENature;
import org.safe.ide.preferences.ISAFEWorkspacePreferences;
//import org.artop.aal.workspace.natures.AutosarNature;
//import org.artop.aal.workspace.preferences.IAutosarWorkspacePreferences;
import org.eatop.eel.workspace.natures.EastADLNature;
import org.eatop.eel.workspace.preferences.IEastADLWorkspacePreferences;

public class CreateNewSAFEProjectJob extends CreateNewModelProjectJob<SAFEReleaseDescriptor>{

	protected String safeNatureId;
	protected IProjectWorkspacePreference<? extends AbstractMetaModelDescriptor> safeWorkspacePreference;

	protected String autosarNatureId;
	protected IProjectWorkspacePreference<? extends AbstractMetaModelDescriptor> autosarWorkspacePreference;

	protected String eastadlNatureId;
	protected IProjectWorkspacePreference<? extends AbstractMetaModelDescriptor> eastadlWorkspacePreference;
	
	private IMetaModelDescriptor safeRelease;
	private IMetaModelDescriptor autosarRelease;
	private IMetaModelDescriptor eastadlRelease;
	
	/**
	 * Create the job
	 */
	public CreateNewSAFEProjectJob(String name, IProject project, URI location, SAFEReleaseDescriptor safeRelease, IMetaModelDescriptor autosarRelease, IMetaModelDescriptor eastadlRelease) {
		super(name, project, location, safeRelease, ISAFEWorkspacePreferences.SAFE_RELEASE);
		this.safeNatureId=SAFENature.ID;
		this.safeWorkspacePreference =  ISAFEWorkspacePreferences.SAFE_RELEASE;
		this.autosarNatureId = AutosarNature.ID;
		this.autosarWorkspacePreference = IAutosarWorkspacePreferences.AUTOSAR_RELEASE;
		this.eastadlNatureId = EastADLNature.ID;
		this.eastadlWorkspacePreference =  IEastADLWorkspacePreferences.EAST_ADL_RELEASE;		
		this.safeRelease = safeRelease;
		this.autosarRelease = autosarRelease;
		this.eastadlRelease = eastadlRelease;
	}
	
	/*
	 * @see org.eclipse.core.resources.WorkspaceJob#runInWorkspace(org.eclipse.core.runtime.IProgressMonitor)
	 */
	@Override
	public IStatus runInWorkspace(IProgressMonitor monitor) throws CoreException {
		SubMonitor progress = SubMonitor.convert(monitor, getName(), 100);
		if (progress.isCanceled()) {
			throw new OperationCanceledException();
		}

		createNewProject(progress.newChild(70));
		addNatures(progress.newChild(15));
		
		setPreference();	
		progress.worked(15);

		return Status.OK_STATUS;
	}
	
	/**
	 * Set the nature to the project created by the job.
	 * 
	 * @param monitor
	 */
	protected void addNatures(IProgressMonitor monitor) throws CoreException {
		SubMonitor progress = SubMonitor.convert(monitor, 100);
		if (progress.isCanceled()) {
			throw new OperationCanceledException();
		}

		if (safeNatureId != null) {
			progress.subTask(Messages.job_AddProjectNatures_SAFE); 
			ExtendedPlatform.addNature(newProject, safeNatureId, progress.newChild(100));
		}
		
		if (autosarNatureId != null) {
			progress.subTask(Messages.job_AddProjectNatures_AUTOSAR); 
			ExtendedPlatform.addNature(newProject, autosarNatureId, progress.newChild(100));
		}
		
		if (eastadlNatureId != null) {
			progress.subTask(Messages.job_AddProjectNatures_EASTADL); 
			ExtendedPlatform.addNature(newProject, eastadlNatureId, progress.newChild(100));
		}
	}
	
	/**
	 * set preferences
	 */
	@SuppressWarnings("unchecked")
	public void setPreference(){
		if (safeWorkspacePreference != null && safeRelease instanceof AbstractMetaModelDescriptor) {
			((IProjectWorkspacePreference<AbstractMetaModelDescriptor>) safeWorkspacePreference).setInProject(newProject, (AbstractMetaModelDescriptor) safeRelease);
		}
		
		if (autosarWorkspacePreference != null && autosarRelease instanceof AbstractMetaModelDescriptor) {
			((IProjectWorkspacePreference<AbstractMetaModelDescriptor>) autosarWorkspacePreference).setInProject(newProject, (AbstractMetaModelDescriptor) autosarRelease);
		}
		
		if (safeWorkspacePreference != null && safeRelease instanceof AbstractMetaModelDescriptor) {
			((IProjectWorkspacePreference<AbstractMetaModelDescriptor>) eastadlWorkspacePreference).setInProject(newProject, (AbstractMetaModelDescriptor) eastadlRelease);
		}
	}
	
}
