/**
 * <copyright>
 * 
 * Copyright (c) 2013 itemis and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.ide.scoping;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IResource;
import org.eclipse.emf.common.util.URI;
import org.eclipse.emf.ecore.resource.Resource;
import org.eclipse.sphinx.emf.metamodel.IMetaModelDescriptor;
import org.eclipse.sphinx.emf.metamodel.MetaModelDescriptorRegistry;
import org.eclipse.sphinx.emf.scoping.ProjectResourceScope;
import org.eclipse.sphinx.emf.util.EcorePlatformUtil;
import org.safe.common.metamodel.SAFEReleaseDescriptor;
import org.safe.ide.scoping.SAFEProjectResourceScopeProvider.IProjectSAFEReleaseProvider;
import org.safe.ide.scoping.SAFEProjectResourceScopeProvider.ProjectSAFEReleaseProvider;
import org.safe.ide.scoping.SAFEProjectResourceScopeProvider.ProjectSAFEReleaseCache;
import org.safe.ide.util.SAFEPlatformUtil;

public class SAFEProjectResourceScope extends ProjectResourceScope {

	protected IProjectSAFEReleaseProvider projectSafeReleaseProvider = new ProjectSAFEReleaseProvider();

	public SAFEProjectResourceScope(IResource resource) {
		super(resource);
	}

	void setProjectAutosarReleaseProvider(IProjectSAFEReleaseProvider projectSafeReleaseProvider) {
		this.projectSafeReleaseProvider = projectSafeReleaseProvider;
	}

	public boolean isSafeReleaseCorrespondingToEnclosingProject(IFile file, IMetaModelDescriptor fileMMDescriptor) {
		if (file == null) {
			// Return always false for null files.
			return false;
		}

		if (!(fileMMDescriptor instanceof SAFEReleaseDescriptor)) {
			// Return true for non-SAFE files
			return true;
		}

		if (projectSafeReleaseProvider == null) {
			projectSafeReleaseProvider = new ProjectSAFEReleaseCache();
		}

		SAFEReleaseDescriptor projectRelease = projectSafeReleaseProvider.get(file.getProject());
		if (projectRelease == null) {
			// Return true for files which are in non-SAFE projects.
			return true;
		}

		return fileMMDescriptor == projectRelease;
	}

	/*
	 * @see org.eclipse.sphinx.emf.scoping.AbstractResourceScope#exists()
	 */
	@Override
	public boolean exists() {
		return super.exists() && SAFEPlatformUtil.hasSAFENature(rootProject);
	}

	/*
	 * @see org.eclipse.sphinx.emf.scoping.ProjectResourceScope#belongsTo(org.eclipse.core.resources.IFile, boolean)
	 */
	@Override
	public boolean belongsTo(IFile file, boolean includeReferencedScopes) {
		if (super.belongsTo(file, includeReferencedScopes)) {
			IMetaModelDescriptor mmDescriptor = MetaModelDescriptorRegistry.INSTANCE.getDescriptor(file);
			return isSafeReleaseCorrespondingToEnclosingProject(file, mmDescriptor);
		} else {
			return false;
		}
	}

	/*
	 * @see org.eclipse.sphinx.emf.scoping.ProjectResourceScope#belongsTo(org.eclipse.emf.ecore.resource.Resource,
	 * boolean)
	 */
	@Override
	public boolean belongsTo(Resource resource, boolean includeReferencedScopes) {
		if (super.belongsTo(resource, includeReferencedScopes)) {
			IMetaModelDescriptor mmDescriptor = MetaModelDescriptorRegistry.INSTANCE.getDescriptor(resource);
			return isSafeReleaseCorrespondingToEnclosingProject(EcorePlatformUtil.getFile(resource), mmDescriptor);
		} else {
			return false;
		}
	}

	/*
	 * @see org.eclipse.sphinx.emf.scoping.ProjectResourceScope#belongsTo(org.eclipse.emf.common.util.URI, boolean)
	 */
	@Override
	public boolean belongsTo(URI uri, boolean includeReferencedScopes) {
		if (super.belongsTo(uri, includeReferencedScopes)) {
			IMetaModelDescriptor mmDescriptor = MetaModelDescriptorRegistry.INSTANCE.getDescriptor(uri);
			return isSafeReleaseCorrespondingToEnclosingProject(EcorePlatformUtil.getFile(uri), mmDescriptor);
		} else {
			return false;
		}
	}
}

