/**
 * <copyright>
 * 
 * Copyright (c) 2014 itemis France and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis France - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.metamodel.safe10;

import org.eclipse.emf.common.util.EList;

/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>Error Model Type</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * ErrorModelType and ErrorModelPrototype support the hierarchical composition of error models based on the type-prototype pattern also adopted for the nominal architecture composition. The purpose of the error models is to represent information relating to the anomalies of a nominal model element. 
 * 
 * Independent of the different subtypes of ErrorModelType, this class describes the external faults  affecting the element, external failures caused by the element and fault propagations within the nominal element. 
 * 
 * ErrorModelType inherits the abstract metaclass TraceableSpecification, allowing the ErrorModelType to be referenced from its design context in a similar way as requirements, test cases and other specifications. 
 * 
 * Constraints:
 * For An ErrorModelType without part, a respective error behavior shall be defined in the safety model.
 * 
 * Semantics:
 * The ErrorModelType represents a specification of the faults and fault propagations of its target element.
 * 
 * Both types and prototypes may be targets, and the following cases are relevant:
 * 
 * - One nominal type:
 * 
 * The ErrorModelType represents the identified nominal type wherever this nominal type is instantiated.
 * 
 * - Several nominal types:
 * 
 * The ErrorModelType represents the identified nominal types individually, i.e. the same error model applies to all nominal types and is reused.
 * 
 * - One nominal prototype:
 * 
 * The ErrorModelType represents the identified nominal prototype whenever its context, i.e. its top-level composition is instantiated.
 * 
 * - Several nominal prototypes with instanceref:
 * 
 * The ErrorModelType represents the identified set of nominal prototypes (together) whenever their context, i.e. their top-level composition, is instantiated.
 * 
 * The fault propagation of an errorModelType is defined by its contained parts, the ErrorModelPrototypes and their connections. In case an error behavior is defined for this error model type, the fault propagation information, the error behavior and the parts of the error model shall be consistent.
 * 
 * FaultFailurePropagationLinks define valid propagation paths in the ErrorModelType. In case the contained external faults and external failures reference nominal ports, the connectivity of the nominal model may serve as a pattern for connecting malfunction prototypes in the ErrorModelType.
 * 
 * Extension:
 * (see ADLTraceableSpecfication)
 * 
 * Original fully qualified name: 
 * <em><b>safe10.ClassModel.ErrorModel.ErrorModelType.ErrorModelType</b></em> 
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link org.safe.metamodel.safe10.ErrorModelType#getErrorModelKind <em>Error Model Kind</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.ErrorModelType#getGenericDescription <em>Generic Description</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.ErrorModelType#getFaultFailureConnector <em>Fault Failure Connector</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.ErrorModelType#getPart <em>Part</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.ErrorModelType#getQuantitativeInformation <em>Quantitative Information</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.ErrorModelType#getExternalFault <em>External Fault</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.ErrorModelType#getExternalFailure <em>External Failure</em>}</li>
 * </ul>
 * </p>
 *
 * @see org.safe.metamodel.safe10.Safe10Package#getErrorModelType()
 * @model annotation="MetaData guid='{EB5607C1-5B47-43dd-81EC-C0D12D27F069}' id='407964011' EA\040name='ErrorModelType'"
 *        extendedMetaData="name='ERROR-MODEL-TYPE' kind='elementOnly'"
 *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='ERROR-MODEL-TYPES'"
 * @generated
 */
public interface ErrorModelType extends TraceableSpecification
{
  /**
   * Returns the value of the '<em><b>Error Model Kind</b></em>' attribute.
   * The default value is <code>"ASSUMPTION"</code>.
   * The literals are from the enumeration {@link org.safe.metamodel.safe10.ErrorModelKind}.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Error Model Kind</em>' attribute isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Error Model Kind</em>' attribute.
   * @see org.safe.metamodel.safe10.ErrorModelKind
   * @see #isSetErrorModelKind()
   * @see #unsetErrorModelKind()
   * @see #setErrorModelKind(ErrorModelKind)
   * @see org.safe.metamodel.safe10.Safe10Package#getErrorModelType_ErrorModelKind()
   * @model default="ASSUMPTION" unsettable="true" required="true"
   *        annotation="MetaData guid='{FAF0E981-8646-437f-8528-1378A16BC642}' id='1405452256' EA\040name='errorModelKind'"
   *        extendedMetaData="name='ERROR-MODEL-KIND' kind='element'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='ERROR-MODEL-KINDS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  ErrorModelKind getErrorModelKind();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.ErrorModelType#getErrorModelKind <em>Error Model Kind</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Error Model Kind</em>' attribute.
   * @see org.safe.metamodel.safe10.ErrorModelKind
   * @see #isSetErrorModelKind()
   * @see #ErrorModelKind()
   * @see #getErrorModelKind()
   * @generated
   */
  void setErrorModelKind(ErrorModelKind value);

  /**
   * Unsets the value of the '{@link org.safe.metamodel.safe10.ErrorModelType#getErrorModelKind <em>Error Model Kind</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetErrorModelKind()
   * @see #getErrorModelKind()
   * @see #setErrorModelKind(ErrorModelKind)
   * @generated
   */
  void unsetErrorModelKind();

  /**
   * Returns whether the value of the '{@link org.safe.metamodel.safe10.ErrorModelType#getErrorModelKind <em>Error Model Kind</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Error Model Kind</em>' attribute is set.
   * @see #ErrorModelKind()
   * @see #getErrorModelKind()
   * @see #setErrorModelKind(ErrorModelKind)
   * @generated
   */
  boolean isSetErrorModelKind();

  /**
   * Returns the value of the '<em><b>Generic Description</b></em>' attribute.
   * The default value is <code>""</code>.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Generic Description</em>' attribute isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Generic Description</em>' attribute.
   * @see #isSetGenericDescription()
   * @see #unsetGenericDescription()
   * @see #setGenericDescription(String)
   * @see org.safe.metamodel.safe10.Safe10Package#getErrorModelType_GenericDescription()
   * @model default="" unsettable="true" dataType="org.safe.metamodel.safe10.String" required="true"
   *        annotation="MetaData guid='{580E8E89-4F2F-4ee6-B3CF-BAE775F07605}' id='-1737176624' EA\040name='genericDescription'"
   *        extendedMetaData="name='GENERIC-DESCRIPTION' kind='element'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='GENERIC-DESCRIPTIONS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  String getGenericDescription();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.ErrorModelType#getGenericDescription <em>Generic Description</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Generic Description</em>' attribute.
   * @see #isSetGenericDescription()
   * @see #GenericDescription()
   * @see #getGenericDescription()
   * @generated
   */
  void setGenericDescription(String value);

  /**
   * Unsets the value of the '{@link org.safe.metamodel.safe10.ErrorModelType#getGenericDescription <em>Generic Description</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetGenericDescription()
   * @see #getGenericDescription()
   * @see #setGenericDescription(String)
   * @generated
   */
  void unsetGenericDescription();

  /**
   * Returns whether the value of the '{@link org.safe.metamodel.safe10.ErrorModelType#getGenericDescription <em>Generic Description</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Generic Description</em>' attribute is set.
   * @see #GenericDescription()
   * @see #getGenericDescription()
   * @see #setGenericDescription(String)
   * @generated
   */
  boolean isSetGenericDescription();

  /**
   * Returns the value of the '<em><b>Fault Failure Connector</b></em>' containment reference list.
   * The list contents are of type {@link org.safe.metamodel.safe10.FaultFailurePropagationLink}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * The contained links for internal propagation of faults/failures between the subordinate error models.
   * <!-- end-model-doc -->
   * @return the value of the '<em>Fault Failure Connector</em>' containment reference list.
   * @see org.safe.metamodel.safe10.Safe10Package#getErrorModelType_FaultFailureConnector()
   * @model containment="true"
   *        annotation="MetaData guid='{5834E9A2-9389-4e6d-AB4D-4312B81EF036}' id='-1893015005' EA\040name=''"
   *        extendedMetaData="name='FAULT-FAILURE-CONNECTOR' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='FAULT-FAILURE-CONNECTORS' xmlAttribute='false' featureWrapperElement='true' featureElement='false' classifierWrapperElement='false' classifierElement='true'"
   * @generated
   */
  EList<FaultFailurePropagationLink> getFaultFailureConnector();

  /**
   * Returns the value of the '<em><b>Part</b></em>' containment reference list.
   * The list contents are of type {@link org.safe.metamodel.safe10.ErrorModelPrototype}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * The contained error models forming a hierarchy.
   * <!-- end-model-doc -->
   * @return the value of the '<em>Part</em>' containment reference list.
   * @see org.safe.metamodel.safe10.Safe10Package#getErrorModelType_Part()
   * @model containment="true"
   *        annotation="MetaData guid='{CE8E4F6F-0FC5-49fe-BAF8-B2BF63733CE0}' id='1898538219' EA\040name=''"
   *        extendedMetaData="name='PART' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='PARTS' xmlAttribute='false' featureWrapperElement='true' featureElement='false' classifierWrapperElement='false' classifierElement='true'"
   * @generated
   */
  EList<ErrorModelPrototype> getPart();

  /**
   * Returns the value of the '<em><b>Quantitative Information</b></em>' containment reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * The quantitative information for this ErrorModelType.
   * <!-- end-model-doc -->
   * @return the value of the '<em>Quantitative Information</em>' containment reference.
   * @see #setQuantitativeInformation(QuantitativeErrorModel)
   * @see org.safe.metamodel.safe10.Safe10Package#getErrorModelType_QuantitativeInformation()
   * @model containment="true" required="true"
   *        annotation="MetaData guid='{AD3E2F34-C554-400b-999D-1BA963BA757B}' id='1145867127' EA\040name=''"
   *        extendedMetaData="name='QUANTITATIVE-INFORMATION' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='QUANTITATIVE-INFORMATIONS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  QuantitativeErrorModel getQuantitativeInformation();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.ErrorModelType#getQuantitativeInformation <em>Quantitative Information</em>}' containment reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Quantitative Information</em>' containment reference.
   * @see #getQuantitativeInformation()
   * @generated
   */
  void setQuantitativeInformation(QuantitativeErrorModel value);

  /**
   * Returns the value of the '<em><b>External Fault</b></em>' containment reference list.
   * The list contents are of type {@link org.safe.metamodel.safe10.MalfunctionPrototype}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * The external faults affecting the proper execution of the architectural element associated with the error model type
   * <!-- end-model-doc -->
   * @return the value of the '<em>External Fault</em>' containment reference list.
   * @see org.safe.metamodel.safe10.Safe10Package#getErrorModelType_ExternalFault()
   * @model containment="true"
   *        annotation="MetaData guid='{65306F93-1BFF-4d79-951A-F84B7E747A46}' id='-118528814' EA\040name=''"
   *        extendedMetaData="name='EXTERNAL-FAULT' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='EXTERNAL-FAULTS' xmlAttribute='false' featureWrapperElement='true' featureElement='false' classifierWrapperElement='false' classifierElement='true'"
   * @generated
   */
  EList<MalfunctionPrototype> getExternalFault();

  /**
   * Returns the value of the '<em><b>External Failure</b></em>' containment reference list.
   * The list contents are of type {@link org.safe.metamodel.safe10.MalfunctionPrototype}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * The external failures visible at the borders of the architectural element.
   * <!-- end-model-doc -->
   * @return the value of the '<em>External Failure</em>' containment reference list.
   * @see org.safe.metamodel.safe10.Safe10Package#getErrorModelType_ExternalFailure()
   * @model containment="true"
   *        annotation="MetaData guid='{9E78873D-A948-4d3e-A237-6789E709F76E}' id='481892100' EA\040name=''"
   *        extendedMetaData="name='EXTERNAL-FAILURE' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='EXTERNAL-FAILURES' xmlAttribute='false' featureWrapperElement='true' featureElement='false' classifierWrapperElement='false' classifierElement='true'"
   * @generated
   */
  EList<MalfunctionPrototype> getExternalFailure();

} // ErrorModelType
