/**
 * <copyright>
 * 
 * Copyright (c) 2014 itemis France and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis France - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.metamodel.safe10;


/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>Fault Failure Propagation Link</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * The FaultFailurePropagationLink metaclass represents the links for the propagations of faults/failures across system elements. In particular, it defines that one error model provides the faults/failures that another error model receives.
 * 
 * A fault/failure link can only be applied to compatible ports, either for fault/failure delegation within an error model or for fault/failure transmission across two error models. A FaultFailurePropagationLink can only connect fault/failures that have compatible types. 
 * 
 * Constraints:
 * [1] Only compatible cause-effect pairs may be connected.
 * 
 * [2] Two fault/failure are compatible if the MalfunctionType of the cause represents a subset of the MalfunctionType set represented by the MalfunctionType of the effect. 
 * 
 * Semantics:
 * The FaultFailurePropagationLink defines a Failure propagation path, from the cause on one error model to the effect of another error model. 
 * 
 * 
 * Extension:
 * UML::Connector
 * 
 * Original fully qualified name: 
 * <em><b>safe10.ClassModel.ErrorModel.ErrorModelType.FaultFailurePropagationLink</b></em> 
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link org.safe.metamodel.safe10.FaultFailurePropagationLink#getDescription <em>Description</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.FaultFailurePropagationLink#getImmediatePropagation <em>Immediate Propagation</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.FaultFailurePropagationLink#getEffect <em>Effect</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.FaultFailurePropagationLink#getCause <em>Cause</em>}</li>
 * </ul>
 * </p>
 *
 * @see org.safe.metamodel.safe10.Safe10Package#getFaultFailurePropagationLink()
 * @model annotation="MetaData guid='{DE9FADCA-2350-4456-BDF4-B923CAD341A1}' id='-601828299' EA\040name='FaultFailurePropagationLink'"
 *        extendedMetaData="name='FAULT-FAILURE-PROPAGATION-LINK' kind='elementOnly'"
 *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='FAULT-FAILURE-PROPAGATION-LINKS'"
 * @generated
 */
public interface FaultFailurePropagationLink extends Identifiable
{
  /**
   * Returns the value of the '<em><b>Description</b></em>' attribute.
   * The default value is <code>""</code>.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Description</em>' attribute isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Description</em>' attribute.
   * @see #isSetDescription()
   * @see #unsetDescription()
   * @see #setDescription(String)
   * @see org.safe.metamodel.safe10.Safe10Package#getFaultFailurePropagationLink_Description()
   * @model default="" unsettable="true" dataType="org.safe.metamodel.safe10.String" required="true"
   *        annotation="MetaData guid='{9B7AB058-B782-4583-A59A-6E81A0C23BBA}' id='1184609811' EA\040name='description'"
   *        extendedMetaData="name='DESCRIPTION' kind='element'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='DESCRIPTIONS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  String getDescription();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.FaultFailurePropagationLink#getDescription <em>Description</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Description</em>' attribute.
   * @see #isSetDescription()
   * @see #Description()
   * @see #getDescription()
   * @generated
   */
  void setDescription(String value);

  /**
   * Unsets the value of the '{@link org.safe.metamodel.safe10.FaultFailurePropagationLink#getDescription <em>Description</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetDescription()
   * @see #getDescription()
   * @see #setDescription(String)
   * @generated
   */
  void unsetDescription();

  /**
   * Returns whether the value of the '{@link org.safe.metamodel.safe10.FaultFailurePropagationLink#getDescription <em>Description</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Description</em>' attribute is set.
   * @see #Description()
   * @see #getDescription()
   * @see #setDescription(String)
   * @generated
   */
  boolean isSetDescription();

  /**
   * Returns the value of the '<em><b>Immediate Propagation</b></em>' attribute.
   * The default value is <code>"false"</code>.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Immediate Propagation</em>' attribute isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Immediate Propagation</em>' attribute.
   * @see #isSetImmediatePropagation()
   * @see #unsetImmediatePropagation()
   * @see #setImmediatePropagation(Boolean)
   * @see org.safe.metamodel.safe10.Safe10Package#getFaultFailurePropagationLink_ImmediatePropagation()
   * @model default="false" unsettable="true" dataType="org.safe.metamodel.safe10.Boolean" required="true"
   *        annotation="MetaData guid='{A241B878-36FC-46ad-9E33-4A964ED996D2}' id='-189994158' EA\040name='immediatePropagation'"
   *        extendedMetaData="name='IMMEDIATE-PROPAGATION' kind='element'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='IMMEDIATE-PROPAGATIONS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  Boolean getImmediatePropagation();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.FaultFailurePropagationLink#getImmediatePropagation <em>Immediate Propagation</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Immediate Propagation</em>' attribute.
   * @see #isSetImmediatePropagation()
   * @see #ImmediatePropagation()
   * @see #getImmediatePropagation()
   * @generated
   */
  void setImmediatePropagation(Boolean value);

  /**
   * Unsets the value of the '{@link org.safe.metamodel.safe10.FaultFailurePropagationLink#getImmediatePropagation <em>Immediate Propagation</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetImmediatePropagation()
   * @see #getImmediatePropagation()
   * @see #setImmediatePropagation(Boolean)
   * @generated
   */
  void unsetImmediatePropagation();

  /**
   * Returns whether the value of the '{@link org.safe.metamodel.safe10.FaultFailurePropagationLink#getImmediatePropagation <em>Immediate Propagation</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Immediate Propagation</em>' attribute is set.
   * @see #ImmediatePropagation()
   * @see #getImmediatePropagation()
   * @see #setImmediatePropagation(Boolean)
   * @generated
   */
  boolean isSetImmediatePropagation();

  /**
   * Returns the value of the '<em><b>Effect</b></em>' containment reference.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Effect</em>' containment reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Effect</em>' containment reference.
   * @see #setEffect(MalfunctionInstanceRef)
   * @see org.safe.metamodel.safe10.Safe10Package#getFaultFailurePropagationLink_Effect()
   * @model containment="true" required="true"
   *        annotation="MetaData guid='{3EE23176-F21B-4b3d-9B71-D4F59D5C028C}' id='-233431452' EA\040name=''"
   *        annotation="TaggedValues xml.name='EFFECT-IREF' xml.namePlural='EFFECT-IREFS' xml.roleElement='true' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        extendedMetaData="name='EFFECT-IREF' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='EFFECT-IREFS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  MalfunctionInstanceRef getEffect();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.FaultFailurePropagationLink#getEffect <em>Effect</em>}' containment reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Effect</em>' containment reference.
   * @see #getEffect()
   * @generated
   */
  void setEffect(MalfunctionInstanceRef value);

  /**
   * Returns the value of the '<em><b>Cause</b></em>' containment reference.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Cause</em>' containment reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Cause</em>' containment reference.
   * @see #setCause(MalfunctionInstanceRef)
   * @see org.safe.metamodel.safe10.Safe10Package#getFaultFailurePropagationLink_Cause()
   * @model containment="true" required="true"
   *        annotation="MetaData guid='{CE83B388-EC4A-4ce9-B8B7-989C598D8FD3}' id='-222555062' EA\040name=''"
   *        annotation="TaggedValues xml.name='CAUSE-IREF' xml.namePlural='CAUSE-IREFS' xml.roleElement='true' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        extendedMetaData="name='CAUSE-IREF' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='CAUSE-IREFS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  MalfunctionInstanceRef getCause();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.FaultFailurePropagationLink#getCause <em>Cause</em>}' containment reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Cause</em>' containment reference.
   * @see #getCause()
   * @generated
   */
  void setCause(MalfunctionInstanceRef value);

} // FaultFailurePropagationLink
