/**
 * <copyright>
 * 
 * Copyright (c) 2014 itemis France and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis France - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.metamodel.safe10;


/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>HW Element Failure Rate Class</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * This class describes for a HWComponent, the FailureRateClass element to evaluate measure for a malfunction (link to violation of a safety goal) for a single element. This violation is based on failure rate class according to context of evaluation such as ASIL level, list of HWFault and diagnosis coverage of the HWComponent as HW Element.  It allows also storing the target for failure rate class, relevant or not depending of the possible HWFault of the failure mode of the HWComponent as  hardware Element. Furthermore if dedicated measures (DM) are required due to failure class target matching and the necessary information are captured as a textual description.
 * 
 * The calculation of the attribute HWElementFailureClass and HWElementDiagnosisCoverage is derived from the Formula Expression FMSingleContributionFormula.
 * 
 * Original fully qualified name: 
 * <em><b>safe10.ClassModel.Hardware.ProbabilisticMethods.HWElementFailureRateClass</b></em> 
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link org.safe.metamodel.safe10.HWElementFailureRateClass#getHwElementFailureClass <em>Hw Element Failure Class</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.HWElementFailureRateClass#getHwElementLatentDiagnosisCoverage <em>Hw Element Latent Diagnosis Coverage</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.HWElementFailureRateClass#getHwElementResidualDiagnosisCoverage <em>Hw Element Residual Diagnosis Coverage</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.HWElementFailureRateClass#getLFTargetFailureRateClass <em>LF Target Failure Rate Class</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.HWElementFailureRateClass#getRationaleDedicatedMeasures <em>Rationale Dedicated Measures</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.HWElementFailureRateClass#getRationaleFailureRateClass <em>Rationale Failure Rate Class</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.HWElementFailureRateClass#getRFTargetFailureRateClass <em>RF Target Failure Rate Class</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.HWElementFailureRateClass#getSPFTargetFailureRateClass <em>SPF Target Failure Rate Class</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.HWElementFailureRateClass#getHwEFRChwElementValue <em>Hw EFR Chw Element Value</em>}</li>
 * </ul>
 * </p>
 *
 * @see org.safe.metamodel.safe10.Safe10Package#getHWElementFailureRateClass()
 * @model annotation="MetaData guid='{236B1260-994E-420c-871F-2F39A1649694}' id='1701386264' EA\040name='HWElementFailureRateClass'"
 *        extendedMetaData="name='HW-ELEMENT-FAILURE-RATE-CLASS' kind='elementOnly'"
 *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='HW-ELEMENT-FAILURE-RATE-CLASSS'"
 * @generated
 */
public interface HWElementFailureRateClass extends Identifiable
{
  /**
   * Returns the value of the '<em><b>Hw Element Failure Class</b></em>' attribute.
   * The default value is <code>"FAILURERATECLASS1"</code>.
   * The literals are from the enumeration {@link org.safe.metamodel.safe10.HWValuesFailureRateClassEnum}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * Failure Rate Class taken from HWValuesRateClassEnum based on the failure rate of the hardware component.
   * <!-- end-model-doc -->
   * @return the value of the '<em>Hw Element Failure Class</em>' attribute.
   * @see org.safe.metamodel.safe10.HWValuesFailureRateClassEnum
   * @see #isSetHwElementFailureClass()
   * @see #unsetHwElementFailureClass()
   * @see #setHwElementFailureClass(HWValuesFailureRateClassEnum)
   * @see org.safe.metamodel.safe10.Safe10Package#getHWElementFailureRateClass_HwElementFailureClass()
   * @model default="FAILURERATECLASS1" unsettable="true" required="true"
   *        annotation="MetaData guid='{860324C4-363D-4538-A120-34033E656501}' id='-853619655' EA\040name='hwElementFailureClass'"
   *        extendedMetaData="name='HW-ELEMENT-FAILURE-CLASS' kind='element'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='HW-ELEMENT-FAILURE-CLASSS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  HWValuesFailureRateClassEnum getHwElementFailureClass();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.HWElementFailureRateClass#getHwElementFailureClass <em>Hw Element Failure Class</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Hw Element Failure Class</em>' attribute.
   * @see org.safe.metamodel.safe10.HWValuesFailureRateClassEnum
   * @see #isSetHwElementFailureClass()
   * @see #HwElementFailureClass()
   * @see #getHwElementFailureClass()
   * @generated
   */
  void setHwElementFailureClass(HWValuesFailureRateClassEnum value);

  /**
   * Unsets the value of the '{@link org.safe.metamodel.safe10.HWElementFailureRateClass#getHwElementFailureClass <em>Hw Element Failure Class</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetHwElementFailureClass()
   * @see #getHwElementFailureClass()
   * @see #setHwElementFailureClass(HWValuesFailureRateClassEnum)
   * @generated
   */
  void unsetHwElementFailureClass();

  /**
   * Returns whether the value of the '{@link org.safe.metamodel.safe10.HWElementFailureRateClass#getHwElementFailureClass <em>Hw Element Failure Class</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Hw Element Failure Class</em>' attribute is set.
   * @see #HwElementFailureClass()
   * @see #getHwElementFailureClass()
   * @see #setHwElementFailureClass(HWValuesFailureRateClassEnum)
   * @generated
   */
  boolean isSetHwElementFailureClass();

  /**
   * Returns the value of the '<em><b>Hw Element Latent Diagnosis Coverage</b></em>' attribute.
   * The default value is <code>"0.0"</code>.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * The diagnostic coverage with respect to latent faults on hardware element level, calculated with the specific failure rate of all latent multiple-point faults and the overall failure rate of the hardware part element.
   * <!-- end-model-doc -->
   * @return the value of the '<em>Hw Element Latent Diagnosis Coverage</em>' attribute.
   * @see #isSetHwElementLatentDiagnosisCoverage()
   * @see #unsetHwElementLatentDiagnosisCoverage()
   * @see #setHwElementLatentDiagnosisCoverage(Double)
   * @see org.safe.metamodel.safe10.Safe10Package#getHWElementFailureRateClass_HwElementLatentDiagnosisCoverage()
   * @model default="0.0" unsettable="true" dataType="org.safe.metamodel.safe10.Float" required="true"
   *        annotation="MetaData guid='{3DA0E041-A7FD-4bd2-8A40-F060E25BF82A}' id='1797594118' EA\040name='hwElementLatentDiagnosisCoverage'"
   *        extendedMetaData="name='HW-ELEMENT-LATENT-DIAGNOSIS-COVERAGE' kind='element'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='HW-ELEMENT-LATENT-DIAGNOSIS-COVERAGES' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  Double getHwElementLatentDiagnosisCoverage();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.HWElementFailureRateClass#getHwElementLatentDiagnosisCoverage <em>Hw Element Latent Diagnosis Coverage</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Hw Element Latent Diagnosis Coverage</em>' attribute.
   * @see #isSetHwElementLatentDiagnosisCoverage()
   * @see #HwElementLatentDiagnosisCoverage()
   * @see #getHwElementLatentDiagnosisCoverage()
   * @generated
   */
  void setHwElementLatentDiagnosisCoverage(Double value);

  /**
   * Unsets the value of the '{@link org.safe.metamodel.safe10.HWElementFailureRateClass#getHwElementLatentDiagnosisCoverage <em>Hw Element Latent Diagnosis Coverage</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetHwElementLatentDiagnosisCoverage()
   * @see #getHwElementLatentDiagnosisCoverage()
   * @see #setHwElementLatentDiagnosisCoverage(Double)
   * @generated
   */
  void unsetHwElementLatentDiagnosisCoverage();

  /**
   * Returns whether the value of the '{@link org.safe.metamodel.safe10.HWElementFailureRateClass#getHwElementLatentDiagnosisCoverage <em>Hw Element Latent Diagnosis Coverage</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Hw Element Latent Diagnosis Coverage</em>' attribute is set.
   * @see #HwElementLatentDiagnosisCoverage()
   * @see #getHwElementLatentDiagnosisCoverage()
   * @see #setHwElementLatentDiagnosisCoverage(Double)
   * @generated
   */
  boolean isSetHwElementLatentDiagnosisCoverage();

  /**
   * Returns the value of the '<em><b>Hw Element Residual Diagnosis Coverage</b></em>' attribute.
   * The default value is <code>"0.0"</code>.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * The diagnostic coverage with respect to residual faults on hardware element level, calculated with the specific failure rate of all single-point and residual faults and the overall failure rate of the hardware part element.
   * <!-- end-model-doc -->
   * @return the value of the '<em>Hw Element Residual Diagnosis Coverage</em>' attribute.
   * @see #isSetHwElementResidualDiagnosisCoverage()
   * @see #unsetHwElementResidualDiagnosisCoverage()
   * @see #setHwElementResidualDiagnosisCoverage(Double)
   * @see org.safe.metamodel.safe10.Safe10Package#getHWElementFailureRateClass_HwElementResidualDiagnosisCoverage()
   * @model default="0.0" unsettable="true" dataType="org.safe.metamodel.safe10.Float" required="true"
   *        annotation="MetaData guid='{E6936D04-5F14-4c09-9999-A8947E16047C}' id='-1875685105' EA\040name='hwElementResidualDiagnosisCoverage'"
   *        extendedMetaData="name='HW-ELEMENT-RESIDUAL-DIAGNOSIS-COVERAGE' kind='element'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='HW-ELEMENT-RESIDUAL-DIAGNOSIS-COVERAGES' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  Double getHwElementResidualDiagnosisCoverage();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.HWElementFailureRateClass#getHwElementResidualDiagnosisCoverage <em>Hw Element Residual Diagnosis Coverage</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Hw Element Residual Diagnosis Coverage</em>' attribute.
   * @see #isSetHwElementResidualDiagnosisCoverage()
   * @see #HwElementResidualDiagnosisCoverage()
   * @see #getHwElementResidualDiagnosisCoverage()
   * @generated
   */
  void setHwElementResidualDiagnosisCoverage(Double value);

  /**
   * Unsets the value of the '{@link org.safe.metamodel.safe10.HWElementFailureRateClass#getHwElementResidualDiagnosisCoverage <em>Hw Element Residual Diagnosis Coverage</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetHwElementResidualDiagnosisCoverage()
   * @see #getHwElementResidualDiagnosisCoverage()
   * @see #setHwElementResidualDiagnosisCoverage(Double)
   * @generated
   */
  void unsetHwElementResidualDiagnosisCoverage();

  /**
   * Returns whether the value of the '{@link org.safe.metamodel.safe10.HWElementFailureRateClass#getHwElementResidualDiagnosisCoverage <em>Hw Element Residual Diagnosis Coverage</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Hw Element Residual Diagnosis Coverage</em>' attribute is set.
   * @see #HwElementResidualDiagnosisCoverage()
   * @see #getHwElementResidualDiagnosisCoverage()
   * @see #setHwElementResidualDiagnosisCoverage(Double)
   * @generated
   */
  boolean isSetHwElementResidualDiagnosisCoverage();

  /**
   * Returns the value of the '<em><b>LF Target Failure Rate Class</b></em>' attribute.
   * The default value is <code>"OUTOFSCOPE"</code>.
   * The literals are from the enumeration {@link org.safe.metamodel.safe10.HWLFTargetFailureRateClassEnum}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * Target Failure Rate Class for multiple-point latent faults, taken from HWLFTargetFailureRateClassEnum.
   * <!-- end-model-doc -->
   * @return the value of the '<em>LF Target Failure Rate Class</em>' attribute.
   * @see org.safe.metamodel.safe10.HWLFTargetFailureRateClassEnum
   * @see #isSetLFTargetFailureRateClass()
   * @see #unsetLFTargetFailureRateClass()
   * @see #setLFTargetFailureRateClass(HWLFTargetFailureRateClassEnum)
   * @see org.safe.metamodel.safe10.Safe10Package#getHWElementFailureRateClass_LFTargetFailureRateClass()
   * @model default="OUTOFSCOPE" unsettable="true" required="true"
   *        annotation="MetaData guid='{49A4436F-F708-441c-AE3D-4F0D1417F521}' id='-1399277148' EA\040name='LFTargetFailureRateClass'"
   *        extendedMetaData="name='LF-TARGET-FAILURE-RATE-CLASS' kind='element'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='LF-TARGET-FAILURE-RATE-CLASSS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  HWLFTargetFailureRateClassEnum getLFTargetFailureRateClass();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.HWElementFailureRateClass#getLFTargetFailureRateClass <em>LF Target Failure Rate Class</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>LF Target Failure Rate Class</em>' attribute.
   * @see org.safe.metamodel.safe10.HWLFTargetFailureRateClassEnum
   * @see #isSetLFTargetFailureRateClass()
   * @see #LFTargetFailureRateClass()
   * @see #getLFTargetFailureRateClass()
   * @generated
   */
  void setLFTargetFailureRateClass(HWLFTargetFailureRateClassEnum value);

  /**
   * Unsets the value of the '{@link org.safe.metamodel.safe10.HWElementFailureRateClass#getLFTargetFailureRateClass <em>LF Target Failure Rate Class</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetLFTargetFailureRateClass()
   * @see #getLFTargetFailureRateClass()
   * @see #setLFTargetFailureRateClass(HWLFTargetFailureRateClassEnum)
   * @generated
   */
  void unsetLFTargetFailureRateClass();

  /**
   * Returns whether the value of the '{@link org.safe.metamodel.safe10.HWElementFailureRateClass#getLFTargetFailureRateClass <em>LF Target Failure Rate Class</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>LF Target Failure Rate Class</em>' attribute is set.
   * @see #LFTargetFailureRateClass()
   * @see #getLFTargetFailureRateClass()
   * @see #setLFTargetFailureRateClass(HWLFTargetFailureRateClassEnum)
   * @generated
   */
  boolean isSetLFTargetFailureRateClass();

  /**
   * Returns the value of the '<em><b>Rationale Dedicated Measures</b></em>' attribute.
   * The default value is <code>""</code>.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * Provides rationale for dedicated measures, if required.
   * 
   * According to ISO 26262 Part 5 9.4.2.4, examples for dedicated measures are
   * 
   * a) design features such as hardware part over design (e.g. electrical or thermal stress rating) or physical separation (e.g. spacing of contacts on a printed circuit board); 
   * b) a special sample test of incoming material to reduce the risk of occurrence of this failure mode; 
   * c) a burn-in test; 
   * d) a dedicated control set as part of the control plan; and 
   * e) assignment of safety-related special characteristics. 
   * <!-- end-model-doc -->
   * @return the value of the '<em>Rationale Dedicated Measures</em>' attribute.
   * @see #isSetRationaleDedicatedMeasures()
   * @see #unsetRationaleDedicatedMeasures()
   * @see #setRationaleDedicatedMeasures(String)
   * @see org.safe.metamodel.safe10.Safe10Package#getHWElementFailureRateClass_RationaleDedicatedMeasures()
   * @model default="" unsettable="true" dataType="org.safe.metamodel.safe10.String" required="true"
   *        annotation="MetaData guid='{FC2B73AA-2858-45de-88B0-D80F3FB6B1C9}' id='-1029572139' EA\040name='rationaleDedicatedMeasures'"
   *        extendedMetaData="name='RATIONALE-DEDICATED-MEASURES' kind='element'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='RATIONALE-DEDICATED-MEASURESS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  String getRationaleDedicatedMeasures();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.HWElementFailureRateClass#getRationaleDedicatedMeasures <em>Rationale Dedicated Measures</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Rationale Dedicated Measures</em>' attribute.
   * @see #isSetRationaleDedicatedMeasures()
   * @see #RationaleDedicatedMeasures()
   * @see #getRationaleDedicatedMeasures()
   * @generated
   */
  void setRationaleDedicatedMeasures(String value);

  /**
   * Unsets the value of the '{@link org.safe.metamodel.safe10.HWElementFailureRateClass#getRationaleDedicatedMeasures <em>Rationale Dedicated Measures</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetRationaleDedicatedMeasures()
   * @see #getRationaleDedicatedMeasures()
   * @see #setRationaleDedicatedMeasures(String)
   * @generated
   */
  void unsetRationaleDedicatedMeasures();

  /**
   * Returns whether the value of the '{@link org.safe.metamodel.safe10.HWElementFailureRateClass#getRationaleDedicatedMeasures <em>Rationale Dedicated Measures</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Rationale Dedicated Measures</em>' attribute is set.
   * @see #RationaleDedicatedMeasures()
   * @see #getRationaleDedicatedMeasures()
   * @see #setRationaleDedicatedMeasures(String)
   * @generated
   */
  boolean isSetRationaleDedicatedMeasures();

  /**
   * Returns the value of the '<em><b>Rationale Failure Rate Class</b></em>' attribute.
   * The default value is <code>""</code>.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * Rationale for matching criteria on Failure Rate Class.
   * <!-- end-model-doc -->
   * @return the value of the '<em>Rationale Failure Rate Class</em>' attribute.
   * @see #isSetRationaleFailureRateClass()
   * @see #unsetRationaleFailureRateClass()
   * @see #setRationaleFailureRateClass(String)
   * @see org.safe.metamodel.safe10.Safe10Package#getHWElementFailureRateClass_RationaleFailureRateClass()
   * @model default="" unsettable="true" dataType="org.safe.metamodel.safe10.String" required="true"
   *        annotation="MetaData guid='{A2DDA5A6-E56C-46c0-A1B1-31B99B572DE6}' id='-919713678' EA\040name='rationaleFailureRateClass'"
   *        extendedMetaData="name='RATIONALE-FAILURE-RATE-CLASS' kind='element'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='RATIONALE-FAILURE-RATE-CLASSS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  String getRationaleFailureRateClass();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.HWElementFailureRateClass#getRationaleFailureRateClass <em>Rationale Failure Rate Class</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Rationale Failure Rate Class</em>' attribute.
   * @see #isSetRationaleFailureRateClass()
   * @see #RationaleFailureRateClass()
   * @see #getRationaleFailureRateClass()
   * @generated
   */
  void setRationaleFailureRateClass(String value);

  /**
   * Unsets the value of the '{@link org.safe.metamodel.safe10.HWElementFailureRateClass#getRationaleFailureRateClass <em>Rationale Failure Rate Class</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetRationaleFailureRateClass()
   * @see #getRationaleFailureRateClass()
   * @see #setRationaleFailureRateClass(String)
   * @generated
   */
  void unsetRationaleFailureRateClass();

  /**
   * Returns whether the value of the '{@link org.safe.metamodel.safe10.HWElementFailureRateClass#getRationaleFailureRateClass <em>Rationale Failure Rate Class</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Rationale Failure Rate Class</em>' attribute is set.
   * @see #RationaleFailureRateClass()
   * @see #getRationaleFailureRateClass()
   * @see #setRationaleFailureRateClass(String)
   * @generated
   */
  boolean isSetRationaleFailureRateClass();

  /**
   * Returns the value of the '<em><b>RF Target Failure Rate Class</b></em>' attribute.
   * The default value is <code>"OUTOFSCOPE"</code>.
   * The literals are from the enumeration {@link org.safe.metamodel.safe10.HWRFTargetFailureRateClassEnum}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * Target Failure Rate Class for residual faults, taken from HWRFTargetFailureRateClassEnum.
   * <!-- end-model-doc -->
   * @return the value of the '<em>RF Target Failure Rate Class</em>' attribute.
   * @see org.safe.metamodel.safe10.HWRFTargetFailureRateClassEnum
   * @see #isSetRFTargetFailureRateClass()
   * @see #unsetRFTargetFailureRateClass()
   * @see #setRFTargetFailureRateClass(HWRFTargetFailureRateClassEnum)
   * @see org.safe.metamodel.safe10.Safe10Package#getHWElementFailureRateClass_RFTargetFailureRateClass()
   * @model default="OUTOFSCOPE" unsettable="true" required="true"
   *        annotation="MetaData guid='{DF535B12-2D50-4e0c-AC1C-E3D79521BD76}' id='1421420555' EA\040name='RFTargetFailureRateClass'"
   *        extendedMetaData="name='RF-TARGET-FAILURE-RATE-CLASS' kind='element'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='RF-TARGET-FAILURE-RATE-CLASSS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  HWRFTargetFailureRateClassEnum getRFTargetFailureRateClass();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.HWElementFailureRateClass#getRFTargetFailureRateClass <em>RF Target Failure Rate Class</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>RF Target Failure Rate Class</em>' attribute.
   * @see org.safe.metamodel.safe10.HWRFTargetFailureRateClassEnum
   * @see #isSetRFTargetFailureRateClass()
   * @see #RFTargetFailureRateClass()
   * @see #getRFTargetFailureRateClass()
   * @generated
   */
  void setRFTargetFailureRateClass(HWRFTargetFailureRateClassEnum value);

  /**
   * Unsets the value of the '{@link org.safe.metamodel.safe10.HWElementFailureRateClass#getRFTargetFailureRateClass <em>RF Target Failure Rate Class</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetRFTargetFailureRateClass()
   * @see #getRFTargetFailureRateClass()
   * @see #setRFTargetFailureRateClass(HWRFTargetFailureRateClassEnum)
   * @generated
   */
  void unsetRFTargetFailureRateClass();

  /**
   * Returns whether the value of the '{@link org.safe.metamodel.safe10.HWElementFailureRateClass#getRFTargetFailureRateClass <em>RF Target Failure Rate Class</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>RF Target Failure Rate Class</em>' attribute is set.
   * @see #RFTargetFailureRateClass()
   * @see #getRFTargetFailureRateClass()
   * @see #setRFTargetFailureRateClass(HWRFTargetFailureRateClassEnum)
   * @generated
   */
  boolean isSetRFTargetFailureRateClass();

  /**
   * Returns the value of the '<em><b>SPF Target Failure Rate Class</b></em>' attribute.
   * The default value is <code>"OUTOFSCOPE"</code>.
   * The literals are from the enumeration {@link org.safe.metamodel.safe10.HWSPFTargetFailureRateClassEnum}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * Target Failure Rate Class for single-point faults, taken from HWSPFTargetFailureRateClassEnum.
   * <!-- end-model-doc -->
   * @return the value of the '<em>SPF Target Failure Rate Class</em>' attribute.
   * @see org.safe.metamodel.safe10.HWSPFTargetFailureRateClassEnum
   * @see #isSetSPFTargetFailureRateClass()
   * @see #unsetSPFTargetFailureRateClass()
   * @see #setSPFTargetFailureRateClass(HWSPFTargetFailureRateClassEnum)
   * @see org.safe.metamodel.safe10.Safe10Package#getHWElementFailureRateClass_SPFTargetFailureRateClass()
   * @model default="OUTOFSCOPE" unsettable="true" required="true"
   *        annotation="MetaData guid='{68399B96-FB31-4ee0-B463-5BB43E7309B3}' id='1246096368' EA\040name='SPFTargetFailureRateClass'"
   *        extendedMetaData="name='SPF-TARGET-FAILURE-RATE-CLASS' kind='element'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='SPF-TARGET-FAILURE-RATE-CLASSS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  HWSPFTargetFailureRateClassEnum getSPFTargetFailureRateClass();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.HWElementFailureRateClass#getSPFTargetFailureRateClass <em>SPF Target Failure Rate Class</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>SPF Target Failure Rate Class</em>' attribute.
   * @see org.safe.metamodel.safe10.HWSPFTargetFailureRateClassEnum
   * @see #isSetSPFTargetFailureRateClass()
   * @see #SPFTargetFailureRateClass()
   * @see #getSPFTargetFailureRateClass()
   * @generated
   */
  void setSPFTargetFailureRateClass(HWSPFTargetFailureRateClassEnum value);

  /**
   * Unsets the value of the '{@link org.safe.metamodel.safe10.HWElementFailureRateClass#getSPFTargetFailureRateClass <em>SPF Target Failure Rate Class</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetSPFTargetFailureRateClass()
   * @see #getSPFTargetFailureRateClass()
   * @see #setSPFTargetFailureRateClass(HWSPFTargetFailureRateClassEnum)
   * @generated
   */
  void unsetSPFTargetFailureRateClass();

  /**
   * Returns whether the value of the '{@link org.safe.metamodel.safe10.HWElementFailureRateClass#getSPFTargetFailureRateClass <em>SPF Target Failure Rate Class</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>SPF Target Failure Rate Class</em>' attribute is set.
   * @see #SPFTargetFailureRateClass()
   * @see #getSPFTargetFailureRateClass()
   * @see #setSPFTargetFailureRateClass(HWSPFTargetFailureRateClassEnum)
   * @generated
   */
  boolean isSetSPFTargetFailureRateClass();

  /**
   * Returns the value of the '<em><b>Hw EFR Chw Element Value</b></em>' containment reference.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Hw EFR Chw Element Value</em>' containment reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Hw EFR Chw Element Value</em>' containment reference.
   * @see #setHwEFRChwElementValue(HWFailureClassContributionFormula)
   * @see org.safe.metamodel.safe10.Safe10Package#getHWElementFailureRateClass_HwEFRChwElementValue()
   * @model containment="true" required="true"
   *        annotation="MetaData guid='{883078D8-C396-4e97-8075-A2866A2C70C3}' id='1128727914' EA\040name=''"
   *        extendedMetaData="name='HW-EFR-CHW-ELEMENT-VALUE' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='HW-EFR-CHW-ELEMENT-VALUES' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  HWFailureClassContributionFormula getHwEFRChwElementValue();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.HWElementFailureRateClass#getHwEFRChwElementValue <em>Hw EFR Chw Element Value</em>}' containment reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Hw EFR Chw Element Value</em>' containment reference.
   * @see #getHwEFRChwElementValue()
   * @generated
   */
  void setHwEFRChwElementValue(HWFailureClassContributionFormula value);

} // HWElementFailureRateClass
