/**
 * <copyright>
 * 
 * Copyright (c) 2014 itemis France and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis France - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.metamodel.safe10;


/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>HW Fault</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * This class HWFault represent the characterization of a HWComponent Fault defined by tags as Safe Fault, SinglePointFault or MultiplePointFault of a specific FailureMode in a context of an Hardware Architecture.
 * 
 * HardwareFault  can only exist for HardwareComponentPrototype when HWComponent are used given by the HWComponentPrototypeScope.
 * 
 * The related malfunction (link to violation of a SafetyGoals) is already linked with the FailureMode of the HardwareComponent via the HWSafetyGoalRelated meta class.
 * 
 * The different values are:
 * SafeFault: no violation of safety goal
 * ResidualOrSinglePointFault: direct violation of the SafetyGoal (1st order fault)
 * MultiplePointFault : violation of the SafetyGoal in combination with an independent failure of another component (minimum 2nd order)
 * 
 * Multiple-point fault for n&gt;2 are considered as safe faults unless shown to be relevant in the technical safety concept (see ISO Part 5 7.4.3.2 Note 1).
 * 
 * Original fully qualified name: 
 * <em><b>safe10.ClassModel.Hardware.Failure.HWFault</b></em> 
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link org.safe.metamodel.safe10.HWFault#getHwFaultType <em>Hw Fault Type</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.HWFault#getLambdaFailureModeValue <em>Lambda Failure Mode Value</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.HWFault#getHwFailureMode <em>Hw Failure Mode</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.HWFault#getHwFailureModeSingleContribution <em>Hw Failure Mode Single Contribution</em>}</li>
 * </ul>
 * </p>
 *
 * @see org.safe.metamodel.safe10.Safe10Package#getHWFault()
 * @model annotation="MetaData guid='{36272151-D9B6-4c56-9EDE-442D02B473CE}' id='-784997424' EA\040name='HWFault'"
 *        extendedMetaData="name='HW-FAULT' kind='elementOnly'"
 *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='HW-FAULTS'"
 * @generated
 */
public interface HWFault extends Referrable, Identifiable
{
  /**
   * Returns the value of the '<em><b>Hw Fault Type</b></em>' attribute.
   * The default value is <code>"SAFEFAULT"</code>.
   * The literals are from the enumeration {@link org.safe.metamodel.safe10.HWPointFaultEnum}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * Characterization of the Failure Mode for a single point related malfunction (linked to violation of a Safety Goal).
   * singlePoint Hw Fault Type can be either SPF or Residual
   * 
   * Possible Types are:
   * 
   * <ul>
   * 	<li>SafeFault (no violation of Safety Goal)</li>
   * 	<li>ResidualOrSinglePointFault (direct violation of Safety Goal (either covered by Safety Mechanism or not)</li>
   * 	<li>Multiple-Point-Fault (violation of Safety Goal in combination with another independent fault)</li>
   * </ul>
   * <!-- end-model-doc -->
   * @return the value of the '<em>Hw Fault Type</em>' attribute.
   * @see org.safe.metamodel.safe10.HWPointFaultEnum
   * @see #isSetHwFaultType()
   * @see #unsetHwFaultType()
   * @see #setHwFaultType(HWPointFaultEnum)
   * @see org.safe.metamodel.safe10.Safe10Package#getHWFault_HwFaultType()
   * @model default="SAFEFAULT" unsettable="true" required="true"
   *        annotation="MetaData guid='{C4C8E94B-25DE-4300-806D-EDFC2A8FF6D8}' id='354806673' EA\040name='hwFaultType'"
   *        extendedMetaData="name='HW-FAULT-TYPE' kind='element'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='HW-FAULT-TYPES' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  HWPointFaultEnum getHwFaultType();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.HWFault#getHwFaultType <em>Hw Fault Type</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Hw Fault Type</em>' attribute.
   * @see org.safe.metamodel.safe10.HWPointFaultEnum
   * @see #isSetHwFaultType()
   * @see #HwFaultType()
   * @see #getHwFaultType()
   * @generated
   */
  void setHwFaultType(HWPointFaultEnum value);

  /**
   * Unsets the value of the '{@link org.safe.metamodel.safe10.HWFault#getHwFaultType <em>Hw Fault Type</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetHwFaultType()
   * @see #getHwFaultType()
   * @see #setHwFaultType(HWPointFaultEnum)
   * @generated
   */
  void unsetHwFaultType();

  /**
   * Returns whether the value of the '{@link org.safe.metamodel.safe10.HWFault#getHwFaultType <em>Hw Fault Type</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Hw Fault Type</em>' attribute is set.
   * @see #HwFaultType()
   * @see #getHwFaultType()
   * @see #setHwFaultType(HWPointFaultEnum)
   * @generated
   */
  boolean isSetHwFaultType();

  /**
   * Returns the value of the '<em><b>Lambda Failure Mode Value</b></em>' reference.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Lambda Failure Mode Value</em>' reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Lambda Failure Mode Value</em>' reference.
   * @see #setLambdaFailureModeValue(HWComponentQuantifiedFMFromPart)
   * @see org.safe.metamodel.safe10.Safe10Package#getHWFault_LambdaFailureModeValue()
   * @model annotation="MetaData guid='{E82580F3-517B-4936-BC3A-D2D18E78F33D}' id='-2037698283' EA\040name=''"
   *        extendedMetaData="name='LAMBDA-FAILURE-MODE-VALUE-REF' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='LAMBDA-FAILURE-MODE-VALUE-REFS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  HWComponentQuantifiedFMFromPart getLambdaFailureModeValue();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.HWFault#getLambdaFailureModeValue <em>Lambda Failure Mode Value</em>}' reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Lambda Failure Mode Value</em>' reference.
   * @see #getLambdaFailureModeValue()
   * @generated
   */
  void setLambdaFailureModeValue(HWComponentQuantifiedFMFromPart value);

  /**
   * Returns the value of the '<em><b>Hw Failure Mode</b></em>' reference.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Hw Failure Mode</em>' reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Hw Failure Mode</em>' reference.
   * @see #setHwFailureMode(HWFailureMode)
   * @see org.safe.metamodel.safe10.Safe10Package#getHWFault_HwFailureMode()
   * @model required="true"
   *        annotation="MetaData guid='{D78C03A5-5EE4-463c-AE4C-D44B5F808386}' id='1443787530' EA\040name=''"
   *        extendedMetaData="name='HW-FAILURE-MODE-REF' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='HW-FAILURE-MODE-REFS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  HWFailureMode getHwFailureMode();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.HWFault#getHwFailureMode <em>Hw Failure Mode</em>}' reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Hw Failure Mode</em>' reference.
   * @see #getHwFailureMode()
   * @generated
   */
  void setHwFailureMode(HWFailureMode value);

  /**
   * Returns the value of the '<em><b>Hw Failure Mode Single Contribution</b></em>' reference.
   * It is bidirectional and its opposite is '{@link org.safe.metamodel.safe10.HWFMSingleContribution#getNameWasNotSet_4 <em>Name Was Not Set 4</em>}'.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Hw Failure Mode Single Contribution</em>' reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Hw Failure Mode Single Contribution</em>' reference.
   * @see #setHwFailureModeSingleContribution(HWFMSingleContribution)
   * @see org.safe.metamodel.safe10.Safe10Package#getHWFault_HwFailureModeSingleContribution()
   * @see org.safe.metamodel.safe10.HWFMSingleContribution#getNameWasNotSet_4
   * @model opposite="NameWasNotSet_4"
   *        extendedMetaData="name='HW-FAILURE-MODE-SINGLE-CONTRIBUTION-REF' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='HW-FAILURE-MODE-SINGLE-CONTRIBUTION-REFS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  HWFMSingleContribution getHwFailureModeSingleContribution();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.HWFault#getHwFailureModeSingleContribution <em>Hw Failure Mode Single Contribution</em>}' reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Hw Failure Mode Single Contribution</em>' reference.
   * @see #getHwFailureModeSingleContribution()
   * @generated
   */
  void setHwFailureModeSingleContribution(HWFMSingleContribution value);

} // HWFault
