/**
 * <copyright>
 * 
 * Copyright (c) 2014 itemis France and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis France - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.metamodel.safe10;

import org.eclipse.emf.common.util.EList;

/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>HWPMHF Formula</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * This class describes the individual PMHF (in FIT) as probabilistic evaluation of violation of a top level malfunction (link to violation of a SafetyGoal).
 * 
 * PMHF = single point faults failure rate + residual faults failure rate + (total safety related faults failure rate / 10<sup>-9</sup> * delta) * latent multiple point faults failure rate
 * 
 * The formula expression shall be for each SafetyGoal:
 * Value(HWPMHF) = [ Sum (lambdaSinglePointFault(HWFMSingleContribution) + lambdaResidualFault(HWFMSingleContribution)) ] + [ Sum(LambdaSafetyComponent)  *  1.10-9  * exposureTime(HWPMHF) * lambdaMultiplePointLatent(HWFMSingleContribution) ]
 * 
 * Value(HWPMHF) is applied on calculatedValue extracted from electronic design level for final calculation and verification of the final PMHF probability.  The selection between calculated and estimated value is a tool feature that allow first a calculation for estimation based on allocation field of failure rate and distribution. Only Component safety relevant are considered.
 * Sum(xxxxValue(xxxxLambdaSafetyComponent) is applied for estimated and calculated, and only counted once (identical safetyComponentClassName).
 * 
 * Original fully qualified name: 
 * <em><b>safe10.ClassModel.Hardware.FailureFormula.HWPMHFFormula</b></em> 
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link org.safe.metamodel.safe10.HWPMHFFormula#getLambdaValue <em>Lambda Value</em>}</li>
 * </ul>
 * </p>
 *
 * @see org.safe.metamodel.safe10.Safe10Package#getHWPMHFFormula()
 * @model annotation="MetaData guid='{7683EBCA-B75E-4384-9B1D-03A4C062085B}' id='-304705806' EA\040name='HWPMHFFormula'"
 *        extendedMetaData="name='HWPMHF-FORMULA' kind='elementOnly'"
 *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='HWPMHF-FORMULAS'"
 * @generated
 */
public interface HWPMHFFormula extends FormulaDocumentation
{
  /**
   * Returns the value of the '<em><b>Lambda Value</b></em>' reference list.
   * The list contents are of type {@link org.safe.metamodel.safe10.HWFMSingleContribution}.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Lambda Value</em>' reference list isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Lambda Value</em>' reference list.
   * @see org.safe.metamodel.safe10.Safe10Package#getHWPMHFFormula_LambdaValue()
   * @model annotation="MetaData guid='{AAF45E4E-435D-4f9d-92FB-6F963ED88BDA}' id='-2018950031' EA\040name=''"
   *        extendedMetaData="name='LAMBDA-VALUE-REF' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='LAMBDA-VALUE-REFS' xmlAttribute='false' featureWrapperElement='true' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  EList<HWFMSingleContribution> getLambdaValue();

} // HWPMHFFormula
