/**
 * <copyright>
 * 
 * Copyright (c) 2014 itemis France and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis France - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.metamodel.safe10;

import org.eclipse.emf.common.util.EList;

/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>HW Part Failure Analysis</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * This class represent the container for all Hardware Part Failure Analysis (Autosar HWElement) for a malfunction.
 * Each malfunction (as Hardware Failure Mode) must lead to a safety part analysis, so this class contains all the information related to the analysis as :
 * - the relation to the malfunction as the malfunctionPrototype for each analysis
 * - the HwElementPrototypeScope to identify all hardware Autosar Element specific to the context as HWComponentPrototype inside a type composition
 * - the HWComponentQuantifiedFMFromPart Analysis performed on the level of the composition of hardware part for contribution to the malfunction
 * 
 * Original fully qualified name: 
 * <em><b>safe10.ClassModel.Hardware.FailurePart.HWPartFailureAnalysis</b></em> 
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link org.safe.metamodel.safe10.HWPartFailureAnalysis#getMalfunctionPartAnalysis <em>Malfunction Part Analysis</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.HWPartFailureAnalysis#getHwElementScope <em>Hw Element Scope</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.HWPartFailureAnalysis#getQuantifiedHardwareFMFromPart <em>Quantified Hardware FM From Part</em>}</li>
 * </ul>
 * </p>
 *
 * @see org.safe.metamodel.safe10.Safe10Package#getHWPartFailureAnalysis()
 * @model annotation="MetaData guid='{5D357B7C-B93D-46f7-8E91-79BA0BC5D857}' id='-701746011' EA\040name='HWPartFailureAnalysis'"
 *        extendedMetaData="name='HW-PART-FAILURE-ANALYSIS' kind='elementOnly'"
 *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='HW-PART-FAILURE-ANALYSISS'"
 * @generated
 */
public interface HWPartFailureAnalysis extends Identifiable
{
  /**
   * Returns the value of the '<em><b>Malfunction Part Analysis</b></em>' containment reference.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Malfunction Part Analysis</em>' containment reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Malfunction Part Analysis</em>' containment reference.
   * @see #setMalfunctionPartAnalysis(MalfunctionInstanceRef)
   * @see org.safe.metamodel.safe10.Safe10Package#getHWPartFailureAnalysis_MalfunctionPartAnalysis()
   * @model containment="true" required="true"
   *        annotation="MetaData guid='{534C8B62-8E7A-468d-BC54-8E2AF1846AF6}' id='-1346198993' EA\040name=''"
   *        annotation="TaggedValues xml.name='MALFUNCTION-PART-ANALYSIS-IREF' xml.namePlural='MALFUNCTION-PART-ANALYSIS-IREFS' xml.roleElement='true' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        extendedMetaData="name='MALFUNCTION-PART-ANALYSIS-IREF' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='MALFUNCTION-PART-ANALYSIS-IREFS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  MalfunctionInstanceRef getMalfunctionPartAnalysis();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.HWPartFailureAnalysis#getMalfunctionPartAnalysis <em>Malfunction Part Analysis</em>}' containment reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Malfunction Part Analysis</em>' containment reference.
   * @see #getMalfunctionPartAnalysis()
   * @generated
   */
  void setMalfunctionPartAnalysis(MalfunctionInstanceRef value);

  /**
   * Returns the value of the '<em><b>Hw Element Scope</b></em>' reference list.
   * The list contents are of type {@link org.safe.metamodel.safe10.HWElementPrototypeScope}.
   * It is bidirectional and its opposite is '{@link org.safe.metamodel.safe10.HWElementPrototypeScope#getNameWasNotSet_2 <em>Name Was Not Set 2</em>}'.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Hw Element Scope</em>' reference list isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Hw Element Scope</em>' reference list.
   * @see org.safe.metamodel.safe10.Safe10Package#getHWPartFailureAnalysis_HwElementScope()
   * @see org.safe.metamodel.safe10.HWElementPrototypeScope#getNameWasNotSet_2
   * @model opposite="NameWasNotSet_2"
   *        extendedMetaData="name='HW-ELEMENT-SCOPE-REF' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='HW-ELEMENT-SCOPE-REFS' xmlAttribute='false' featureWrapperElement='true' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  EList<HWElementPrototypeScope> getHwElementScope();

  /**
   * Returns the value of the '<em><b>Quantified Hardware FM From Part</b></em>' reference.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Quantified Hardware FM From Part</em>' reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Quantified Hardware FM From Part</em>' reference.
   * @see #setQuantifiedHardwareFMFromPart(HWComponentQuantifiedFMFromPart)
   * @see org.safe.metamodel.safe10.Safe10Package#getHWPartFailureAnalysis_QuantifiedHardwareFMFromPart()
   * @model annotation="MetaData guid='{C687E08C-EE8E-4c15-A70B-68202A370AFF}' id='622194477' EA\040name=''"
   *        extendedMetaData="name='QUANTIFIED-HARDWARE-FM-FROM-PART-REF' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='QUANTIFIED-HARDWARE-FM-FROM-PART-REFS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  HWComponentQuantifiedFMFromPart getQuantifiedHardwareFMFromPart();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.HWPartFailureAnalysis#getQuantifiedHardwareFMFromPart <em>Quantified Hardware FM From Part</em>}' reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Quantified Hardware FM From Part</em>' reference.
   * @see #getQuantifiedHardwareFMFromPart()
   * @generated
   */
  void setQuantifiedHardwareFMFromPart(HWComponentQuantifiedFMFromPart value);

} // HWPartFailureAnalysis
