/**
 * <copyright>
 * 
 * Copyright (c) 2014 itemis France and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis France - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.metamodel.safe10;

import org.eclipse.emf.common.util.EList;

/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>Hardware Software Interface Specification</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * The HardwareSoftwareInterface (HSI) specification specifies the hardware and software interaction. 
 * 
 * The HSI specification includes the component's hardware devices that are controlled by software and hardware resources that support the execution of software.
 * 
 * The HSI specification shall includes the following characteristics:
 * a) the relevant operating modes of hardware devices and the relevant configuration parameters;
 * EXAMPLE 1 Operating modes of hardware devices such as: default, init, test or advanced modes.
 * EXAMPLE 2 Configuration parameters such as: gain control, band pass frequency or clock prescaler.
 * b) the hardware features that ensure the independence between elements and that support software partitioning;
 * c) shared and exclusive use of hardware resources;
 * EXAMPLE 3 Memory mapping, allocation of registers, timers, interrupts, I/O ports.
 * d) the access mechanism to hardware devices; and
 * EXAMPLE 4 Serial, parallel, slave, master/slave.
 * e) the timing constraints defined for each service involved in the technical safety concept.
 * 
 * Original fully qualified name: 
 * <em><b>safe10.ClassModel.System.HardwareSoftwareInterfaceSpecification</b></em> 
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link org.safe.metamodel.safe10.HardwareSoftwareInterfaceSpecification#getHSIElements <em>HSI Elements</em>}</li>
 * </ul>
 * </p>
 *
 * @see org.safe.metamodel.safe10.Safe10Package#getHardwareSoftwareInterfaceSpecification()
 * @model annotation="MetaData guid='{54EACE86-8206-4517-ABB5-7A50EE3BC559}' id='-906981718' EA\040name='HardwareSoftwareInterfaceSpecification'"
 *        extendedMetaData="name='HARDWARE-SOFTWARE-INTERFACE-SPECIFICATION' kind='elementOnly'"
 *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='HARDWARE-SOFTWARE-INTERFACE-SPECIFICATIONS'"
 * @generated
 */
public interface HardwareSoftwareInterfaceSpecification extends Identifiable
{
  /**
   * Returns the value of the '<em><b>HSI Elements</b></em>' containment reference list.
   * The list contents are of type {@link org.safe.metamodel.safe10.HardwareSoftwareInterfaceElement}.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>HSI Elements</em>' containment reference list isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>HSI Elements</em>' containment reference list.
   * @see org.safe.metamodel.safe10.Safe10Package#getHardwareSoftwareInterfaceSpecification_HSIElements()
   * @model containment="true"
   *        annotation="MetaData guid='{039E0FBB-DD1B-437e-82C7-CECDD88E5AA0}' id='-1341924321' EA\040name=''"
   *        extendedMetaData="name='H-SI-ELEMENTS' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='H-SI-ELEMENTSS' xmlAttribute='false' featureWrapperElement='true' featureElement='false' classifierWrapperElement='false' classifierElement='true'"
   * @generated
   */
  EList<HardwareSoftwareInterfaceElement> getHSIElements();

} // HardwareSoftwareInterfaceSpecification
