/**
 * <copyright>
 * 
 * Copyright (c) 2014 itemis France and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis France - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.metamodel.safe10;


/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>Hazard</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * A hazard describes a potential source of harm. Important is that it is formulated in terms of behavior that can be observed on vehicle level.
 * 
 * Hazards shall be defined in terms of the conditions or behavior that can be observed at the vehicle level. 
 * 
 * The hazards shall be determined systematically by using adequate techniques, such as brainstorming, checklists, quality history, FMEA and field studies.
 * 
 * <i><u>Reference:</u></i>
 * ISO 26262-3-7.4.2.2.2
 * ISO 26262-3-7.4.2.2.1
 * 
 * Original fully qualified name: 
 * <em><b>safe10.ClassModel.Hazards.Hazard</b></em> 
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link org.safe.metamodel.safe10.Hazard#getFormal <em>Formal</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.Hazard#getInformal <em>Informal</em>}</li>
 * </ul>
 * </p>
 *
 * @see org.safe.metamodel.safe10.Safe10Package#getHazard()
 * @model annotation="MetaData guid='{FBE4CEFB-5060-484b-8AF1-EAA98AEE2514}' id='1125210707' EA\040name='Hazard'"
 *        extendedMetaData="name='HAZARD' kind='elementOnly'"
 *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='HAZARDS'"
 * @generated
 */
public interface Hazard extends Identifiable
{
  /**
   * Returns the value of the '<em><b>Formal</b></em>' attribute.
   * The default value is <code>""</code>.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * Provides the possibility to capture the formal description of the hazard.
   * <!-- end-model-doc -->
   * @return the value of the '<em>Formal</em>' attribute.
   * @see #isSetFormal()
   * @see #unsetFormal()
   * @see #setFormal(String)
   * @see org.safe.metamodel.safe10.Safe10Package#getHazard_Formal()
   * @model default="" unsettable="true" dataType="org.safe.metamodel.safe10.String" required="true"
   *        annotation="MetaData guid='{3EBE641F-F519-4b36-A1CC-6262F0955155}' id='-1762430312' EA\040name='formal'"
   *        extendedMetaData="name='FORMAL' kind='element'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='FORMALS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  String getFormal();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.Hazard#getFormal <em>Formal</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Formal</em>' attribute.
   * @see #isSetFormal()
   * @see #Formal()
   * @see #getFormal()
   * @generated
   */
  void setFormal(String value);

  /**
   * Unsets the value of the '{@link org.safe.metamodel.safe10.Hazard#getFormal <em>Formal</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetFormal()
   * @see #getFormal()
   * @see #setFormal(String)
   * @generated
   */
  void unsetFormal();

  /**
   * Returns whether the value of the '{@link org.safe.metamodel.safe10.Hazard#getFormal <em>Formal</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Formal</em>' attribute is set.
   * @see #Formal()
   * @see #getFormal()
   * @see #setFormal(String)
   * @generated
   */
  boolean isSetFormal();

  /**
   * Returns the value of the '<em><b>Informal</b></em>' attribute.
   * The default value is <code>""</code>.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * Provides the possibility to capture the informal description of the hazard.
   * <!-- end-model-doc -->
   * @return the value of the '<em>Informal</em>' attribute.
   * @see #isSetInformal()
   * @see #unsetInformal()
   * @see #setInformal(String)
   * @see org.safe.metamodel.safe10.Safe10Package#getHazard_Informal()
   * @model default="" unsettable="true" dataType="org.safe.metamodel.safe10.String" required="true"
   *        annotation="MetaData guid='{3FE97368-C875-4dfa-B2EA-0B3F56003C91}' id='-272649031' EA\040name='informal'"
   *        extendedMetaData="name='INFORMAL' kind='element'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='INFORMALS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  String getInformal();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.Hazard#getInformal <em>Informal</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Informal</em>' attribute.
   * @see #isSetInformal()
   * @see #Informal()
   * @see #getInformal()
   * @generated
   */
  void setInformal(String value);

  /**
   * Unsets the value of the '{@link org.safe.metamodel.safe10.Hazard#getInformal <em>Informal</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetInformal()
   * @see #getInformal()
   * @see #setInformal(String)
   * @generated
   */
  void unsetInformal();

  /**
   * Returns whether the value of the '{@link org.safe.metamodel.safe10.Hazard#getInformal <em>Informal</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Informal</em>' attribute is set.
   * @see #Informal()
   * @see #getInformal()
   * @see #setInformal(String)
   * @generated
   */
  boolean isSetInformal();

} // Hazard
