/**
 * <copyright>
 * 
 * Copyright (c) 2014 itemis France and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis France - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.metamodel.safe10;


/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>Malfunction Prototype</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * A malfunction is a failure or unintended behavior of the item or element of the item that has the potential to propogate. The MalfunctionPrototype metaclass represents an error that may occur internally in an ErrorModel or be propagated to it, or a failure that is propagated out of an Error Model. The MalfunctionPrototype may represent different errors depending on its type (enumeration of generic description).
 * 
 * Semantics:
 * An malfunction prototype refers to a condition that deviates from expectations based on requirements specifications, design documents, user documents, standards, etc., or from someone's perceptions or experiences (ISO26262). The set of available faults or failures represented by the MalfunctionPrototype is defined by its type, typically an enumeration type like {omission, commission}. It is an abstract class further specialized with metaclasses for different types of fault/failure.
 * 
 * Extension:
 * (UML::Part)
 * 
 * Original fully qualified name: 
 * <em><b>safe10.ClassModel.ErrorModel.Malfunction.MalfunctionPrototype</b></em> 
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link org.safe.metamodel.safe10.MalfunctionPrototype#getGenericDescription <em>Generic Description</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.MalfunctionPrototype#getType <em>Type</em>}</li>
 * </ul>
 * </p>
 *
 * @see org.safe.metamodel.safe10.Safe10Package#getMalfunctionPrototype()
 * @model annotation="MetaData guid='{1796FECA-7118-40fa-9C81-F5D7E75453F4}' id='-1171674075' EA\040name='MalfunctionPrototype'"
 *        extendedMetaData="name='MALFUNCTION-PROTOTYPE' kind='elementOnly'"
 *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='MALFUNCTION-PROTOTYPES'"
 * @generated
 */
public interface MalfunctionPrototype extends Identifiable
{
  /**
   * Returns the value of the '<em><b>Generic Description</b></em>' attribute.
   * The default value is <code>""</code>.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * A description of the MalfunctionPrototype
   * <!-- end-model-doc -->
   * @return the value of the '<em>Generic Description</em>' attribute.
   * @see #isSetGenericDescription()
   * @see #unsetGenericDescription()
   * @see #setGenericDescription(String)
   * @see org.safe.metamodel.safe10.Safe10Package#getMalfunctionPrototype_GenericDescription()
   * @model default="" unsettable="true" dataType="org.safe.metamodel.safe10.String" required="true"
   *        annotation="MetaData guid='{0CCFC6E3-3526-42f5-B71F-FA428A050C32}' id='977043586' EA\040name='genericDescription'"
   *        extendedMetaData="name='GENERIC-DESCRIPTION' kind='element'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='GENERIC-DESCRIPTIONS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  String getGenericDescription();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.MalfunctionPrototype#getGenericDescription <em>Generic Description</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Generic Description</em>' attribute.
   * @see #isSetGenericDescription()
   * @see #GenericDescription()
   * @see #getGenericDescription()
   * @generated
   */
  void setGenericDescription(String value);

  /**
   * Unsets the value of the '{@link org.safe.metamodel.safe10.MalfunctionPrototype#getGenericDescription <em>Generic Description</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetGenericDescription()
   * @see #getGenericDescription()
   * @see #setGenericDescription(String)
   * @generated
   */
  void unsetGenericDescription();

  /**
   * Returns whether the value of the '{@link org.safe.metamodel.safe10.MalfunctionPrototype#getGenericDescription <em>Generic Description</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Generic Description</em>' attribute is set.
   * @see #GenericDescription()
   * @see #getGenericDescription()
   * @see #setGenericDescription(String)
   * @generated
   */
  boolean isSetGenericDescription();

  /**
   * Returns the value of the '<em><b>Type</b></em>' reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * The type of the malfunction prototype. It describes how the malfunction prototype becomes visible.
   * <!-- end-model-doc -->
   * @return the value of the '<em>Type</em>' reference.
   * @see #setType(MalfunctionType)
   * @see org.safe.metamodel.safe10.Safe10Package#getMalfunctionPrototype_Type()
   * @model required="true"
   *        annotation="MetaData guid='{4E0C592C-2C31-4787-A223-EEA5EEBF5A9B}' id='1218767231' EA\040name=''"
   *        annotation="Stereotype Stereotype='isOfType'"
   *        extendedMetaData="name='TYPE-TREF' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='TYPE-TREFS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  MalfunctionType getType();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.MalfunctionPrototype#getType <em>Type</em>}' reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Type</em>' reference.
   * @see #getType()
   * @generated
   */
  void setType(MalfunctionType value);

} // MalfunctionPrototype
