/**
 * <copyright>
 * 
 * Copyright (c) 2014 itemis France and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis France - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.metamodel.safe10;

import org.eclipse.emf.common.util.EList;

/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>Safety Concept</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * This container provides the possibility to group different requirements belonging to the realization of a safety concept. For example, a functional safety concept consisting of requirements specifying what kind of error detection must be done and what kind of handling for detected errors must be done.
 * 
 * Furthermore, the container provides two attributes relevant for safety concepts, fault tolerant time interval (FTTI) and emergency operation time interval. These attributes can be used to derive the time quantum allocated to each requirement belonging to the concept.
 * 
 * Original fully qualified name: 
 * <em><b>safe10.ClassModel.Requirements.SafetyConcept</b></em> 
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link org.safe.metamodel.safe10.SafetyConcept#getEmergencyOperationTimeInterval <em>Emergency Operation Time Interval</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.SafetyConcept#getFaultTolerantTimeInterval <em>Fault Tolerant Time Interval</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.SafetyConcept#getSafetyGoal <em>Safety Goal</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.SafetyConcept#getRequirements <em>Requirements</em>}</li>
 * </ul>
 * </p>
 *
 * @see org.safe.metamodel.safe10.Safe10Package#getSafetyConcept()
 * @model annotation="MetaData guid='{B0A0DA86-6ED5-49c0-AC5C-CB4D7429BF11}' id='-924295792' EA\040name='SafetyConcept'"
 *        extendedMetaData="name='SAFETY-CONCEPT' kind='elementOnly'"
 *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='SAFETY-CONCEPTS'"
 * @generated
 */
public interface SafetyConcept extends AbstractSafetyRequirement
{
  /**
   * Returns the value of the '<em><b>Emergency Operation Time Interval</b></em>' attribute.
   * The default value is <code>"0"</code>.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Emergency Operation Time Interval</em>' attribute isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Emergency Operation Time Interval</em>' attribute.
   * @see #isSetEmergencyOperationTimeInterval()
   * @see #unsetEmergencyOperationTimeInterval()
   * @see #setEmergencyOperationTimeInterval(Integer)
   * @see org.safe.metamodel.safe10.Safe10Package#getSafetyConcept_EmergencyOperationTimeInterval()
   * @model default="0" unsettable="true" dataType="org.safe.metamodel.safe10.Integer"
   *        annotation="MetaData guid='{F4E787EC-0CA4-4a7b-B72E-E61E0289E105}' id='-1772714304' EA\040name='emergencyOperationTimeInterval'"
   *        extendedMetaData="name='EMERGENCY-OPERATION-TIME-INTERVAL' kind='attribute'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='EMERGENCY-OPERATION-TIME-INTERVALS' xmlAttribute='true' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  Integer getEmergencyOperationTimeInterval();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.SafetyConcept#getEmergencyOperationTimeInterval <em>Emergency Operation Time Interval</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Emergency Operation Time Interval</em>' attribute.
   * @see #isSetEmergencyOperationTimeInterval()
   * @see #EmergencyOperationTimeInterval()
   * @see #getEmergencyOperationTimeInterval()
   * @generated
   */
  void setEmergencyOperationTimeInterval(Integer value);

  /**
   * Unsets the value of the '{@link org.safe.metamodel.safe10.SafetyConcept#getEmergencyOperationTimeInterval <em>Emergency Operation Time Interval</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetEmergencyOperationTimeInterval()
   * @see #getEmergencyOperationTimeInterval()
   * @see #setEmergencyOperationTimeInterval(Integer)
   * @generated
   */
  void unsetEmergencyOperationTimeInterval();

  /**
   * Returns whether the value of the '{@link org.safe.metamodel.safe10.SafetyConcept#getEmergencyOperationTimeInterval <em>Emergency Operation Time Interval</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Emergency Operation Time Interval</em>' attribute is set.
   * @see #EmergencyOperationTimeInterval()
   * @see #getEmergencyOperationTimeInterval()
   * @see #setEmergencyOperationTimeInterval(Integer)
   * @generated
   */
  boolean isSetEmergencyOperationTimeInterval();

  /**
   * Returns the value of the '<em><b>Fault Tolerant Time Interval</b></em>' attribute.
   * The default value is <code>"0"</code>.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Fault Tolerant Time Interval</em>' attribute isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Fault Tolerant Time Interval</em>' attribute.
   * @see #isSetFaultTolerantTimeInterval()
   * @see #unsetFaultTolerantTimeInterval()
   * @see #setFaultTolerantTimeInterval(Integer)
   * @see org.safe.metamodel.safe10.Safe10Package#getSafetyConcept_FaultTolerantTimeInterval()
   * @model default="0" unsettable="true" dataType="org.safe.metamodel.safe10.Integer"
   *        annotation="MetaData guid='{68F8B44A-8258-440f-A722-0DC16711B61F}' id='-1549844453' EA\040name='faultTolerantTimeInterval'"
   *        extendedMetaData="name='FAULT-TOLERANT-TIME-INTERVAL' kind='attribute'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='FAULT-TOLERANT-TIME-INTERVALS' xmlAttribute='true' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  Integer getFaultTolerantTimeInterval();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.SafetyConcept#getFaultTolerantTimeInterval <em>Fault Tolerant Time Interval</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Fault Tolerant Time Interval</em>' attribute.
   * @see #isSetFaultTolerantTimeInterval()
   * @see #FaultTolerantTimeInterval()
   * @see #getFaultTolerantTimeInterval()
   * @generated
   */
  void setFaultTolerantTimeInterval(Integer value);

  /**
   * Unsets the value of the '{@link org.safe.metamodel.safe10.SafetyConcept#getFaultTolerantTimeInterval <em>Fault Tolerant Time Interval</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetFaultTolerantTimeInterval()
   * @see #getFaultTolerantTimeInterval()
   * @see #setFaultTolerantTimeInterval(Integer)
   * @generated
   */
  void unsetFaultTolerantTimeInterval();

  /**
   * Returns whether the value of the '{@link org.safe.metamodel.safe10.SafetyConcept#getFaultTolerantTimeInterval <em>Fault Tolerant Time Interval</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Fault Tolerant Time Interval</em>' attribute is set.
   * @see #FaultTolerantTimeInterval()
   * @see #getFaultTolerantTimeInterval()
   * @see #setFaultTolerantTimeInterval(Integer)
   * @generated
   */
  boolean isSetFaultTolerantTimeInterval();

  /**
   * Returns the value of the '<em><b>Safety Goal</b></em>' reference list.
   * The list contents are of type {@link org.safe.metamodel.safe10.FunctionalSafetyRequirement}.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Safety Goal</em>' reference list isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Safety Goal</em>' reference list.
   * @see org.safe.metamodel.safe10.Safe10Package#getSafetyConcept_SafetyGoal()
   * @model annotation="MetaData guid='{27732D84-FB33-413c-B1CD-552474EAB19C}' id='1552542175' EA\040name=''"
   *        extendedMetaData="name='SAFETY-GOAL-REF' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='SAFETY-GOAL-REFS' xmlAttribute='false' featureWrapperElement='true' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  EList<FunctionalSafetyRequirement> getSafetyGoal();

  /**
   * Returns the value of the '<em><b>Requirements</b></em>' reference list.
   * The list contents are of type {@link org.safe.metamodel.safe10.AbstractSafetyRequirement}.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Requirements</em>' reference list isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Requirements</em>' reference list.
   * @see org.safe.metamodel.safe10.Safe10Package#getSafetyConcept_Requirements()
   * @model annotation="MetaData guid='{DD745C18-F07B-4c25-BA5B-99BD2E9A5D4F}' id='2023209642' EA\040name=''"
   *        extendedMetaData="name='REQUIREMENTS-REF' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='REQUIREMENTS-REFS' xmlAttribute='false' featureWrapperElement='true' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  EList<AbstractSafetyRequirement> getRequirements();

} // SafetyConcept
