/**
 * <copyright>
 * 
 * Copyright (c) 2013 itemis and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.serialization.internal;

import java.util.Map;

import org.eatop.eel.serialization.internal.ExtendedXMLPersistenceMappingHandler;
import org.eclipse.emf.common.util.URI;
import org.eclipse.emf.ecore.EStructuralFeature;
import org.eclipse.emf.ecore.InternalEObject;
import org.eclipse.emf.ecore.xmi.XMLHelper;
import org.eclipse.emf.ecore.xmi.XMLResource;
import org.eclipse.emf.ecore.xmi.impl.XMLHandler;
import org.safe.common.resource.SAFEURIFactory;
import org.safe.common.util.ISAFEConstants;

/**
 * A ExtendedXMLPersistenceMappingHandler that can handle SAX events from a SAFE resource.
 */
public class SafeXMLPersistenceMappingHandler extends ExtendedXMLPersistenceMappingHandler {

	/**
	 * @param xmlResource
	 * @param helper
	 * @param options
	 */
	public SafeXMLPersistenceMappingHandler(XMLResource xmlResource, XMLHelper helper, Map<?, ?> options) {
		super(xmlResource, helper, options);
	}

	/*
	 * Overridden to enrich proxy URIs being created with context information required to honor their {@link
	 * IResourceScope resource scope}s when they are being resolved and to support the resolution of proxified
	 * references between objects from different metamodels.
	 * @see org.eclipse.emf.ecore.xmi.impl.XMLHandler#handleProxy(org.eclipse.emf.ecore.InternalEObject,
	 * java.lang.String)
	 */
	@Override
	protected void handleProxy(InternalEObject proxy, String uriLiteral) {
		int index = uriLiteral.lastIndexOf(ISAFEConstants.FRAGMENT_SEPARATOR); // "#"
		if (index != -1) {
			uriLiteral = uriLiteral.substring(index + 1);
		}
		index = uriLiteral.lastIndexOf(ISAFEConstants.QUERY_SEPARATOR + ISAFEConstants.DESTINATION_TYPE_KEY + ISAFEConstants.KEY_VALUE_SEPARATOR); // "?type="
		if (index != -1) {
			uriLiteral = uriLiteral.substring(0, index);
		}

		URI proxyURI = SAFEURIFactory.createSAFEURI(uriLiteral, proxy.eClass().getName());
		proxy.eSetProxyURI(proxyURI);
	}

	// FIXME: to check 2013-01-09
	@SuppressWarnings("nls")
	@Override
	/**
	 * Returns the xsi type. 
	 * Since the xsiType does not save the prefix, the original fetched xsiType does not contain ":". 
	 * Therefore it could not be directly indicated that whether the xsiType is SAFE or a referenced namesapce.  
	 * It is possible that the xsiType is SAFE, as well as AUTOSAR or EAST-ADL. 
	 * To distiguish such cases, if the URI of the package of the feature type is different from SAFE, 
	 * then it is considered to be an AUTOSAR or EAST-ADL element, the prefix is append to construct the new xsiType for loading the model
	 */
	protected String getXSIType(EStructuralFeature f) {
		typeAttributeName = xmlPersistenceMappingExtendedMetaData.getXMLTypeAttributeName(f);
		if (null == typeAttributeName || XMLHandler.TYPE_ATTRIB.equals(typeAttributeName)) {
			return getXSIType();
		} else {
			String namespace = xmlPersistenceMappingExtendedMetaData.getNamespace(f);
			if (null == namespace) {
				namespace = f.getEContainingClass().getEPackage().getNsURI();
			}
			String xsiType = attribs.getValue(typeAttributeName);
			if (null == xsiType) {
				xsiType = attribs.getValue(namespace, typeAttributeName);
			}
			if (null != xsiType && !xsiType.contains(":")) {
				String prefix = helper.getPrefix(namespace);
				if (null == prefix || !"".equals(prefix)) {
					StringBuffer buffer = new StringBuffer();
					buffer.append(helper.getPrefix(namespace));
					buffer.append(":");
					buffer.append(xsiType);
					xsiType = buffer.toString();
				}
				// If prefix is "", it is still possible that the xsiType is AUTOSAR or EAST-ADL element.
				// If the URI of the package of the feature type is different from the SAFE nsURI, then get the
				// prefix and append it to construct the new xsiType for loading the model
				else if ("".equals(prefix)) {
					String nsURI = f.getEType().getEPackage().getNsURI();
					if (nsURI.contains(ISAFEConstants.AUTOSAR_ROOT_PACKAGE_NSURI)) {
						nsURI = ISAFEConstants.AUTOSAR_NSURI;
					}
					if (nsURI != ISAFEConstants.SAFE_PACKAGE_NSURI) {
						StringBuffer buffer = new StringBuffer();
						buffer.append(helper.getPrefix(nsURI));
						buffer.append(":");
						buffer.append(xsiType);
						xsiType = buffer.toString();
					}
				}

			}

			return xsiType;
		}
	}
}