/**
 * <copyright>
 * 
 * Copyright (c) itemis and others.
 * All rights reserved. This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 
 * which accompanies this distribution, and is
 * available at http://www.eclipse.org/org/documents/epl-v10.php
 * 
 * Contributors: 
 *     itemis - Initial API and implementation
 * 
 * </copyright>
 */
 package org.safe.metamodelgen.serialization.generators.xsd

import org.eclipse.emf.common.util.URI
import java.io.File
import org.eclipse.emf.ecore.EPackage
import org.eclipse.sphinx.emf.serialization.generators.util.Ecore2XSDUtil
import java.util.Map
import org.eclipse.core.runtime.IProgressMonitor
import org.eclipse.sphinx.emf.serialization.generators.xsd.Ecore2XSDFactory
import org.eclipse.sphinx.emf.serialization.generators.xsd.Ecore2XSDGenerator
import org.eclipse.sphinx.emf.serialization.generators.xsd.Ecore2XSDConverter
import org.eclipse.xsd.XSDSchema

class SAFEEcore2XSDGenerator extends Ecore2XSDGenerator {
	protected String AR_Root_Package_Ns = "http://autosar.org/schema/r4.0/autosar40"; 
	protected String AR_Global_Ns = "http://autosar.org/schema/r4.0"; 
	
//	protected String EA_Root_Package_Ns = "http://east-adl.info/2.1.11/eastadl21"; 
//	protected String EA_Global_Ns = "http://east-adl.info/2.1.11"; 
	protected String EA_Root_Package_Ns = "http://east-adl.info/2.1.12/eastadl21"; 
	protected String EA_Global_Ns = "http://east-adl.info/2.1.12";
	
	new(URI xsdFileURI, File schemaFile, EPackage ecoreModel) {
		super(xsdFileURI, schemaFile, ecoreModel)
	}
	
	// provide SAFE ecore2xsd converter
	override protected Ecore2XSDConverter createEcore2XSDConverter(Ecore2XSDFactory xsdFactory, XSDSchema xsdSchema){
		return new SAFEEcore2XSDConverter(xsdFactory, xsdSchema)
	}
	
	// provide SAFE ecore2xsd generator
	override protected Ecore2XSDFactory createEcore2XSDFactory(){		
		return new SAFEEcore2XSDFactory(ecoreModel);
	}
	
	override protected void refineXSDSchemaNamespace(IProgressMonitor monitor){
		val Map<String, String> namespaces = xsdSchema.getQNamePrefixToNamespaceMap();
		if(namespaces.containsValue(AR_Root_Package_Ns)){
			val String prefix = Ecore2XSDUtil::getNsPrefixFromQNamePrefixToNamespaceMap(namespaces, AR_Root_Package_Ns);
			if(prefix != null){
				namespaces.remove(prefix);
				namespaces.put(prefix, AR_Global_Ns);
			}
		}
		
		monitor.worked(50);
		
		if(namespaces.containsValue(EA_Root_Package_Ns)){
			val String prefix = Ecore2XSDUtil::getNsPrefixFromQNamePrefixToNamespaceMap(namespaces, EA_Root_Package_Ns);
			if(prefix != null){
				namespaces.remove(prefix);
				namespaces.put(prefix, EA_Global_Ns);
			}
		}
		
		monitor.done();
	}
	
}