package org.safe.metamodelgen.postprocessings;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.util.List;
import java.util.Properties;

import org.eclipse.core.resources.IContainer;
import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IResource;
import org.eclipse.eatop.eaadapter.ea2ecore.postprocessings.AdjustGenModel;
import org.eclipse.eatop.eaadapter.util.IConstants;
import org.eclipse.eatop.metamodelgen.util.ITemplateConstants;
import org.eclipse.emf.codegen.ecore.genmodel.GenModel;
import org.eclipse.emf.codegen.ecore.genmodel.GenPackage;
import org.eclipse.emf.codegen.ecore.genmodel.GenResourceKind;
import org.eclipse.emf.ecore.resource.ResourceSet;
import org.safe.metamodelgen.util.SAFEConstants;

public class SAFEAdjustGenModel extends AdjustGenModel {

	private static final String EASTADL_STUB_GENMODEL = SAFEConstants.EASTADL_STUB_GENMODEL;
    private static final String AUTOSAR_STUB_GENMODEL = SAFEConstants.AUTOSAR_STUB_GENMODEL;
		
	public String getGenModelProperties(){
			return "../../../../../../" + SAFEConstants.SAFE_SOURCE_PATH + SAFEConstants.SAFE_GENMODEL_PROPERTIES;
	}
	
	@Override
	public String getModelConfigPropertiesPath(){
			return "../../../../../../" + SAFEConstants.SAFE_SOURCE_PATH + IConstants.SOURCE_MODEL_ROOT_PATH + SAFEConstants.SOURCE_REVISION_NAME_PREFIX_SAFE;  //"/model/safe-";
	}
	
	
	public SAFEAdjustGenModel(File modelFile, String modelProject, String version) throws IOException {
		super(modelFile, modelProject, version);
		
		//load GenModel-Properties from properties file
		Properties props = new Properties();
		InputStream in;
				
					//in = getClass().getResourceAsStream(GENMODEL_PROPERTIES);
					//in = getClass().getResourceAsStream(getGenModelProperties());
					URL url = getClass().getResource(getGenModelProperties());
					in = url.openStream();
					props.load(in);
					in.close();
					this.fileExtensions = props.getProperty(ITemplateConstants.FILE_EXTENSIONS);
					this.complianceLevel = props.getProperty(ITemplateConstants.COMPLIANCE_LEVEL);		    
					this.nonNLSMarkers = Boolean.valueOf(props.getProperty(ITemplateConstants.NON_NLS_MARKERS));
					this.runtimeVersion = props.getProperty(ITemplateConstants.RUNTIME_VERSION);
					this.modelPluginClass = props.getProperty(ITemplateConstants.MODEL_PLUGIN_CLASS);
					this.modelPluginVariables = props.getProperty(ITemplateConstants.MODEL_PLUGIN_VARIABLES);
					this.editPluginClass = props.getProperty(ITemplateConstants.EDIT_PLUGIN_CLASS);
					this.editPluginVariables = props.getProperty(ITemplateConstants.EDIT_PLUGIN_VARIABLES);
					this.creationIcons = Boolean.valueOf(props.getProperty(ITemplateConstants.CREATION_ICONS));
					this.providerRootExtendsClass = props.getProperty(ITemplateConstants.PROVIDER_ROOT_EXTENDS_CLASS);
					this.rootExtendsClass = props.getProperty(ITemplateConstants.ROOT_EXTENDS_CLASS);
					this.rootPackageBasePackage = props.getProperty(ITemplateConstants.ROOT_PACKAGE_BASE_PACKAGE);
					
					if (version != null && version.length() > 0) {

						//in = getClass().getResourceAsStream(getModelConfigPropertiesPath() + version + "/" + MODEL_CONFIG_PROPERTIES_NAME);
						URL modelCfgUrl = getClass().getResource(getModelConfigPropertiesPath() + version + "/" + MODEL_CONFIG_PROPERTIES_NAME);
						in = modelCfgUrl.openStream();
						props.load(in);
						in.close();
						this.rootPackageContentTypeId = props.getProperty(ITemplateConstants.ROOT_PACKAGE_CONTENT_TYPE_ID);
					}
	}
	
	@Override
	protected GenModel addUsedGenPackage(GenModel genModel, IFile iFile, ResourceSet resourceSet){
		IContainer folder = iFile.getParent();
		
		// Add used gen package: EASTADL STUB package
		IResource eastadl21GenModel = folder.findMember(EASTADL_STUB_GENMODEL);		
		if (eastadl21GenModel != null && eastadl21GenModel instanceof IFile && eastadl21GenModel.exists()) {
			UsedGenModel usedEastadl21GenModel = new UsedGenModel();
			usedEastadl21GenModel.setFile((IFile) eastadl21GenModel);
			List<GenPackage> genPackageList = usedEastadl21GenModel.loadRootGenPackage(resourceSet);
			if(genPackageList!= null){
				for(GenPackage genPackage : genPackageList){
					logger.info("EAST-ADL STUB genPackage = " + genPackage.getPackageName());
				}
			}
					
			genModel.getUsedGenPackages().addAll(genPackageList);				
		}
				
		// Add used gen package: AUTOSAR STUB package
		IResource autosar41GenModel = folder.findMember(AUTOSAR_STUB_GENMODEL);		
		if (autosar41GenModel != null && autosar41GenModel instanceof IFile && autosar41GenModel.exists()) {
			UsedGenModel usedAutosar41GenModel = new UsedGenModel();
			usedAutosar41GenModel.setFile((IFile) autosar41GenModel);
			List<GenPackage> genPackageList = usedAutosar41GenModel.loadRootGenPackage(resourceSet);
			if(genPackageList!= null){
				for(GenPackage genPackage : genPackageList){
					logger.info("AUTOSAR STUB genPackage = " + genPackage.getPackageName());
				}
			}
			genModel.getUsedGenPackages().addAll(genPackageList);
		}
			
	return genModel;
	}

	@Override
	protected void adjustGenPackage(GenPackage genPackage) {

		// Leave resource/resource factory generation enabled for root package only;
		// disable it for all sub packages
		if (genPackage.eContainer() != genPackage.getGenModel()) {
			genPackage.setResource(GenResourceKind.NONE_LITERAL);
			genPackage.setFileExtensions("");
		} 
		else {
				genPackage.setResource(GenResourceKind.XMI_LITERAL);				
				genPackage.setFileExtensions(fileExtensions);
				if (this.rootPackageContentTypeId != null) {
					genPackage.setContentTypeIdentifier(this.rootPackageContentTypeId);
				}
				if(this.rootPackageBasePackage != null){
					genPackage.setBasePackage(this.rootPackageBasePackage);
				}
		}

		// Package Suffixes section
		genPackage.setProviderPackageSuffix(IConstants.EDIT + "." + IConstants.PROVIDER_PACKAGE_SUFFIX);

		// Adjust sub Package settings
		for (GenPackage subGenPackage : genPackage.getNestedGenPackages()) {
			adjustGenPackage(subGenPackage);
		}
	}

	@Override
	protected GenModel setModelAndEditDirectory(GenModel genModel){
		// Model & Model Class Defaults sections
		genModel.setModelDirectory("/" + modelProject + SAFEConstants.SRC_GEN_DIRECTORY);
			
		// Edit section
		genModel.setEditDirectory("/" + editProject + SAFEConstants.SRC_GEN_DIRECTORY);
				
		return genModel;
	}
}


