/**
 */
package org.safe.metamodel.safe10.util;

import java.util.List;

import org.eclipse.emf.ecore.EClass;
import org.eclipse.emf.ecore.EObject;

import org.safe.metamodel.safe10.AUTOSARRunnableEntitySequenceConstraint;
import org.safe.metamodel.safe10.AUTOSARSequenceConstraint;
import org.safe.metamodel.safe10.AbstractErrorBehavior;
import org.safe.metamodel.safe10.AbstractQuantifiableSafetyRequirement;
import org.safe.metamodel.safe10.AbstractReference;
import org.safe.metamodel.safe10.AbstractSafetyRequirement;
import org.safe.metamodel.safe10.Actor;
import org.safe.metamodel.safe10.ActuatorError;
import org.safe.metamodel.safe10.ActuatorErrorDetection;
import org.safe.metamodel.safe10.ActuatorMonitor;
import org.safe.metamodel.safe10.AlivenessCheckpointTooEarly;
import org.safe.metamodel.safe10.AlivenessCheckpointTooLate;
import org.safe.metamodel.safe10.AlivenessCheckpointTooOften;
import org.safe.metamodel.safe10.AlivenessMonitor;
import org.safe.metamodel.safe10.AllocatableElement;
import org.safe.metamodel.safe10.AllocationTargets;
import org.safe.metamodel.safe10.AnalysisReport;
import org.safe.metamodel.safe10.Application;
import org.safe.metamodel.safe10.Assumption;
import org.safe.metamodel.safe10.AutosarAbstractComponentInstanceRef;
import org.safe.metamodel.safe10.AutosarAbstractPortInComponentInstanceRef;
import org.safe.metamodel.safe10.AutosarActuatorMonitor;
import org.safe.metamodel.safe10.AutosarAlivenessMonitor;
import org.safe.metamodel.safe10.AutosarCRC;
import org.safe.metamodel.safe10.AutosarCheckPoint;
import org.safe.metamodel.safe10.AutosarClientServerOperationInstanceRef;
import org.safe.metamodel.safe10.AutosarComparison;
import org.safe.metamodel.safe10.AutosarComparisonParam;
import org.safe.metamodel.safe10.AutosarComponentInCompositionInstanceRef;
import org.safe.metamodel.safe10.AutosarContext;
import org.safe.metamodel.safe10.AutosarContextRangeCheck;
import org.safe.metamodel.safe10.AutosarEvaluationFunction;
import org.safe.metamodel.safe10.AutosarGradientCheck;
import org.safe.metamodel.safe10.AutosarHardwareSafetyExtension;
import org.safe.metamodel.safe10.AutosarInstanceRef;
import org.safe.metamodel.safe10.AutosarModeInPortFromComponentInCompositionInstanceRef;
import org.safe.metamodel.safe10.AutosarPortInCompositionInstanceRef;
import org.safe.metamodel.safe10.AutosarReference;
import org.safe.metamodel.safe10.AutosarSafetyExtension;
import org.safe.metamodel.safe10.AutosarSystemSafetyExtension;
import org.safe.metamodel.safe10.AutosarUndefinedInstanceRef;
import org.safe.metamodel.safe10.AutosarVariableDataPrototypeInstanceRef;
import org.safe.metamodel.safe10.AutosarVfbSafetyExtension;
import org.safe.metamodel.safe10.Avoid;
import org.safe.metamodel.safe10.BooleanConfigParameterValue;
import org.safe.metamodel.safe10.CHROMOSOMEHealthMonitorNotification;
import org.safe.metamodel.safe10.CHROMOSOMEReference;
import org.safe.metamodel.safe10.CRC;
import org.safe.metamodel.safe10.CRCConfig;
import org.safe.metamodel.safe10.CRCErrorDetection;
import org.safe.metamodel.safe10.CRCFailed;
import org.safe.metamodel.safe10.CheckPoint;
import org.safe.metamodel.safe10.ChromosomeApplicationHealthMonitor;
import org.safe.metamodel.safe10.ChromosomeApplicationSafetyExtension;
import org.safe.metamodel.safe10.ChromosomeComparison;
import org.safe.metamodel.safe10.ChromosomeComparisonParameter;
import org.safe.metamodel.safe10.ChromosomeComponentModeCondition;
import org.safe.metamodel.safe10.ChromosomeCpuSelfTest;
import org.safe.metamodel.safe10.ChromosomeErrorEventCondition;
import org.safe.metamodel.safe10.ChromosomeErrorHandler;
import org.safe.metamodel.safe10.ChromosomeHealthMonitor;
import org.safe.metamodel.safe10.ChromosomeHeartbeatReceiver;
import org.safe.metamodel.safe10.ChromosomeHeartbeatSender;
import org.safe.metamodel.safe10.ChromosomeMemoryTest;
import org.safe.metamodel.safe10.ChromosomeNodeHealthMonitor;
import org.safe.metamodel.safe10.ChromosomeSafeExtension;
import org.safe.metamodel.safe10.ChromosomeSystemSafetyExtension;
import org.safe.metamodel.safe10.ChromosomeVoter;
import org.safe.metamodel.safe10.ChromosomeVoterParameter;
import org.safe.metamodel.safe10.CodeGenerationConfiguration;
import org.safe.metamodel.safe10.Comparison;
import org.safe.metamodel.safe10.ComparisonDetection;
import org.safe.metamodel.safe10.ComparisonFalse;
import org.safe.metamodel.safe10.ComparisonParameter;
import org.safe.metamodel.safe10.ComparisonTrue;
import org.safe.metamodel.safe10.Component;
import org.safe.metamodel.safe10.ComponentModeInstanceRef;
import org.safe.metamodel.safe10.ComponentPrototypeCRC;
import org.safe.metamodel.safe10.ConfigParameter;
import org.safe.metamodel.safe10.ConfigParameterValue;
import org.safe.metamodel.safe10.ConstantComparisonParameter;
import org.safe.metamodel.safe10.Context;
import org.safe.metamodel.safe10.ContextParameter;
import org.safe.metamodel.safe10.ContextRangeCheck;
import org.safe.metamodel.safe10.ContextRangeCheckDetection;
import org.safe.metamodel.safe10.ControlBlock;
import org.safe.metamodel.safe10.ControlFlowError;
import org.safe.metamodel.safe10.ControlFlowErrorDetection;
import org.safe.metamodel.safe10.ControlFlowMonitor;
import org.safe.metamodel.safe10.ControllabilityReference;
import org.safe.metamodel.safe10.CpuSelfTest;
import org.safe.metamodel.safe10.CpuSelfTestConfig;
import org.safe.metamodel.safe10.CpuSelfTestDetection;
import org.safe.metamodel.safe10.CpuSelfTestFailed;
import org.safe.metamodel.safe10.DesignLevelSafetyExtension;
import org.safe.metamodel.safe10.DesignSpecification;
import org.safe.metamodel.safe10.Detect;
import org.safe.metamodel.safe10.EMPAnalysis;
import org.safe.metamodel.safe10.EMPBswModule;
import org.safe.metamodel.safe10.EMPDesign;
import org.safe.metamodel.safe10.EMPHwComponent;
import org.safe.metamodel.safe10.EMPReference;
import org.safe.metamodel.safe10.EMPSwComponent;
import org.safe.metamodel.safe10.EMTypeAnalysis;
import org.safe.metamodel.safe10.EMTypeApplicationEnvironment;
import org.safe.metamodel.safe10.EMTypeBswModule;
import org.safe.metamodel.safe10.EMTypeDesign;
import org.safe.metamodel.safe10.EMTypeHwComponent;
import org.safe.metamodel.safe10.EMTypeSwComponent;
import org.safe.metamodel.safe10.EastADLErrorBehavior;
import org.safe.metamodel.safe10.EastAdlReference;
import org.safe.metamodel.safe10.ErrorBehaviorMapping;
import org.safe.metamodel.safe10.ErrorModel;
import org.safe.metamodel.safe10.ErrorModelInstanceRef;
import org.safe.metamodel.safe10.ErrorModelMapping;
import org.safe.metamodel.safe10.ErrorModelPrototype;
import org.safe.metamodel.safe10.ErrorModelPrototype_analysisFunctionTarget;
import org.safe.metamodel.safe10.ErrorModelPrototype_designFunctionTarget;
import org.safe.metamodel.safe10.ErrorModelPrototype_hwTarget;
import org.safe.metamodel.safe10.ErrorModelType;
import org.safe.metamodel.safe10.EvaluationFunction;
import org.safe.metamodel.safe10.FMEAReport;
import org.safe.metamodel.safe10.FailureLogicFormula;
import org.safe.metamodel.safe10.FailureRate;
import org.safe.metamodel.safe10.FaultFailurePort_functionTarget;
import org.safe.metamodel.safe10.FaultFailurePort_hwPinTarget;
import org.safe.metamodel.safe10.FaultFailurePort_hwPortTarget;
import org.safe.metamodel.safe10.FaultFailurePropagationLink;
import org.safe.metamodel.safe10.FieldTestProtocol;
import org.safe.metamodel.safe10.Filter;
import org.safe.metamodel.safe10.FilterBasedHandling;
import org.safe.metamodel.safe10.FilterError;
import org.safe.metamodel.safe10.FilterExpression;
import org.safe.metamodel.safe10.FilterParameter;
import org.safe.metamodel.safe10.FloatConfigParameterValue;
import org.safe.metamodel.safe10.FormulaDocumentation;
import org.safe.metamodel.safe10.FormulaExpression;
import org.safe.metamodel.safe10.FunctionalSafetyExtension;
import org.safe.metamodel.safe10.FunctionalSafetyRequirement;
import org.safe.metamodel.safe10.Goal;
import org.safe.metamodel.safe10.GradientCheck;
import org.safe.metamodel.safe10.GradientCheckDetection;
import org.safe.metamodel.safe10.GradientTooHigh;
import org.safe.metamodel.safe10.GradientTooLow;
import org.safe.metamodel.safe10.HWArchitecturalMetrics;
import org.safe.metamodel.safe10.HWComponentPrototypeScope;
import org.safe.metamodel.safe10.HWComponentQuantifiedFMFromPart;
import org.safe.metamodel.safe10.HWElementFailureRateClass;
import org.safe.metamodel.safe10.HWElementPrototypeScope;
import org.safe.metamodel.safe10.HWElementScopeInstanceRef;
import org.safe.metamodel.safe10.HWFMSingleContribution;
import org.safe.metamodel.safe10.HWFMSingleContributionFormula;
import org.safe.metamodel.safe10.HWFailureClassContainer;
import org.safe.metamodel.safe10.HWFailureClassContributionFormula;
import org.safe.metamodel.safe10.HWFailureMode;
import org.safe.metamodel.safe10.HWFailureRate;
import org.safe.metamodel.safe10.HWFault;
import org.safe.metamodel.safe10.HWLambdaPartFormula;
import org.safe.metamodel.safe10.HWLatentFaultMetric;
import org.safe.metamodel.safe10.HWLatentFaultMetricFormula;
import org.safe.metamodel.safe10.HWPMHF;
import org.safe.metamodel.safe10.HWPMHFFormula;
import org.safe.metamodel.safe10.HWPartFailure;
import org.safe.metamodel.safe10.HWPartFailureAnalysis;
import org.safe.metamodel.safe10.HWPartFailureMode;
import org.safe.metamodel.safe10.HWPartFailureRate;
import org.safe.metamodel.safe10.HWProbabilisticValue;
import org.safe.metamodel.safe10.HWQuantitativeFailureAnalysis;
import org.safe.metamodel.safe10.HWSinglePointFaultMetric;
import org.safe.metamodel.safe10.HWSinglePointFaultMetricFormula;
import org.safe.metamodel.safe10.Handle;
import org.safe.metamodel.safe10.HardwareComponentFailure;
import org.safe.metamodel.safe10.HardwareFailureAnalysis;
import org.safe.metamodel.safe10.HardwareSafetyExtension;
import org.safe.metamodel.safe10.HardwareSafetyRequirement;
import org.safe.metamodel.safe10.HardwareSoftwareInterfaceElement;
import org.safe.metamodel.safe10.HardwareSoftwareInterfaceSpecification;
import org.safe.metamodel.safe10.Hazard;
import org.safe.metamodel.safe10.HazardandRiskSafetyExtension;
import org.safe.metamodel.safe10.HazardousEvent;
import org.safe.metamodel.safe10.HealthMonitor;
import org.safe.metamodel.safe10.HealthMonitorErrorCondition;
import org.safe.metamodel.safe10.HealthMonitoring;
import org.safe.metamodel.safe10.HeartBeatDeadlineMissed;
import org.safe.metamodel.safe10.HeartBeatDetection;
import org.safe.metamodel.safe10.Heartbeat;
import org.safe.metamodel.safe10.HeartbeatConfig;
import org.safe.metamodel.safe10.HeartbeatReceiver;
import org.safe.metamodel.safe10.HeartbeatSender;
import org.safe.metamodel.safe10.HwComponentScopeInstanceRef;
import org.safe.metamodel.safe10.Identifiable;
import org.safe.metamodel.safe10.IdentifierConfigParameterValue;
import org.safe.metamodel.safe10.ImplementationSafetyExtension;
import org.safe.metamodel.safe10.InputBlock;
import org.safe.metamodel.safe10.IntegerConfigParameterValue;
import org.safe.metamodel.safe10.InterfaceCRC;
import org.safe.metamodel.safe10.Item;
import org.safe.metamodel.safe10.ItemFunctionDescription;
import org.safe.metamodel.safe10.Justification;
import org.safe.metamodel.safe10.MFPBswPort;
import org.safe.metamodel.safe10.MFPFunctionPort;
import org.safe.metamodel.safe10.MFPHardwarePin;
import org.safe.metamodel.safe10.MFPHardwarePort;
import org.safe.metamodel.safe10.MFPOperation;
import org.safe.metamodel.safe10.MFPSwcPort;
import org.safe.metamodel.safe10.MFPVariable;
import org.safe.metamodel.safe10.MTComposite;
import org.safe.metamodel.safe10.MTCompositeElementPrototype;
import org.safe.metamodel.safe10.MTPrimitive;
import org.safe.metamodel.safe10.MalfunctionInstanceRef;
import org.safe.metamodel.safe10.MalfunctionMapping;
import org.safe.metamodel.safe10.MalfunctionPrototype;
import org.safe.metamodel.safe10.MalfunctionType;
import org.safe.metamodel.safe10.MemoryRange;
import org.safe.metamodel.safe10.MemorySelfTest;
import org.safe.metamodel.safe10.MemorySelfTestConfig;
import org.safe.metamodel.safe10.MemorySelfTestFailed;
import org.safe.metamodel.safe10.MemorySelfTesting;
import org.safe.metamodel.safe10.MultiLevelSafetyExtension;
import org.safe.metamodel.safe10.NativeErrorBehavior;
import org.safe.metamodel.safe10.Node;
import org.safe.metamodel.safe10.OperatingMode;
import org.safe.metamodel.safe10.OperationBlock;
import org.safe.metamodel.safe10.OperationalSituation;
import org.safe.metamodel.safe10.OutputBlock;
import org.safe.metamodel.safe10.PackageableElement;
import org.safe.metamodel.safe10.QuantifiedDiagnosticCoverageProperty;
import org.safe.metamodel.safe10.QuantifiedHWProperty;
import org.safe.metamodel.safe10.QuantitativeErrorModel;
import org.safe.metamodel.safe10.RangeCheckContext;
import org.safe.metamodel.safe10.Referrable;
import org.safe.metamodel.safe10.RequirementsLink;
import org.safe.metamodel.safe10.RequirementsReleationship;
import org.safe.metamodel.safe10.Restrictable;
import org.safe.metamodel.safe10.Restriction;
import org.safe.metamodel.safe10.RiskDescription;
import org.safe.metamodel.safe10.RunnableEntitySequenceElement;
import org.safe.metamodel.safe10.SAFE;
import org.safe.metamodel.safe10.SAFEElement;
import org.safe.metamodel.safe10.SAFEPackage;
import org.safe.metamodel.safe10.Safe10Package;
import org.safe.metamodel.safe10.SafeState;
import org.safe.metamodel.safe10.SafetyCase;
import org.safe.metamodel.safe10.SafetyConcept;
import org.safe.metamodel.safe10.SafetyExtension;
import org.safe.metamodel.safe10.Satisfy;
import org.safe.metamodel.safe10.SequenceBlock;
import org.safe.metamodel.safe10.SingleLevelSafetyExtension;
import org.safe.metamodel.safe10.Situation;
import org.safe.metamodel.safe10.SoftwareAlivenessDetection;
import org.safe.metamodel.safe10.SoftwareSafetyExtension;
import org.safe.metamodel.safe10.SoftwareSafetyRequirement;
import org.safe.metamodel.safe10.Solution;
import org.safe.metamodel.safe10.Strategy;
import org.safe.metamodel.safe10.StringConfigParameterValue;
import org.safe.metamodel.safe10.Tactic;
import org.safe.metamodel.safe10.TechnicalSafetyExtension;
import org.safe.metamodel.safe10.TechnicalSafetyRequirement;
import org.safe.metamodel.safe10.TestProtocol;
import org.safe.metamodel.safe10.Topic;
import org.safe.metamodel.safe10.TraceableSpecification;
import org.safe.metamodel.safe10.UnitTestProtocol;
import org.safe.metamodel.safe10.ValueAboveRange;
import org.safe.metamodel.safe10.ValueBelowRange;
import org.safe.metamodel.safe10.Variant;
import org.safe.metamodel.safe10.Verify;
import org.safe.metamodel.safe10.Voter;
import org.safe.metamodel.safe10.VoterConfig;
import org.safe.metamodel.safe10.VoterNoConsensus;
import org.safe.metamodel.safe10.VoterParameter;
import org.safe.metamodel.safe10.VoterValueMismatch;
import org.safe.metamodel.safe10.Voting;
import org.safe.metamodel.safe10.WarningAndDegradation;
import org.safe.metamodel.safe10.WarningAndDegradationHandle;

/**
 * <!-- begin-user-doc -->
 * The <b>Switch</b> for the model's inheritance hierarchy.
 * It supports the call {@link #doSwitch(EObject) doSwitch(object)}
 * to invoke the <code>caseXXX</code> method for each class of the model,
 * starting with the actual class of the object
 * and proceeding up the inheritance hierarchy
 * until a non-null result is returned,
 * which is the result of the switch.
 * <!-- end-user-doc -->
 * @see org.safe.metamodel.safe10.Safe10Package
 * @generated
 */
public class Safe10Switch<T>
{
  /**
   * The cached model package
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected static Safe10Package modelPackage;

  /**
   * Creates an instance of the switch.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public Safe10Switch()
  {
    if (modelPackage == null)
    {
      modelPackage = Safe10Package.eINSTANCE;
    }
  }

  /**
   * Calls <code>caseXXX</code> for each class of the model until one returns a non null result; it yields that result.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return the first non-null result returned by a <code>caseXXX</code> call.
   * @generated
   */
  public T doSwitch(EObject theEObject)
  {
    return doSwitch(theEObject.eClass(), theEObject);
  }

  /**
   * Calls <code>caseXXX</code> for each class of the model until one returns a non null result; it yields that result.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return the first non-null result returned by a <code>caseXXX</code> call.
   * @generated
   */
  protected T doSwitch(EClass theEClass, EObject theEObject)
  {
    if (theEClass.eContainer() == modelPackage)
    {
      return doSwitch(theEClass.getClassifierID(), theEObject);
    }
    else
    {
      List<EClass> eSuperTypes = theEClass.getESuperTypes();
      return
        eSuperTypes.isEmpty() ?
          defaultCase(theEObject) :
          doSwitch(eSuperTypes.get(0), theEObject);
    }
  }

  /**
   * Calls <code>caseXXX</code> for each class of the model until one returns a non null result; it yields that result.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return the first non-null result returned by a <code>caseXXX</code> call.
   * @generated
   */
  protected T doSwitch(int classifierID, EObject theEObject)
  {
    switch (classifierID)
    {
      case Safe10Package.FILTER_EXPRESSION:
      {
        FilterExpression filterExpression = (FilterExpression)theEObject;
        T result = caseFilterExpression(filterExpression);
        if (result == null) result = caseFormulaExpression(filterExpression);
        if (result == null) result = caseIdentifiable(filterExpression);
        if (result == null) result = caseReferrable(filterExpression);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.FORMULA_EXPRESSION:
      {
        FormulaExpression formulaExpression = (FormulaExpression)theEObject;
        T result = caseFormulaExpression(formulaExpression);
        if (result == null) result = caseIdentifiable(formulaExpression);
        if (result == null) result = caseReferrable(formulaExpression);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.ABSTRACT_REFERENCE:
      {
        AbstractReference abstractReference = (AbstractReference)theEObject;
        T result = caseAbstractReference(abstractReference);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.AUTOSAR_REFERENCE:
      {
        AutosarReference autosarReference = (AutosarReference)theEObject;
        T result = caseAutosarReference(autosarReference);
        if (result == null) result = caseAbstractReference(autosarReference);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CHROMOSOME_REFERENCE:
      {
        CHROMOSOMEReference chromosomeReference = (CHROMOSOMEReference)theEObject;
        T result = caseCHROMOSOMEReference(chromosomeReference);
        if (result == null) result = caseAbstractReference(chromosomeReference);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.EAST_ADL_REFERENCE:
      {
        EastAdlReference eastAdlReference = (EastAdlReference)theEObject;
        T result = caseEastAdlReference(eastAdlReference);
        if (result == null) result = caseAbstractReference(eastAdlReference);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.APPLICATION:
      {
        Application application = (Application)theEObject;
        T result = caseApplication(application);
        if (result == null) result = caseCHROMOSOMEReference(application);
        if (result == null) result = caseAbstractReference(application);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.COMPONENT:
      {
        Component component = (Component)theEObject;
        T result = caseComponent(component);
        if (result == null) result = caseCHROMOSOMEReference(component);
        if (result == null) result = caseAbstractReference(component);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.COMPONENT_MODE_INSTANCE_REF:
      {
        ComponentModeInstanceRef componentModeInstanceRef = (ComponentModeInstanceRef)theEObject;
        T result = caseComponentModeInstanceRef(componentModeInstanceRef);
        if (result == null) result = caseCHROMOSOMEReference(componentModeInstanceRef);
        if (result == null) result = caseAbstractReference(componentModeInstanceRef);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.NODE:
      {
        Node node = (Node)theEObject;
        T result = caseNode(node);
        if (result == null) result = caseCHROMOSOMEReference(node);
        if (result == null) result = caseAbstractReference(node);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.SYSTEM:
      {
        org.safe.metamodel.safe10.System system = (org.safe.metamodel.safe10.System)theEObject;
        T result = caseSystem(system);
        if (result == null) result = caseCHROMOSOMEReference(system);
        if (result == null) result = caseAbstractReference(system);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.TOPIC:
      {
        Topic topic = (Topic)theEObject;
        T result = caseTopic(topic);
        if (result == null) result = caseCHROMOSOMEReference(topic);
        if (result == null) result = caseAbstractReference(topic);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.MULTI_LEVEL_SAFETY_EXTENSION:
      {
        MultiLevelSafetyExtension multiLevelSafetyExtension = (MultiLevelSafetyExtension)theEObject;
        T result = caseMultiLevelSafetyExtension(multiLevelSafetyExtension);
        if (result == null) result = caseSafetyExtension(multiLevelSafetyExtension);
        if (result == null) result = caseSAFEElement(multiLevelSafetyExtension);
        if (result == null) result = casePackageableElement(multiLevelSafetyExtension);
        if (result == null) result = caseIdentifiable(multiLevelSafetyExtension);
        if (result == null) result = caseReferrable(multiLevelSafetyExtension);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.SAFETY_EXTENSION:
      {
        SafetyExtension safetyExtension = (SafetyExtension)theEObject;
        T result = caseSafetyExtension(safetyExtension);
        if (result == null) result = caseSAFEElement(safetyExtension);
        if (result == null) result = casePackageableElement(safetyExtension);
        if (result == null) result = caseIdentifiable(safetyExtension);
        if (result == null) result = caseReferrable(safetyExtension);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.SINGLE_LEVEL_SAFETY_EXTENSION:
      {
        SingleLevelSafetyExtension singleLevelSafetyExtension = (SingleLevelSafetyExtension)theEObject;
        T result = caseSingleLevelSafetyExtension(singleLevelSafetyExtension);
        if (result == null) result = caseSafetyExtension(singleLevelSafetyExtension);
        if (result == null) result = caseSAFEElement(singleLevelSafetyExtension);
        if (result == null) result = casePackageableElement(singleLevelSafetyExtension);
        if (result == null) result = caseIdentifiable(singleLevelSafetyExtension);
        if (result == null) result = caseReferrable(singleLevelSafetyExtension);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.FUNCTIONAL_SAFETY_EXTENSION:
      {
        FunctionalSafetyExtension functionalSafetyExtension = (FunctionalSafetyExtension)theEObject;
        T result = caseFunctionalSafetyExtension(functionalSafetyExtension);
        if (result == null) result = caseSingleLevelSafetyExtension(functionalSafetyExtension);
        if (result == null) result = caseSafetyExtension(functionalSafetyExtension);
        if (result == null) result = caseSAFEElement(functionalSafetyExtension);
        if (result == null) result = casePackageableElement(functionalSafetyExtension);
        if (result == null) result = caseIdentifiable(functionalSafetyExtension);
        if (result == null) result = caseReferrable(functionalSafetyExtension);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HAZARDAND_RISK_SAFETY_EXTENSION:
      {
        HazardandRiskSafetyExtension hazardandRiskSafetyExtension = (HazardandRiskSafetyExtension)theEObject;
        T result = caseHazardandRiskSafetyExtension(hazardandRiskSafetyExtension);
        if (result == null) result = caseSingleLevelSafetyExtension(hazardandRiskSafetyExtension);
        if (result == null) result = caseSafetyExtension(hazardandRiskSafetyExtension);
        if (result == null) result = caseSAFEElement(hazardandRiskSafetyExtension);
        if (result == null) result = casePackageableElement(hazardandRiskSafetyExtension);
        if (result == null) result = caseIdentifiable(hazardandRiskSafetyExtension);
        if (result == null) result = caseReferrable(hazardandRiskSafetyExtension);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.AUTOSAR_HARDWARE_SAFETY_EXTENSION:
      {
        AutosarHardwareSafetyExtension autosarHardwareSafetyExtension = (AutosarHardwareSafetyExtension)theEObject;
        T result = caseAutosarHardwareSafetyExtension(autosarHardwareSafetyExtension);
        if (result == null) result = caseAutosarSafetyExtension(autosarHardwareSafetyExtension);
        if (result == null) result = caseImplementationSafetyExtension(autosarHardwareSafetyExtension);
        if (result == null) result = caseSingleLevelSafetyExtension(autosarHardwareSafetyExtension);
        if (result == null) result = caseSafetyExtension(autosarHardwareSafetyExtension);
        if (result == null) result = caseSAFEElement(autosarHardwareSafetyExtension);
        if (result == null) result = casePackageableElement(autosarHardwareSafetyExtension);
        if (result == null) result = caseIdentifiable(autosarHardwareSafetyExtension);
        if (result == null) result = caseReferrable(autosarHardwareSafetyExtension);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.AUTOSAR_SAFETY_EXTENSION:
      {
        AutosarSafetyExtension autosarSafetyExtension = (AutosarSafetyExtension)theEObject;
        T result = caseAutosarSafetyExtension(autosarSafetyExtension);
        if (result == null) result = caseImplementationSafetyExtension(autosarSafetyExtension);
        if (result == null) result = caseSingleLevelSafetyExtension(autosarSafetyExtension);
        if (result == null) result = caseSafetyExtension(autosarSafetyExtension);
        if (result == null) result = caseSAFEElement(autosarSafetyExtension);
        if (result == null) result = casePackageableElement(autosarSafetyExtension);
        if (result == null) result = caseIdentifiable(autosarSafetyExtension);
        if (result == null) result = caseReferrable(autosarSafetyExtension);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.AUTOSAR_SYSTEM_SAFETY_EXTENSION:
      {
        AutosarSystemSafetyExtension autosarSystemSafetyExtension = (AutosarSystemSafetyExtension)theEObject;
        T result = caseAutosarSystemSafetyExtension(autosarSystemSafetyExtension);
        if (result == null) result = caseAutosarSafetyExtension(autosarSystemSafetyExtension);
        if (result == null) result = caseImplementationSafetyExtension(autosarSystemSafetyExtension);
        if (result == null) result = caseSingleLevelSafetyExtension(autosarSystemSafetyExtension);
        if (result == null) result = caseSafetyExtension(autosarSystemSafetyExtension);
        if (result == null) result = caseSAFEElement(autosarSystemSafetyExtension);
        if (result == null) result = casePackageableElement(autosarSystemSafetyExtension);
        if (result == null) result = caseIdentifiable(autosarSystemSafetyExtension);
        if (result == null) result = caseReferrable(autosarSystemSafetyExtension);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.AUTOSAR_VFB_SAFETY_EXTENSION:
      {
        AutosarVfbSafetyExtension autosarVfbSafetyExtension = (AutosarVfbSafetyExtension)theEObject;
        T result = caseAutosarVfbSafetyExtension(autosarVfbSafetyExtension);
        if (result == null) result = caseAutosarSafetyExtension(autosarVfbSafetyExtension);
        if (result == null) result = caseImplementationSafetyExtension(autosarVfbSafetyExtension);
        if (result == null) result = caseSingleLevelSafetyExtension(autosarVfbSafetyExtension);
        if (result == null) result = caseSafetyExtension(autosarVfbSafetyExtension);
        if (result == null) result = caseSAFEElement(autosarVfbSafetyExtension);
        if (result == null) result = casePackageableElement(autosarVfbSafetyExtension);
        if (result == null) result = caseIdentifiable(autosarVfbSafetyExtension);
        if (result == null) result = caseReferrable(autosarVfbSafetyExtension);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CHROMOSOME_APPLICATION_SAFETY_EXTENSION:
      {
        ChromosomeApplicationSafetyExtension chromosomeApplicationSafetyExtension = (ChromosomeApplicationSafetyExtension)theEObject;
        T result = caseChromosomeApplicationSafetyExtension(chromosomeApplicationSafetyExtension);
        if (result == null) result = caseChromosomeSafeExtension(chromosomeApplicationSafetyExtension);
        if (result == null) result = caseImplementationSafetyExtension(chromosomeApplicationSafetyExtension);
        if (result == null) result = caseSingleLevelSafetyExtension(chromosomeApplicationSafetyExtension);
        if (result == null) result = caseSafetyExtension(chromosomeApplicationSafetyExtension);
        if (result == null) result = caseSAFEElement(chromosomeApplicationSafetyExtension);
        if (result == null) result = casePackageableElement(chromosomeApplicationSafetyExtension);
        if (result == null) result = caseIdentifiable(chromosomeApplicationSafetyExtension);
        if (result == null) result = caseReferrable(chromosomeApplicationSafetyExtension);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CHROMOSOME_SAFE_EXTENSION:
      {
        ChromosomeSafeExtension chromosomeSafeExtension = (ChromosomeSafeExtension)theEObject;
        T result = caseChromosomeSafeExtension(chromosomeSafeExtension);
        if (result == null) result = caseImplementationSafetyExtension(chromosomeSafeExtension);
        if (result == null) result = caseSingleLevelSafetyExtension(chromosomeSafeExtension);
        if (result == null) result = caseSafetyExtension(chromosomeSafeExtension);
        if (result == null) result = caseSAFEElement(chromosomeSafeExtension);
        if (result == null) result = casePackageableElement(chromosomeSafeExtension);
        if (result == null) result = caseIdentifiable(chromosomeSafeExtension);
        if (result == null) result = caseReferrable(chromosomeSafeExtension);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CHROMOSOME_SYSTEM_SAFETY_EXTENSION:
      {
        ChromosomeSystemSafetyExtension chromosomeSystemSafetyExtension = (ChromosomeSystemSafetyExtension)theEObject;
        T result = caseChromosomeSystemSafetyExtension(chromosomeSystemSafetyExtension);
        if (result == null) result = caseChromosomeSafeExtension(chromosomeSystemSafetyExtension);
        if (result == null) result = caseImplementationSafetyExtension(chromosomeSystemSafetyExtension);
        if (result == null) result = caseSingleLevelSafetyExtension(chromosomeSystemSafetyExtension);
        if (result == null) result = caseSafetyExtension(chromosomeSystemSafetyExtension);
        if (result == null) result = caseSAFEElement(chromosomeSystemSafetyExtension);
        if (result == null) result = casePackageableElement(chromosomeSystemSafetyExtension);
        if (result == null) result = caseIdentifiable(chromosomeSystemSafetyExtension);
        if (result == null) result = caseReferrable(chromosomeSystemSafetyExtension);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.IMPLEMENTATION_SAFETY_EXTENSION:
      {
        ImplementationSafetyExtension implementationSafetyExtension = (ImplementationSafetyExtension)theEObject;
        T result = caseImplementationSafetyExtension(implementationSafetyExtension);
        if (result == null) result = caseSingleLevelSafetyExtension(implementationSafetyExtension);
        if (result == null) result = caseSafetyExtension(implementationSafetyExtension);
        if (result == null) result = caseSAFEElement(implementationSafetyExtension);
        if (result == null) result = casePackageableElement(implementationSafetyExtension);
        if (result == null) result = caseIdentifiable(implementationSafetyExtension);
        if (result == null) result = caseReferrable(implementationSafetyExtension);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.DESIGN_LEVEL_SAFETY_EXTENSION:
      {
        DesignLevelSafetyExtension designLevelSafetyExtension = (DesignLevelSafetyExtension)theEObject;
        T result = caseDesignLevelSafetyExtension(designLevelSafetyExtension);
        if (result == null) result = caseTechnicalSafetyExtension(designLevelSafetyExtension);
        if (result == null) result = caseSingleLevelSafetyExtension(designLevelSafetyExtension);
        if (result == null) result = caseSafetyExtension(designLevelSafetyExtension);
        if (result == null) result = caseSAFEElement(designLevelSafetyExtension);
        if (result == null) result = casePackageableElement(designLevelSafetyExtension);
        if (result == null) result = caseIdentifiable(designLevelSafetyExtension);
        if (result == null) result = caseReferrable(designLevelSafetyExtension);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HARDWARE_SAFETY_EXTENSION:
      {
        HardwareSafetyExtension hardwareSafetyExtension = (HardwareSafetyExtension)theEObject;
        T result = caseHardwareSafetyExtension(hardwareSafetyExtension);
        if (result == null) result = caseTechnicalSafetyExtension(hardwareSafetyExtension);
        if (result == null) result = caseSingleLevelSafetyExtension(hardwareSafetyExtension);
        if (result == null) result = caseSafetyExtension(hardwareSafetyExtension);
        if (result == null) result = caseSAFEElement(hardwareSafetyExtension);
        if (result == null) result = casePackageableElement(hardwareSafetyExtension);
        if (result == null) result = caseIdentifiable(hardwareSafetyExtension);
        if (result == null) result = caseReferrable(hardwareSafetyExtension);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.SOFTWARE_SAFETY_EXTENSION:
      {
        SoftwareSafetyExtension softwareSafetyExtension = (SoftwareSafetyExtension)theEObject;
        T result = caseSoftwareSafetyExtension(softwareSafetyExtension);
        if (result == null) result = caseTechnicalSafetyExtension(softwareSafetyExtension);
        if (result == null) result = caseSingleLevelSafetyExtension(softwareSafetyExtension);
        if (result == null) result = caseSafetyExtension(softwareSafetyExtension);
        if (result == null) result = caseSAFEElement(softwareSafetyExtension);
        if (result == null) result = casePackageableElement(softwareSafetyExtension);
        if (result == null) result = caseIdentifiable(softwareSafetyExtension);
        if (result == null) result = caseReferrable(softwareSafetyExtension);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.TECHNICAL_SAFETY_EXTENSION:
      {
        TechnicalSafetyExtension technicalSafetyExtension = (TechnicalSafetyExtension)theEObject;
        T result = caseTechnicalSafetyExtension(technicalSafetyExtension);
        if (result == null) result = caseSingleLevelSafetyExtension(technicalSafetyExtension);
        if (result == null) result = caseSafetyExtension(technicalSafetyExtension);
        if (result == null) result = caseSAFEElement(technicalSafetyExtension);
        if (result == null) result = casePackageableElement(technicalSafetyExtension);
        if (result == null) result = caseIdentifiable(technicalSafetyExtension);
        if (result == null) result = caseReferrable(technicalSafetyExtension);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.PACKAGEABLE_ELEMENT:
      {
        PackageableElement packageableElement = (PackageableElement)theEObject;
        T result = casePackageableElement(packageableElement);
        if (result == null) result = caseIdentifiable(packageableElement);
        if (result == null) result = caseReferrable(packageableElement);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.REFERRABLE:
      {
        Referrable referrable = (Referrable)theEObject;
        T result = caseReferrable(referrable);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.SAFE:
      {
        SAFE safe = (SAFE)theEObject;
        T result = caseSAFE(safe);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.SAFE_ELEMENT:
      {
        SAFEElement safeElement = (SAFEElement)theEObject;
        T result = caseSAFEElement(safeElement);
        if (result == null) result = casePackageableElement(safeElement);
        if (result == null) result = caseIdentifiable(safeElement);
        if (result == null) result = caseReferrable(safeElement);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.SAFE_PACKAGE:
      {
        SAFEPackage safePackage = (SAFEPackage)theEObject;
        T result = caseSAFEPackage(safePackage);
        if (result == null) result = caseIdentifiable(safePackage);
        if (result == null) result = caseReferrable(safePackage);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.IDENTIFIABLE:
      {
        Identifiable identifiable = (Identifiable)theEObject;
        T result = caseIdentifiable(identifiable);
        if (result == null) result = caseReferrable(identifiable);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.AUTOSAR_ABSTRACT_COMPONENT_INSTANCE_REF:
      {
        AutosarAbstractComponentInstanceRef autosarAbstractComponentInstanceRef = (AutosarAbstractComponentInstanceRef)theEObject;
        T result = caseAutosarAbstractComponentInstanceRef(autosarAbstractComponentInstanceRef);
        if (result == null) result = caseAutosarInstanceRef(autosarAbstractComponentInstanceRef);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.AUTOSAR_ABSTRACT_PORT_IN_COMPONENT_INSTANCE_REF:
      {
        AutosarAbstractPortInComponentInstanceRef autosarAbstractPortInComponentInstanceRef = (AutosarAbstractPortInComponentInstanceRef)theEObject;
        T result = caseAutosarAbstractPortInComponentInstanceRef(autosarAbstractPortInComponentInstanceRef);
        if (result == null) result = caseAutosarAbstractComponentInstanceRef(autosarAbstractPortInComponentInstanceRef);
        if (result == null) result = caseAutosarInstanceRef(autosarAbstractPortInComponentInstanceRef);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.AUTOSAR_CLIENT_SERVER_OPERATION_INSTANCE_REF:
      {
        AutosarClientServerOperationInstanceRef autosarClientServerOperationInstanceRef = (AutosarClientServerOperationInstanceRef)theEObject;
        T result = caseAutosarClientServerOperationInstanceRef(autosarClientServerOperationInstanceRef);
        if (result == null) result = caseAutosarAbstractPortInComponentInstanceRef(autosarClientServerOperationInstanceRef);
        if (result == null) result = caseAutosarAbstractComponentInstanceRef(autosarClientServerOperationInstanceRef);
        if (result == null) result = caseAutosarInstanceRef(autosarClientServerOperationInstanceRef);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.AUTOSAR_COMPONENT_IN_COMPOSITION_INSTANCE_REF:
      {
        AutosarComponentInCompositionInstanceRef autosarComponentInCompositionInstanceRef = (AutosarComponentInCompositionInstanceRef)theEObject;
        T result = caseAutosarComponentInCompositionInstanceRef(autosarComponentInCompositionInstanceRef);
        if (result == null) result = caseAutosarAbstractComponentInstanceRef(autosarComponentInCompositionInstanceRef);
        if (result == null) result = caseAutosarInstanceRef(autosarComponentInCompositionInstanceRef);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.AUTOSAR_INSTANCE_REF:
      {
        AutosarInstanceRef autosarInstanceRef = (AutosarInstanceRef)theEObject;
        T result = caseAutosarInstanceRef(autosarInstanceRef);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.AUTOSAR_MODE_IN_PORT_FROM_COMPONENT_IN_COMPOSITION_INSTANCE_REF:
      {
        AutosarModeInPortFromComponentInCompositionInstanceRef autosarModeInPortFromComponentInCompositionInstanceRef = (AutosarModeInPortFromComponentInCompositionInstanceRef)theEObject;
        T result = caseAutosarModeInPortFromComponentInCompositionInstanceRef(autosarModeInPortFromComponentInCompositionInstanceRef);
        if (result == null) result = caseAutosarAbstractPortInComponentInstanceRef(autosarModeInPortFromComponentInCompositionInstanceRef);
        if (result == null) result = caseAutosarAbstractComponentInstanceRef(autosarModeInPortFromComponentInCompositionInstanceRef);
        if (result == null) result = caseAutosarInstanceRef(autosarModeInPortFromComponentInCompositionInstanceRef);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.AUTOSAR_PORT_IN_COMPOSITION_INSTANCE_REF:
      {
        AutosarPortInCompositionInstanceRef autosarPortInCompositionInstanceRef = (AutosarPortInCompositionInstanceRef)theEObject;
        T result = caseAutosarPortInCompositionInstanceRef(autosarPortInCompositionInstanceRef);
        if (result == null) result = caseAutosarAbstractComponentInstanceRef(autosarPortInCompositionInstanceRef);
        if (result == null) result = caseAutosarInstanceRef(autosarPortInCompositionInstanceRef);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.AUTOSAR_UNDEFINED_INSTANCE_REF:
      {
        AutosarUndefinedInstanceRef autosarUndefinedInstanceRef = (AutosarUndefinedInstanceRef)theEObject;
        T result = caseAutosarUndefinedInstanceRef(autosarUndefinedInstanceRef);
        if (result == null) result = caseAutosarInstanceRef(autosarUndefinedInstanceRef);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.AUTOSAR_VARIABLE_DATA_PROTOTYPE_INSTANCE_REF:
      {
        AutosarVariableDataPrototypeInstanceRef autosarVariableDataPrototypeInstanceRef = (AutosarVariableDataPrototypeInstanceRef)theEObject;
        T result = caseAutosarVariableDataPrototypeInstanceRef(autosarVariableDataPrototypeInstanceRef);
        if (result == null) result = caseAutosarAbstractPortInComponentInstanceRef(autosarVariableDataPrototypeInstanceRef);
        if (result == null) result = caseAutosarAbstractComponentInstanceRef(autosarVariableDataPrototypeInstanceRef);
        if (result == null) result = caseAutosarInstanceRef(autosarVariableDataPrototypeInstanceRef);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.RESTRICTABLE:
      {
        Restrictable restrictable = (Restrictable)theEObject;
        T result = caseRestrictable(restrictable);
        if (result == null) result = casePackageableElement(restrictable);
        if (result == null) result = caseIdentifiable(restrictable);
        if (result == null) result = caseReferrable(restrictable);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.RESTRICTION:
      {
        Restriction restriction = (Restriction)theEObject;
        T result = caseRestriction(restriction);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.VARIANT:
      {
        Variant variant = (Variant)theEObject;
        T result = caseVariant(variant);
        if (result == null) result = casePackageableElement(variant);
        if (result == null) result = caseIdentifiable(variant);
        if (result == null) result = caseReferrable(variant);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.ERROR_MODEL:
      {
        ErrorModel errorModel = (ErrorModel)theEObject;
        T result = caseErrorModel(errorModel);
        if (result == null) result = caseIdentifiable(errorModel);
        if (result == null) result = caseReferrable(errorModel);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.ERROR_MODEL_INSTANCE_REF:
      {
        ErrorModelInstanceRef errorModelInstanceRef = (ErrorModelInstanceRef)theEObject;
        T result = caseErrorModelInstanceRef(errorModelInstanceRef);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.ERROR_MODEL_PROTOTYPE_ANALYSIS_FUNCTION_TARGET:
      {
        ErrorModelPrototype_analysisFunctionTarget errorModelPrototype_analysisFunctionTarget = (ErrorModelPrototype_analysisFunctionTarget)theEObject;
        T result = caseErrorModelPrototype_analysisFunctionTarget(errorModelPrototype_analysisFunctionTarget);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.ERROR_MODEL_PROTOTYPE_DESIGN_FUNCTION_TARGET:
      {
        ErrorModelPrototype_designFunctionTarget errorModelPrototype_designFunctionTarget = (ErrorModelPrototype_designFunctionTarget)theEObject;
        T result = caseErrorModelPrototype_designFunctionTarget(errorModelPrototype_designFunctionTarget);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.ERROR_MODEL_PROTOTYPE_HW_TARGET:
      {
        ErrorModelPrototype_hwTarget errorModelPrototype_hwTarget = (ErrorModelPrototype_hwTarget)theEObject;
        T result = caseErrorModelPrototype_hwTarget(errorModelPrototype_hwTarget);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.FAULT_FAILURE_PORT_FUNCTION_TARGET:
      {
        FaultFailurePort_functionTarget faultFailurePort_functionTarget = (FaultFailurePort_functionTarget)theEObject;
        T result = caseFaultFailurePort_functionTarget(faultFailurePort_functionTarget);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.FAULT_FAILURE_PORT_HW_PIN_TARGET:
      {
        FaultFailurePort_hwPinTarget faultFailurePort_hwPinTarget = (FaultFailurePort_hwPinTarget)theEObject;
        T result = caseFaultFailurePort_hwPinTarget(faultFailurePort_hwPinTarget);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.FAULT_FAILURE_PORT_HW_PORT_TARGET:
      {
        FaultFailurePort_hwPortTarget faultFailurePort_hwPortTarget = (FaultFailurePort_hwPortTarget)theEObject;
        T result = caseFaultFailurePort_hwPortTarget(faultFailurePort_hwPortTarget);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.MALFUNCTION_INSTANCE_REF:
      {
        MalfunctionInstanceRef malfunctionInstanceRef = (MalfunctionInstanceRef)theEObject;
        T result = caseMalfunctionInstanceRef(malfunctionInstanceRef);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.ABSTRACT_ERROR_BEHAVIOR:
      {
        AbstractErrorBehavior abstractErrorBehavior = (AbstractErrorBehavior)theEObject;
        T result = caseAbstractErrorBehavior(abstractErrorBehavior);
        if (result == null) result = caseIdentifiable(abstractErrorBehavior);
        if (result == null) result = caseReferrable(abstractErrorBehavior);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.EAST_ADL_ERROR_BEHAVIOR:
      {
        EastADLErrorBehavior eastADLErrorBehavior = (EastADLErrorBehavior)theEObject;
        T result = caseEastADLErrorBehavior(eastADLErrorBehavior);
        if (result == null) result = caseAbstractErrorBehavior(eastADLErrorBehavior);
        if (result == null) result = caseIdentifiable(eastADLErrorBehavior);
        if (result == null) result = caseReferrable(eastADLErrorBehavior);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.FAILURE_LOGIC_FORMULA:
      {
        FailureLogicFormula failureLogicFormula = (FailureLogicFormula)theEObject;
        T result = caseFailureLogicFormula(failureLogicFormula);
        if (result == null) result = caseFormulaExpression(failureLogicFormula);
        if (result == null) result = caseIdentifiable(failureLogicFormula);
        if (result == null) result = caseReferrable(failureLogicFormula);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.NATIVE_ERROR_BEHAVIOR:
      {
        NativeErrorBehavior nativeErrorBehavior = (NativeErrorBehavior)theEObject;
        T result = caseNativeErrorBehavior(nativeErrorBehavior);
        if (result == null) result = caseAbstractErrorBehavior(nativeErrorBehavior);
        if (result == null) result = caseIdentifiable(nativeErrorBehavior);
        if (result == null) result = caseReferrable(nativeErrorBehavior);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.EMP_ANALYSIS:
      {
        EMPAnalysis empAnalysis = (EMPAnalysis)theEObject;
        T result = caseEMPAnalysis(empAnalysis);
        if (result == null) result = caseErrorModelPrototype(empAnalysis);
        if (result == null) result = caseIdentifiable(empAnalysis);
        if (result == null) result = caseReferrable(empAnalysis);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.EMP_BSW_MODULE:
      {
        EMPBswModule empBswModule = (EMPBswModule)theEObject;
        T result = caseEMPBswModule(empBswModule);
        if (result == null) result = caseErrorModelPrototype(empBswModule);
        if (result == null) result = caseIdentifiable(empBswModule);
        if (result == null) result = caseReferrable(empBswModule);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.EMP_DESIGN:
      {
        EMPDesign empDesign = (EMPDesign)theEObject;
        T result = caseEMPDesign(empDesign);
        if (result == null) result = caseErrorModelPrototype(empDesign);
        if (result == null) result = caseIdentifiable(empDesign);
        if (result == null) result = caseReferrable(empDesign);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.EMP_HW_COMPONENT:
      {
        EMPHwComponent empHwComponent = (EMPHwComponent)theEObject;
        T result = caseEMPHwComponent(empHwComponent);
        if (result == null) result = caseErrorModelPrototype(empHwComponent);
        if (result == null) result = caseIdentifiable(empHwComponent);
        if (result == null) result = caseReferrable(empHwComponent);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.EMP_REFERENCE:
      {
        EMPReference empReference = (EMPReference)theEObject;
        T result = caseEMPReference(empReference);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.EMP_SW_COMPONENT:
      {
        EMPSwComponent empSwComponent = (EMPSwComponent)theEObject;
        T result = caseEMPSwComponent(empSwComponent);
        if (result == null) result = caseErrorModelPrototype(empSwComponent);
        if (result == null) result = caseIdentifiable(empSwComponent);
        if (result == null) result = caseReferrable(empSwComponent);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.EM_TYPE_ANALYSIS:
      {
        EMTypeAnalysis emTypeAnalysis = (EMTypeAnalysis)theEObject;
        T result = caseEMTypeAnalysis(emTypeAnalysis);
        if (result == null) result = caseErrorModelType(emTypeAnalysis);
        if (result == null) result = caseTraceableSpecification(emTypeAnalysis);
        if (result == null) result = caseIdentifiable(emTypeAnalysis);
        if (result == null) result = caseReferrable(emTypeAnalysis);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.EM_TYPE_APPLICATION_ENVIRONMENT:
      {
        EMTypeApplicationEnvironment emTypeApplicationEnvironment = (EMTypeApplicationEnvironment)theEObject;
        T result = caseEMTypeApplicationEnvironment(emTypeApplicationEnvironment);
        if (result == null) result = caseErrorModelType(emTypeApplicationEnvironment);
        if (result == null) result = caseTraceableSpecification(emTypeApplicationEnvironment);
        if (result == null) result = caseIdentifiable(emTypeApplicationEnvironment);
        if (result == null) result = caseReferrable(emTypeApplicationEnvironment);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.EM_TYPE_BSW_MODULE:
      {
        EMTypeBswModule emTypeBswModule = (EMTypeBswModule)theEObject;
        T result = caseEMTypeBswModule(emTypeBswModule);
        if (result == null) result = caseErrorModelType(emTypeBswModule);
        if (result == null) result = caseTraceableSpecification(emTypeBswModule);
        if (result == null) result = caseIdentifiable(emTypeBswModule);
        if (result == null) result = caseReferrable(emTypeBswModule);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.EM_TYPE_DESIGN:
      {
        EMTypeDesign emTypeDesign = (EMTypeDesign)theEObject;
        T result = caseEMTypeDesign(emTypeDesign);
        if (result == null) result = caseErrorModelType(emTypeDesign);
        if (result == null) result = caseTraceableSpecification(emTypeDesign);
        if (result == null) result = caseIdentifiable(emTypeDesign);
        if (result == null) result = caseReferrable(emTypeDesign);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.EM_TYPE_HW_COMPONENT:
      {
        EMTypeHwComponent emTypeHwComponent = (EMTypeHwComponent)theEObject;
        T result = caseEMTypeHwComponent(emTypeHwComponent);
        if (result == null) result = caseErrorModelType(emTypeHwComponent);
        if (result == null) result = caseTraceableSpecification(emTypeHwComponent);
        if (result == null) result = caseIdentifiable(emTypeHwComponent);
        if (result == null) result = caseReferrable(emTypeHwComponent);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.EM_TYPE_SW_COMPONENT:
      {
        EMTypeSwComponent emTypeSwComponent = (EMTypeSwComponent)theEObject;
        T result = caseEMTypeSwComponent(emTypeSwComponent);
        if (result == null) result = caseErrorModelType(emTypeSwComponent);
        if (result == null) result = caseTraceableSpecification(emTypeSwComponent);
        if (result == null) result = caseIdentifiable(emTypeSwComponent);
        if (result == null) result = caseReferrable(emTypeSwComponent);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.ERROR_MODEL_PROTOTYPE:
      {
        ErrorModelPrototype errorModelPrototype = (ErrorModelPrototype)theEObject;
        T result = caseErrorModelPrototype(errorModelPrototype);
        if (result == null) result = caseIdentifiable(errorModelPrototype);
        if (result == null) result = caseReferrable(errorModelPrototype);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.ERROR_MODEL_TYPE:
      {
        ErrorModelType errorModelType = (ErrorModelType)theEObject;
        T result = caseErrorModelType(errorModelType);
        if (result == null) result = caseTraceableSpecification(errorModelType);
        if (result == null) result = caseIdentifiable(errorModelType);
        if (result == null) result = caseReferrable(errorModelType);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.FAULT_FAILURE_PROPAGATION_LINK:
      {
        FaultFailurePropagationLink faultFailurePropagationLink = (FaultFailurePropagationLink)theEObject;
        T result = caseFaultFailurePropagationLink(faultFailurePropagationLink);
        if (result == null) result = caseIdentifiable(faultFailurePropagationLink);
        if (result == null) result = caseReferrable(faultFailurePropagationLink);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.FAILURE_RATE:
      {
        FailureRate failureRate = (FailureRate)theEObject;
        T result = caseFailureRate(failureRate);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.QUANTITATIVE_ERROR_MODEL:
      {
        QuantitativeErrorModel quantitativeErrorModel = (QuantitativeErrorModel)theEObject;
        T result = caseQuantitativeErrorModel(quantitativeErrorModel);
        if (result == null) result = caseIdentifiable(quantitativeErrorModel);
        if (result == null) result = caseReferrable(quantitativeErrorModel);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.MALFUNCTION_PROTOTYPE:
      {
        MalfunctionPrototype malfunctionPrototype = (MalfunctionPrototype)theEObject;
        T result = caseMalfunctionPrototype(malfunctionPrototype);
        if (result == null) result = caseIdentifiable(malfunctionPrototype);
        if (result == null) result = caseReferrable(malfunctionPrototype);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.MALFUNCTION_TYPE:
      {
        MalfunctionType malfunctionType = (MalfunctionType)theEObject;
        T result = caseMalfunctionType(malfunctionType);
        if (result == null) result = caseIdentifiable(malfunctionType);
        if (result == null) result = caseReferrable(malfunctionType);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.MFP_BSW_PORT:
      {
        MFPBswPort mfpBswPort = (MFPBswPort)theEObject;
        T result = caseMFPBswPort(mfpBswPort);
        if (result == null) result = caseMalfunctionPrototype(mfpBswPort);
        if (result == null) result = caseIdentifiable(mfpBswPort);
        if (result == null) result = caseReferrable(mfpBswPort);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.MFP_FUNCTION_PORT:
      {
        MFPFunctionPort mfpFunctionPort = (MFPFunctionPort)theEObject;
        T result = caseMFPFunctionPort(mfpFunctionPort);
        if (result == null) result = caseMalfunctionPrototype(mfpFunctionPort);
        if (result == null) result = caseIdentifiable(mfpFunctionPort);
        if (result == null) result = caseReferrable(mfpFunctionPort);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.MFP_HARDWARE_PIN:
      {
        MFPHardwarePin mfpHardwarePin = (MFPHardwarePin)theEObject;
        T result = caseMFPHardwarePin(mfpHardwarePin);
        if (result == null) result = caseMalfunctionPrototype(mfpHardwarePin);
        if (result == null) result = caseIdentifiable(mfpHardwarePin);
        if (result == null) result = caseReferrable(mfpHardwarePin);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.MFP_HARDWARE_PORT:
      {
        MFPHardwarePort mfpHardwarePort = (MFPHardwarePort)theEObject;
        T result = caseMFPHardwarePort(mfpHardwarePort);
        if (result == null) result = caseMalfunctionPrototype(mfpHardwarePort);
        if (result == null) result = caseIdentifiable(mfpHardwarePort);
        if (result == null) result = caseReferrable(mfpHardwarePort);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.MFP_OPERATION:
      {
        MFPOperation mfpOperation = (MFPOperation)theEObject;
        T result = caseMFPOperation(mfpOperation);
        if (result == null) result = caseMFPSwcPort(mfpOperation);
        if (result == null) result = caseMalfunctionPrototype(mfpOperation);
        if (result == null) result = caseIdentifiable(mfpOperation);
        if (result == null) result = caseReferrable(mfpOperation);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.MFP_SWC_PORT:
      {
        MFPSwcPort mfpSwcPort = (MFPSwcPort)theEObject;
        T result = caseMFPSwcPort(mfpSwcPort);
        if (result == null) result = caseMalfunctionPrototype(mfpSwcPort);
        if (result == null) result = caseIdentifiable(mfpSwcPort);
        if (result == null) result = caseReferrable(mfpSwcPort);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.MFP_VARIABLE:
      {
        MFPVariable mfpVariable = (MFPVariable)theEObject;
        T result = caseMFPVariable(mfpVariable);
        if (result == null) result = caseMFPSwcPort(mfpVariable);
        if (result == null) result = caseMalfunctionPrototype(mfpVariable);
        if (result == null) result = caseIdentifiable(mfpVariable);
        if (result == null) result = caseReferrable(mfpVariable);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.MT_COMPOSITE:
      {
        MTComposite mtComposite = (MTComposite)theEObject;
        T result = caseMTComposite(mtComposite);
        if (result == null) result = caseMalfunctionType(mtComposite);
        if (result == null) result = caseIdentifiable(mtComposite);
        if (result == null) result = caseReferrable(mtComposite);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.MT_COMPOSITE_ELEMENT_PROTOTYPE:
      {
        MTCompositeElementPrototype mtCompositeElementPrototype = (MTCompositeElementPrototype)theEObject;
        T result = caseMTCompositeElementPrototype(mtCompositeElementPrototype);
        if (result == null) result = caseIdentifiable(mtCompositeElementPrototype);
        if (result == null) result = caseReferrable(mtCompositeElementPrototype);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.MT_PRIMITIVE:
      {
        MTPrimitive mtPrimitive = (MTPrimitive)theEObject;
        T result = caseMTPrimitive(mtPrimitive);
        if (result == null) result = caseMalfunctionType(mtPrimitive);
        if (result == null) result = caseIdentifiable(mtPrimitive);
        if (result == null) result = caseReferrable(mtPrimitive);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.ERROR_BEHAVIOR_MAPPING:
      {
        ErrorBehaviorMapping errorBehaviorMapping = (ErrorBehaviorMapping)theEObject;
        T result = caseErrorBehaviorMapping(errorBehaviorMapping);
        if (result == null) result = caseIdentifiable(errorBehaviorMapping);
        if (result == null) result = caseReferrable(errorBehaviorMapping);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.ERROR_MODEL_MAPPING:
      {
        ErrorModelMapping errorModelMapping = (ErrorModelMapping)theEObject;
        T result = caseErrorModelMapping(errorModelMapping);
        if (result == null) result = caseIdentifiable(errorModelMapping);
        if (result == null) result = caseReferrable(errorModelMapping);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.MALFUNCTION_MAPPING:
      {
        MalfunctionMapping malfunctionMapping = (MalfunctionMapping)theEObject;
        T result = caseMalfunctionMapping(malfunctionMapping);
        if (result == null) result = caseIdentifiable(malfunctionMapping);
        if (result == null) result = caseReferrable(malfunctionMapping);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.FORMULA_DOCUMENTATION:
      {
        FormulaDocumentation formulaDocumentation = (FormulaDocumentation)theEObject;
        T result = caseFormulaDocumentation(formulaDocumentation);
        if (result == null) result = caseIdentifiable(formulaDocumentation);
        if (result == null) result = caseReferrable(formulaDocumentation);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HW_FAILURE_CLASS_CONTRIBUTION_FORMULA:
      {
        HWFailureClassContributionFormula hwFailureClassContributionFormula = (HWFailureClassContributionFormula)theEObject;
        T result = caseHWFailureClassContributionFormula(hwFailureClassContributionFormula);
        if (result == null) result = caseFormulaDocumentation(hwFailureClassContributionFormula);
        if (result == null) result = caseIdentifiable(hwFailureClassContributionFormula);
        if (result == null) result = caseReferrable(hwFailureClassContributionFormula);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HWFM_SINGLE_CONTRIBUTION_FORMULA:
      {
        HWFMSingleContributionFormula hwfmSingleContributionFormula = (HWFMSingleContributionFormula)theEObject;
        T result = caseHWFMSingleContributionFormula(hwfmSingleContributionFormula);
        if (result == null) result = caseFormulaDocumentation(hwfmSingleContributionFormula);
        if (result == null) result = caseIdentifiable(hwfmSingleContributionFormula);
        if (result == null) result = caseReferrable(hwfmSingleContributionFormula);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HW_LAMBDA_PART_FORMULA:
      {
        HWLambdaPartFormula hwLambdaPartFormula = (HWLambdaPartFormula)theEObject;
        T result = caseHWLambdaPartFormula(hwLambdaPartFormula);
        if (result == null) result = caseFormulaDocumentation(hwLambdaPartFormula);
        if (result == null) result = caseIdentifiable(hwLambdaPartFormula);
        if (result == null) result = caseReferrable(hwLambdaPartFormula);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HW_LATENT_FAULT_METRIC_FORMULA:
      {
        HWLatentFaultMetricFormula hwLatentFaultMetricFormula = (HWLatentFaultMetricFormula)theEObject;
        T result = caseHWLatentFaultMetricFormula(hwLatentFaultMetricFormula);
        if (result == null) result = caseFormulaDocumentation(hwLatentFaultMetricFormula);
        if (result == null) result = caseIdentifiable(hwLatentFaultMetricFormula);
        if (result == null) result = caseReferrable(hwLatentFaultMetricFormula);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HWPMHF_FORMULA:
      {
        HWPMHFFormula hwpmhfFormula = (HWPMHFFormula)theEObject;
        T result = caseHWPMHFFormula(hwpmhfFormula);
        if (result == null) result = caseFormulaDocumentation(hwpmhfFormula);
        if (result == null) result = caseIdentifiable(hwpmhfFormula);
        if (result == null) result = caseReferrable(hwpmhfFormula);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HW_SINGLE_POINT_FAULT_METRIC_FORMULA:
      {
        HWSinglePointFaultMetricFormula hwSinglePointFaultMetricFormula = (HWSinglePointFaultMetricFormula)theEObject;
        T result = caseHWSinglePointFaultMetricFormula(hwSinglePointFaultMetricFormula);
        if (result == null) result = caseFormulaDocumentation(hwSinglePointFaultMetricFormula);
        if (result == null) result = caseIdentifiable(hwSinglePointFaultMetricFormula);
        if (result == null) result = caseReferrable(hwSinglePointFaultMetricFormula);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HARDWARE_FAILURE_ANALYSIS:
      {
        HardwareFailureAnalysis hardwareFailureAnalysis = (HardwareFailureAnalysis)theEObject;
        T result = caseHardwareFailureAnalysis(hardwareFailureAnalysis);
        if (result == null) result = caseIdentifiable(hardwareFailureAnalysis);
        if (result == null) result = caseReferrable(hardwareFailureAnalysis);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HARDWARE_COMPONENT_FAILURE:
      {
        HardwareComponentFailure hardwareComponentFailure = (HardwareComponentFailure)theEObject;
        T result = caseHardwareComponentFailure(hardwareComponentFailure);
        if (result == null) result = caseIdentifiable(hardwareComponentFailure);
        if (result == null) result = caseReferrable(hardwareComponentFailure);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HW_FAILURE_RATE:
      {
        HWFailureRate hwFailureRate = (HWFailureRate)theEObject;
        T result = caseHWFailureRate(hwFailureRate);
        if (result == null) result = caseReferrable(hwFailureRate);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HW_FAILURE_MODE:
      {
        HWFailureMode hwFailureMode = (HWFailureMode)theEObject;
        T result = caseHWFailureMode(hwFailureMode);
        if (result == null) result = caseMalfunctionType(hwFailureMode);
        if (result == null) result = caseIdentifiable(hwFailureMode);
        if (result == null) result = caseReferrable(hwFailureMode);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HW_FAULT:
      {
        HWFault hwFault = (HWFault)theEObject;
        T result = caseHWFault(hwFault);
        if (result == null) result = caseIdentifiable(hwFault);
        if (result == null) result = caseReferrable(hwFault);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HW_COMPONENT_PROTOTYPE_SCOPE:
      {
        HWComponentPrototypeScope hwComponentPrototypeScope = (HWComponentPrototypeScope)theEObject;
        T result = caseHWComponentPrototypeScope(hwComponentPrototypeScope);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HW_COMPONENT_SCOPE_INSTANCE_REF:
      {
        HwComponentScopeInstanceRef hwComponentScopeInstanceRef = (HwComponentScopeInstanceRef)theEObject;
        T result = caseHwComponentScopeInstanceRef(hwComponentScopeInstanceRef);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HW_COMPONENT_QUANTIFIED_FM_FROM_PART:
      {
        HWComponentQuantifiedFMFromPart hwComponentQuantifiedFMFromPart = (HWComponentQuantifiedFMFromPart)theEObject;
        T result = caseHWComponentQuantifiedFMFromPart(hwComponentQuantifiedFMFromPart);
        if (result == null) result = caseIdentifiable(hwComponentQuantifiedFMFromPart);
        if (result == null) result = caseReferrable(hwComponentQuantifiedFMFromPart);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HW_ELEMENT_PROTOTYPE_SCOPE:
      {
        HWElementPrototypeScope hwElementPrototypeScope = (HWElementPrototypeScope)theEObject;
        T result = caseHWElementPrototypeScope(hwElementPrototypeScope);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HW_PART_FAILURE:
      {
        HWPartFailure hwPartFailure = (HWPartFailure)theEObject;
        T result = caseHWPartFailure(hwPartFailure);
        if (result == null) result = caseIdentifiable(hwPartFailure);
        if (result == null) result = caseReferrable(hwPartFailure);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HW_PART_FAILURE_ANALYSIS:
      {
        HWPartFailureAnalysis hwPartFailureAnalysis = (HWPartFailureAnalysis)theEObject;
        T result = caseHWPartFailureAnalysis(hwPartFailureAnalysis);
        if (result == null) result = caseIdentifiable(hwPartFailureAnalysis);
        if (result == null) result = caseReferrable(hwPartFailureAnalysis);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HW_PART_FAILURE_MODE:
      {
        HWPartFailureMode hwPartFailureMode = (HWPartFailureMode)theEObject;
        T result = caseHWPartFailureMode(hwPartFailureMode);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HW_PART_FAILURE_RATE:
      {
        HWPartFailureRate hwPartFailureRate = (HWPartFailureRate)theEObject;
        T result = caseHWPartFailureRate(hwPartFailureRate);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HW_ELEMENT_SCOPE_INSTANCE_REF:
      {
        HWElementScopeInstanceRef hwElementScopeInstanceRef = (HWElementScopeInstanceRef)theEObject;
        T result = caseHWElementScopeInstanceRef(hwElementScopeInstanceRef);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HW_ARCHITECTURAL_METRICS:
      {
        HWArchitecturalMetrics hwArchitecturalMetrics = (HWArchitecturalMetrics)theEObject;
        T result = caseHWArchitecturalMetrics(hwArchitecturalMetrics);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HWFM_SINGLE_CONTRIBUTION:
      {
        HWFMSingleContribution hwfmSingleContribution = (HWFMSingleContribution)theEObject;
        T result = caseHWFMSingleContribution(hwfmSingleContribution);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HW_PROBABILISTIC_VALUE:
      {
        HWProbabilisticValue hwProbabilisticValue = (HWProbabilisticValue)theEObject;
        T result = caseHWProbabilisticValue(hwProbabilisticValue);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HW_QUANTITATIVE_FAILURE_ANALYSIS:
      {
        HWQuantitativeFailureAnalysis hwQuantitativeFailureAnalysis = (HWQuantitativeFailureAnalysis)theEObject;
        T result = caseHWQuantitativeFailureAnalysis(hwQuantitativeFailureAnalysis);
        if (result == null) result = caseIdentifiable(hwQuantitativeFailureAnalysis);
        if (result == null) result = caseReferrable(hwQuantitativeFailureAnalysis);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HW_LATENT_FAULT_METRIC:
      {
        HWLatentFaultMetric hwLatentFaultMetric = (HWLatentFaultMetric)theEObject;
        T result = caseHWLatentFaultMetric(hwLatentFaultMetric);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HW_SINGLE_POINT_FAULT_METRIC:
      {
        HWSinglePointFaultMetric hwSinglePointFaultMetric = (HWSinglePointFaultMetric)theEObject;
        T result = caseHWSinglePointFaultMetric(hwSinglePointFaultMetric);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HW_ELEMENT_FAILURE_RATE_CLASS:
      {
        HWElementFailureRateClass hwElementFailureRateClass = (HWElementFailureRateClass)theEObject;
        T result = caseHWElementFailureRateClass(hwElementFailureRateClass);
        if (result == null) result = caseIdentifiable(hwElementFailureRateClass);
        if (result == null) result = caseReferrable(hwElementFailureRateClass);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HW_FAILURE_CLASS_CONTAINER:
      {
        HWFailureClassContainer hwFailureClassContainer = (HWFailureClassContainer)theEObject;
        T result = caseHWFailureClassContainer(hwFailureClassContainer);
        if (result == null) result = caseIdentifiable(hwFailureClassContainer);
        if (result == null) result = caseReferrable(hwFailureClassContainer);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HWPMHF:
      {
        HWPMHF hwpmhf = (HWPMHF)theEObject;
        T result = caseHWPMHF(hwpmhf);
        if (result == null) result = caseIdentifiable(hwpmhf);
        if (result == null) result = caseReferrable(hwpmhf);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.ACTOR:
      {
        Actor actor = (Actor)theEObject;
        T result = caseActor(actor);
        if (result == null) result = caseIdentifiable(actor);
        if (result == null) result = caseReferrable(actor);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CONTROLLABILITY_REFERENCE:
      {
        ControllabilityReference controllabilityReference = (ControllabilityReference)theEObject;
        T result = caseControllabilityReference(controllabilityReference);
        if (result == null) result = caseIdentifiable(controllabilityReference);
        if (result == null) result = caseReferrable(controllabilityReference);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HAZARD:
      {
        Hazard hazard = (Hazard)theEObject;
        T result = caseHazard(hazard);
        if (result == null) result = caseIdentifiable(hazard);
        if (result == null) result = caseReferrable(hazard);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HAZARDOUS_EVENT:
      {
        HazardousEvent hazardousEvent = (HazardousEvent)theEObject;
        T result = caseHazardousEvent(hazardousEvent);
        if (result == null) result = caseIdentifiable(hazardousEvent);
        if (result == null) result = caseReferrable(hazardousEvent);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.ITEM:
      {
        Item item = (Item)theEObject;
        T result = caseItem(item);
        if (result == null) result = caseIdentifiable(item);
        if (result == null) result = caseReferrable(item);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.ITEM_FUNCTION_DESCRIPTION:
      {
        ItemFunctionDescription itemFunctionDescription = (ItemFunctionDescription)theEObject;
        T result = caseItemFunctionDescription(itemFunctionDescription);
        if (result == null) result = caseIdentifiable(itemFunctionDescription);
        if (result == null) result = caseReferrable(itemFunctionDescription);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.OPERATING_MODE:
      {
        OperatingMode operatingMode = (OperatingMode)theEObject;
        T result = caseOperatingMode(operatingMode);
        if (result == null) result = caseIdentifiable(operatingMode);
        if (result == null) result = caseReferrable(operatingMode);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.OPERATIONAL_SITUATION:
      {
        OperationalSituation operationalSituation = (OperationalSituation)theEObject;
        T result = caseOperationalSituation(operationalSituation);
        if (result == null) result = caseTraceableSpecification(operationalSituation);
        if (result == null) result = caseIdentifiable(operationalSituation);
        if (result == null) result = caseReferrable(operationalSituation);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.RISK_DESCRIPTION:
      {
        RiskDescription riskDescription = (RiskDescription)theEObject;
        T result = caseRiskDescription(riskDescription);
        if (result == null) result = caseTraceableSpecification(riskDescription);
        if (result == null) result = caseIdentifiable(riskDescription);
        if (result == null) result = caseReferrable(riskDescription);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.SAFE_STATE:
      {
        SafeState safeState = (SafeState)theEObject;
        T result = caseSafeState(safeState);
        if (result == null) result = caseIdentifiable(safeState);
        if (result == null) result = caseReferrable(safeState);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.ABSTRACT_QUANTIFIABLE_SAFETY_REQUIREMENT:
      {
        AbstractQuantifiableSafetyRequirement abstractQuantifiableSafetyRequirement = (AbstractQuantifiableSafetyRequirement)theEObject;
        T result = caseAbstractQuantifiableSafetyRequirement(abstractQuantifiableSafetyRequirement);
        if (result == null) result = caseAbstractSafetyRequirement(abstractQuantifiableSafetyRequirement);
        if (result == null) result = caseTraceableSpecification(abstractQuantifiableSafetyRequirement);
        if (result == null) result = caseAllocatableElement(abstractQuantifiableSafetyRequirement);
        if (result == null) result = caseIdentifiable(abstractQuantifiableSafetyRequirement);
        if (result == null) result = caseReferrable(abstractQuantifiableSafetyRequirement);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.ABSTRACT_SAFETY_REQUIREMENT:
      {
        AbstractSafetyRequirement abstractSafetyRequirement = (AbstractSafetyRequirement)theEObject;
        T result = caseAbstractSafetyRequirement(abstractSafetyRequirement);
        if (result == null) result = caseTraceableSpecification(abstractSafetyRequirement);
        if (result == null) result = caseAllocatableElement(abstractSafetyRequirement);
        if (result == null) result = caseIdentifiable(abstractSafetyRequirement);
        if (result == null) result = caseReferrable(abstractSafetyRequirement);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.ALLOCATABLE_ELEMENT:
      {
        AllocatableElement allocatableElement = (AllocatableElement)theEObject;
        T result = caseAllocatableElement(allocatableElement);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.ALLOCATION_TARGETS:
      {
        AllocationTargets allocationTargets = (AllocationTargets)theEObject;
        T result = caseAllocationTargets(allocationTargets);
        if (result == null) result = caseIdentifiable(allocationTargets);
        if (result == null) result = caseReferrable(allocationTargets);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.FUNCTIONAL_SAFETY_REQUIREMENT:
      {
        FunctionalSafetyRequirement functionalSafetyRequirement = (FunctionalSafetyRequirement)theEObject;
        T result = caseFunctionalSafetyRequirement(functionalSafetyRequirement);
        if (result == null) result = caseAbstractSafetyRequirement(functionalSafetyRequirement);
        if (result == null) result = caseTraceableSpecification(functionalSafetyRequirement);
        if (result == null) result = caseAllocatableElement(functionalSafetyRequirement);
        if (result == null) result = caseIdentifiable(functionalSafetyRequirement);
        if (result == null) result = caseReferrable(functionalSafetyRequirement);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HARDWARE_SAFETY_REQUIREMENT:
      {
        HardwareSafetyRequirement hardwareSafetyRequirement = (HardwareSafetyRequirement)theEObject;
        T result = caseHardwareSafetyRequirement(hardwareSafetyRequirement);
        if (result == null) result = caseAbstractQuantifiableSafetyRequirement(hardwareSafetyRequirement);
        if (result == null) result = caseAbstractSafetyRequirement(hardwareSafetyRequirement);
        if (result == null) result = caseTraceableSpecification(hardwareSafetyRequirement);
        if (result == null) result = caseAllocatableElement(hardwareSafetyRequirement);
        if (result == null) result = caseIdentifiable(hardwareSafetyRequirement);
        if (result == null) result = caseReferrable(hardwareSafetyRequirement);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.QUANTIFIED_DIAGNOSTIC_COVERAGE_PROPERTY:
      {
        QuantifiedDiagnosticCoverageProperty quantifiedDiagnosticCoverageProperty = (QuantifiedDiagnosticCoverageProperty)theEObject;
        T result = caseQuantifiedDiagnosticCoverageProperty(quantifiedDiagnosticCoverageProperty);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.QUANTIFIED_HW_PROPERTY:
      {
        QuantifiedHWProperty quantifiedHWProperty = (QuantifiedHWProperty)theEObject;
        T result = caseQuantifiedHWProperty(quantifiedHWProperty);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.REQUIREMENTS_LINK:
      {
        RequirementsLink requirementsLink = (RequirementsLink)theEObject;
        T result = caseRequirementsLink(requirementsLink);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.REQUIREMENTS_RELEATIONSHIP:
      {
        RequirementsReleationship requirementsReleationship = (RequirementsReleationship)theEObject;
        T result = caseRequirementsReleationship(requirementsReleationship);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.SAFETY_CONCEPT:
      {
        SafetyConcept safetyConcept = (SafetyConcept)theEObject;
        T result = caseSafetyConcept(safetyConcept);
        if (result == null) result = caseAbstractSafetyRequirement(safetyConcept);
        if (result == null) result = caseTraceableSpecification(safetyConcept);
        if (result == null) result = caseAllocatableElement(safetyConcept);
        if (result == null) result = caseIdentifiable(safetyConcept);
        if (result == null) result = caseReferrable(safetyConcept);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.SATISFY:
      {
        Satisfy satisfy = (Satisfy)theEObject;
        T result = caseSatisfy(satisfy);
        if (result == null) result = caseRequirementsReleationship(satisfy);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.SOFTWARE_SAFETY_REQUIREMENT:
      {
        SoftwareSafetyRequirement softwareSafetyRequirement = (SoftwareSafetyRequirement)theEObject;
        T result = caseSoftwareSafetyRequirement(softwareSafetyRequirement);
        if (result == null) result = caseAbstractQuantifiableSafetyRequirement(softwareSafetyRequirement);
        if (result == null) result = caseAbstractSafetyRequirement(softwareSafetyRequirement);
        if (result == null) result = caseTraceableSpecification(softwareSafetyRequirement);
        if (result == null) result = caseAllocatableElement(softwareSafetyRequirement);
        if (result == null) result = caseIdentifiable(softwareSafetyRequirement);
        if (result == null) result = caseReferrable(softwareSafetyRequirement);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.TECHNICAL_SAFETY_REQUIREMENT:
      {
        TechnicalSafetyRequirement technicalSafetyRequirement = (TechnicalSafetyRequirement)theEObject;
        T result = caseTechnicalSafetyRequirement(technicalSafetyRequirement);
        if (result == null) result = caseAbstractQuantifiableSafetyRequirement(technicalSafetyRequirement);
        if (result == null) result = caseAbstractSafetyRequirement(technicalSafetyRequirement);
        if (result == null) result = caseTraceableSpecification(technicalSafetyRequirement);
        if (result == null) result = caseAllocatableElement(technicalSafetyRequirement);
        if (result == null) result = caseIdentifiable(technicalSafetyRequirement);
        if (result == null) result = caseReferrable(technicalSafetyRequirement);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.TRACEABLE_SPECIFICATION:
      {
        TraceableSpecification traceableSpecification = (TraceableSpecification)theEObject;
        T result = caseTraceableSpecification(traceableSpecification);
        if (result == null) result = caseIdentifiable(traceableSpecification);
        if (result == null) result = caseReferrable(traceableSpecification);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.VERIFY:
      {
        Verify verify = (Verify)theEObject;
        T result = caseVerify(verify);
        if (result == null) result = caseRequirementsReleationship(verify);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.WARNING_AND_DEGRADATION:
      {
        WarningAndDegradation warningAndDegradation = (WarningAndDegradation)theEObject;
        T result = caseWarningAndDegradation(warningAndDegradation);
        if (result == null) result = caseFunctionalSafetyRequirement(warningAndDegradation);
        if (result == null) result = caseAbstractSafetyRequirement(warningAndDegradation);
        if (result == null) result = caseTraceableSpecification(warningAndDegradation);
        if (result == null) result = caseAllocatableElement(warningAndDegradation);
        if (result == null) result = caseIdentifiable(warningAndDegradation);
        if (result == null) result = caseReferrable(warningAndDegradation);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.WARNING_AND_DEGRADATION_HANDLE:
      {
        WarningAndDegradationHandle warningAndDegradationHandle = (WarningAndDegradationHandle)theEObject;
        T result = caseWarningAndDegradationHandle(warningAndDegradationHandle);
        if (result == null) result = caseHandle(warningAndDegradationHandle);
        if (result == null) result = caseTactic(warningAndDegradationHandle);
        if (result == null) result = caseIdentifiable(warningAndDegradationHandle);
        if (result == null) result = caseReferrable(warningAndDegradationHandle);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.ASSUMPTION:
      {
        Assumption assumption = (Assumption)theEObject;
        T result = caseAssumption(assumption);
        if (result == null) result = caseAbstractSafetyRequirement(assumption);
        if (result == null) result = caseTraceableSpecification(assumption);
        if (result == null) result = caseAllocatableElement(assumption);
        if (result == null) result = caseIdentifiable(assumption);
        if (result == null) result = caseReferrable(assumption);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CONTEXT:
      {
        Context context = (Context)theEObject;
        T result = caseContext(context);
        if (result == null) result = caseAbstractSafetyRequirement(context);
        if (result == null) result = caseTraceableSpecification(context);
        if (result == null) result = caseAllocatableElement(context);
        if (result == null) result = caseIdentifiable(context);
        if (result == null) result = caseReferrable(context);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.GOAL:
      {
        Goal goal = (Goal)theEObject;
        T result = caseGoal(goal);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.JUSTIFICATION:
      {
        Justification justification = (Justification)theEObject;
        T result = caseJustification(justification);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.SAFETY_CASE:
      {
        SafetyCase safetyCase = (SafetyCase)theEObject;
        T result = caseSafetyCase(safetyCase);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.SOLUTION:
      {
        Solution solution = (Solution)theEObject;
        T result = caseSolution(solution);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.STRATEGY:
      {
        Strategy strategy = (Strategy)theEObject;
        T result = caseStrategy(strategy);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.ANALYSIS_REPORT:
      {
        AnalysisReport analysisReport = (AnalysisReport)theEObject;
        T result = caseAnalysisReport(analysisReport);
        if (result == null) result = caseSolution(analysisReport);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.DESIGN_SPECIFICATION:
      {
        DesignSpecification designSpecification = (DesignSpecification)theEObject;
        T result = caseDesignSpecification(designSpecification);
        if (result == null) result = caseSolution(designSpecification);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.FIELD_TEST_PROTOCOL:
      {
        FieldTestProtocol fieldTestProtocol = (FieldTestProtocol)theEObject;
        T result = caseFieldTestProtocol(fieldTestProtocol);
        if (result == null) result = caseTestProtocol(fieldTestProtocol);
        if (result == null) result = caseSolution(fieldTestProtocol);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.FMEA_REPORT:
      {
        FMEAReport fmeaReport = (FMEAReport)theEObject;
        T result = caseFMEAReport(fmeaReport);
        if (result == null) result = caseAnalysisReport(fmeaReport);
        if (result == null) result = caseSolution(fmeaReport);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.TEST_PROTOCOL:
      {
        TestProtocol testProtocol = (TestProtocol)theEObject;
        T result = caseTestProtocol(testProtocol);
        if (result == null) result = caseSolution(testProtocol);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.UNIT_TEST_PROTOCOL:
      {
        UnitTestProtocol unitTestProtocol = (UnitTestProtocol)theEObject;
        T result = caseUnitTestProtocol(unitTestProtocol);
        if (result == null) result = caseTestProtocol(unitTestProtocol);
        if (result == null) result = caseSolution(unitTestProtocol);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.AVOID:
      {
        Avoid avoid = (Avoid)theEObject;
        T result = caseAvoid(avoid);
        if (result == null) result = caseTactic(avoid);
        if (result == null) result = caseIdentifiable(avoid);
        if (result == null) result = caseReferrable(avoid);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.DETECT:
      {
        Detect detect = (Detect)theEObject;
        T result = caseDetect(detect);
        if (result == null) result = caseTactic(detect);
        if (result == null) result = caseIdentifiable(detect);
        if (result == null) result = caseReferrable(detect);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HANDLE:
      {
        Handle handle = (Handle)theEObject;
        T result = caseHandle(handle);
        if (result == null) result = caseTactic(handle);
        if (result == null) result = caseIdentifiable(handle);
        if (result == null) result = caseReferrable(handle);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.SITUATION:
      {
        Situation situation = (Situation)theEObject;
        T result = caseSituation(situation);
        if (result == null) result = caseIdentifiable(situation);
        if (result == null) result = caseReferrable(situation);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.TACTIC:
      {
        Tactic tactic = (Tactic)theEObject;
        T result = caseTactic(tactic);
        if (result == null) result = caseIdentifiable(tactic);
        if (result == null) result = caseReferrable(tactic);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.AUTOSAR_RUNNABLE_ENTITY_SEQUENCE_CONSTRAINT:
      {
        AUTOSARRunnableEntitySequenceConstraint autosarRunnableEntitySequenceConstraint = (AUTOSARRunnableEntitySequenceConstraint)theEObject;
        T result = caseAUTOSARRunnableEntitySequenceConstraint(autosarRunnableEntitySequenceConstraint);
        if (result == null) result = caseSequenceBlock(autosarRunnableEntitySequenceConstraint);
        if (result == null) result = caseControlBlock(autosarRunnableEntitySequenceConstraint);
        if (result == null) result = caseIdentifiable(autosarRunnableEntitySequenceConstraint);
        if (result == null) result = caseReferrable(autosarRunnableEntitySequenceConstraint);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.AUTOSAR_SEQUENCE_CONSTRAINT:
      {
        AUTOSARSequenceConstraint autosarSequenceConstraint = (AUTOSARSequenceConstraint)theEObject;
        T result = caseAUTOSARSequenceConstraint(autosarSequenceConstraint);
        if (result == null) result = caseSequenceBlock(autosarSequenceConstraint);
        if (result == null) result = caseControlBlock(autosarSequenceConstraint);
        if (result == null) result = caseIdentifiable(autosarSequenceConstraint);
        if (result == null) result = caseReferrable(autosarSequenceConstraint);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CONTROL_BLOCK:
      {
        ControlBlock controlBlock = (ControlBlock)theEObject;
        T result = caseControlBlock(controlBlock);
        if (result == null) result = caseIdentifiable(controlBlock);
        if (result == null) result = caseReferrable(controlBlock);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CONTROL_FLOW_ERROR:
      {
        ControlFlowError controlFlowError = (ControlFlowError)theEObject;
        T result = caseControlFlowError(controlFlowError);
        if (result == null) result = caseSituation(controlFlowError);
        if (result == null) result = caseIdentifiable(controlFlowError);
        if (result == null) result = caseReferrable(controlFlowError);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CONTROL_FLOW_ERROR_DETECTION:
      {
        ControlFlowErrorDetection controlFlowErrorDetection = (ControlFlowErrorDetection)theEObject;
        T result = caseControlFlowErrorDetection(controlFlowErrorDetection);
        if (result == null) result = caseDetect(controlFlowErrorDetection);
        if (result == null) result = caseTactic(controlFlowErrorDetection);
        if (result == null) result = caseIdentifiable(controlFlowErrorDetection);
        if (result == null) result = caseReferrable(controlFlowErrorDetection);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CONTROL_FLOW_MONITOR:
      {
        ControlFlowMonitor controlFlowMonitor = (ControlFlowMonitor)theEObject;
        T result = caseControlFlowMonitor(controlFlowMonitor);
        if (result == null) result = caseSoftwareSafetyRequirement(controlFlowMonitor);
        if (result == null) result = caseAbstractQuantifiableSafetyRequirement(controlFlowMonitor);
        if (result == null) result = caseAbstractSafetyRequirement(controlFlowMonitor);
        if (result == null) result = caseTraceableSpecification(controlFlowMonitor);
        if (result == null) result = caseAllocatableElement(controlFlowMonitor);
        if (result == null) result = caseIdentifiable(controlFlowMonitor);
        if (result == null) result = caseReferrable(controlFlowMonitor);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.INPUT_BLOCK:
      {
        InputBlock inputBlock = (InputBlock)theEObject;
        T result = caseInputBlock(inputBlock);
        if (result == null) result = caseOperationBlock(inputBlock);
        if (result == null) result = caseControlBlock(inputBlock);
        if (result == null) result = caseIdentifiable(inputBlock);
        if (result == null) result = caseReferrable(inputBlock);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.OPERATION_BLOCK:
      {
        OperationBlock operationBlock = (OperationBlock)theEObject;
        T result = caseOperationBlock(operationBlock);
        if (result == null) result = caseControlBlock(operationBlock);
        if (result == null) result = caseIdentifiable(operationBlock);
        if (result == null) result = caseReferrable(operationBlock);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.OUTPUT_BLOCK:
      {
        OutputBlock outputBlock = (OutputBlock)theEObject;
        T result = caseOutputBlock(outputBlock);
        if (result == null) result = caseOperationBlock(outputBlock);
        if (result == null) result = caseControlBlock(outputBlock);
        if (result == null) result = caseIdentifiable(outputBlock);
        if (result == null) result = caseReferrable(outputBlock);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.RUNNABLE_ENTITY_SEQUENCE_ELEMENT:
      {
        RunnableEntitySequenceElement runnableEntitySequenceElement = (RunnableEntitySequenceElement)theEObject;
        T result = caseRunnableEntitySequenceElement(runnableEntitySequenceElement);
        if (result == null) result = caseIdentifiable(runnableEntitySequenceElement);
        if (result == null) result = caseReferrable(runnableEntitySequenceElement);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.SEQUENCE_BLOCK:
      {
        SequenceBlock sequenceBlock = (SequenceBlock)theEObject;
        T result = caseSequenceBlock(sequenceBlock);
        if (result == null) result = caseControlBlock(sequenceBlock);
        if (result == null) result = caseIdentifiable(sequenceBlock);
        if (result == null) result = caseReferrable(sequenceBlock);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.ALIVENESS_CHECKPOINT_TOO_EARLY:
      {
        AlivenessCheckpointTooEarly alivenessCheckpointTooEarly = (AlivenessCheckpointTooEarly)theEObject;
        T result = caseAlivenessCheckpointTooEarly(alivenessCheckpointTooEarly);
        if (result == null) result = caseSituation(alivenessCheckpointTooEarly);
        if (result == null) result = caseIdentifiable(alivenessCheckpointTooEarly);
        if (result == null) result = caseReferrable(alivenessCheckpointTooEarly);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.ALIVENESS_CHECKPOINT_TOO_LATE:
      {
        AlivenessCheckpointTooLate alivenessCheckpointTooLate = (AlivenessCheckpointTooLate)theEObject;
        T result = caseAlivenessCheckpointTooLate(alivenessCheckpointTooLate);
        if (result == null) result = caseSituation(alivenessCheckpointTooLate);
        if (result == null) result = caseIdentifiable(alivenessCheckpointTooLate);
        if (result == null) result = caseReferrable(alivenessCheckpointTooLate);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.ALIVENESS_CHECKPOINT_TOO_OFTEN:
      {
        AlivenessCheckpointTooOften alivenessCheckpointTooOften = (AlivenessCheckpointTooOften)theEObject;
        T result = caseAlivenessCheckpointTooOften(alivenessCheckpointTooOften);
        if (result == null) result = caseSituation(alivenessCheckpointTooOften);
        if (result == null) result = caseIdentifiable(alivenessCheckpointTooOften);
        if (result == null) result = caseReferrable(alivenessCheckpointTooOften);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.ALIVENESS_MONITOR:
      {
        AlivenessMonitor alivenessMonitor = (AlivenessMonitor)theEObject;
        T result = caseAlivenessMonitor(alivenessMonitor);
        if (result == null) result = caseSoftwareSafetyRequirement(alivenessMonitor);
        if (result == null) result = caseAbstractQuantifiableSafetyRequirement(alivenessMonitor);
        if (result == null) result = caseAbstractSafetyRequirement(alivenessMonitor);
        if (result == null) result = caseTraceableSpecification(alivenessMonitor);
        if (result == null) result = caseAllocatableElement(alivenessMonitor);
        if (result == null) result = caseIdentifiable(alivenessMonitor);
        if (result == null) result = caseReferrable(alivenessMonitor);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.AUTOSAR_ALIVENESS_MONITOR:
      {
        AutosarAlivenessMonitor autosarAlivenessMonitor = (AutosarAlivenessMonitor)theEObject;
        T result = caseAutosarAlivenessMonitor(autosarAlivenessMonitor);
        if (result == null) result = caseAlivenessMonitor(autosarAlivenessMonitor);
        if (result == null) result = caseSoftwareSafetyRequirement(autosarAlivenessMonitor);
        if (result == null) result = caseAbstractQuantifiableSafetyRequirement(autosarAlivenessMonitor);
        if (result == null) result = caseAbstractSafetyRequirement(autosarAlivenessMonitor);
        if (result == null) result = caseTraceableSpecification(autosarAlivenessMonitor);
        if (result == null) result = caseAllocatableElement(autosarAlivenessMonitor);
        if (result == null) result = caseIdentifiable(autosarAlivenessMonitor);
        if (result == null) result = caseReferrable(autosarAlivenessMonitor);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.AUTOSAR_CHECK_POINT:
      {
        AutosarCheckPoint autosarCheckPoint = (AutosarCheckPoint)theEObject;
        T result = caseAutosarCheckPoint(autosarCheckPoint);
        if (result == null) result = caseCheckPoint(autosarCheckPoint);
        if (result == null) result = caseIdentifiable(autosarCheckPoint);
        if (result == null) result = caseReferrable(autosarCheckPoint);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CHECK_POINT:
      {
        CheckPoint checkPoint = (CheckPoint)theEObject;
        T result = caseCheckPoint(checkPoint);
        if (result == null) result = caseIdentifiable(checkPoint);
        if (result == null) result = caseReferrable(checkPoint);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.SOFTWARE_ALIVENESS_DETECTION:
      {
        SoftwareAlivenessDetection softwareAlivenessDetection = (SoftwareAlivenessDetection)theEObject;
        T result = caseSoftwareAlivenessDetection(softwareAlivenessDetection);
        if (result == null) result = caseDetect(softwareAlivenessDetection);
        if (result == null) result = caseTactic(softwareAlivenessDetection);
        if (result == null) result = caseIdentifiable(softwareAlivenessDetection);
        if (result == null) result = caseReferrable(softwareAlivenessDetection);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.ACTUATOR_ERROR:
      {
        ActuatorError actuatorError = (ActuatorError)theEObject;
        T result = caseActuatorError(actuatorError);
        if (result == null) result = caseSituation(actuatorError);
        if (result == null) result = caseIdentifiable(actuatorError);
        if (result == null) result = caseReferrable(actuatorError);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.ACTUATOR_ERROR_DETECTION:
      {
        ActuatorErrorDetection actuatorErrorDetection = (ActuatorErrorDetection)theEObject;
        T result = caseActuatorErrorDetection(actuatorErrorDetection);
        if (result == null) result = caseDetect(actuatorErrorDetection);
        if (result == null) result = caseTactic(actuatorErrorDetection);
        if (result == null) result = caseIdentifiable(actuatorErrorDetection);
        if (result == null) result = caseReferrable(actuatorErrorDetection);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.ACTUATOR_MONITOR:
      {
        ActuatorMonitor actuatorMonitor = (ActuatorMonitor)theEObject;
        T result = caseActuatorMonitor(actuatorMonitor);
        if (result == null) result = caseSoftwareSafetyRequirement(actuatorMonitor);
        if (result == null) result = caseAbstractQuantifiableSafetyRequirement(actuatorMonitor);
        if (result == null) result = caseAbstractSafetyRequirement(actuatorMonitor);
        if (result == null) result = caseTraceableSpecification(actuatorMonitor);
        if (result == null) result = caseAllocatableElement(actuatorMonitor);
        if (result == null) result = caseIdentifiable(actuatorMonitor);
        if (result == null) result = caseReferrable(actuatorMonitor);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.AUTOSAR_ACTUATOR_MONITOR:
      {
        AutosarActuatorMonitor autosarActuatorMonitor = (AutosarActuatorMonitor)theEObject;
        T result = caseAutosarActuatorMonitor(autosarActuatorMonitor);
        if (result == null) result = caseActuatorMonitor(autosarActuatorMonitor);
        if (result == null) result = caseSoftwareSafetyRequirement(autosarActuatorMonitor);
        if (result == null) result = caseAbstractQuantifiableSafetyRequirement(autosarActuatorMonitor);
        if (result == null) result = caseAbstractSafetyRequirement(autosarActuatorMonitor);
        if (result == null) result = caseTraceableSpecification(autosarActuatorMonitor);
        if (result == null) result = caseAllocatableElement(autosarActuatorMonitor);
        if (result == null) result = caseIdentifiable(autosarActuatorMonitor);
        if (result == null) result = caseReferrable(autosarActuatorMonitor);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.AUTOSAR_EVALUATION_FUNCTION:
      {
        AutosarEvaluationFunction autosarEvaluationFunction = (AutosarEvaluationFunction)theEObject;
        T result = caseAutosarEvaluationFunction(autosarEvaluationFunction);
        if (result == null) result = caseEvaluationFunction(autosarEvaluationFunction);
        if (result == null) result = caseIdentifiable(autosarEvaluationFunction);
        if (result == null) result = caseReferrable(autosarEvaluationFunction);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.EVALUATION_FUNCTION:
      {
        EvaluationFunction evaluationFunction = (EvaluationFunction)theEObject;
        T result = caseEvaluationFunction(evaluationFunction);
        if (result == null) result = caseIdentifiable(evaluationFunction);
        if (result == null) result = caseReferrable(evaluationFunction);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.AUTOSAR_CRC:
      {
        AutosarCRC autosarCRC = (AutosarCRC)theEObject;
        T result = caseAutosarCRC(autosarCRC);
        if (result == null) result = caseCRC(autosarCRC);
        if (result == null) result = caseSoftwareSafetyRequirement(autosarCRC);
        if (result == null) result = caseAbstractQuantifiableSafetyRequirement(autosarCRC);
        if (result == null) result = caseAbstractSafetyRequirement(autosarCRC);
        if (result == null) result = caseTraceableSpecification(autosarCRC);
        if (result == null) result = caseAllocatableElement(autosarCRC);
        if (result == null) result = caseIdentifiable(autosarCRC);
        if (result == null) result = caseReferrable(autosarCRC);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.COMPONENT_PROTOTYPE_CRC:
      {
        ComponentPrototypeCRC componentPrototypeCRC = (ComponentPrototypeCRC)theEObject;
        T result = caseComponentPrototypeCRC(componentPrototypeCRC);
        if (result == null) result = caseAutosarCRC(componentPrototypeCRC);
        if (result == null) result = caseCRC(componentPrototypeCRC);
        if (result == null) result = caseSoftwareSafetyRequirement(componentPrototypeCRC);
        if (result == null) result = caseAbstractQuantifiableSafetyRequirement(componentPrototypeCRC);
        if (result == null) result = caseAbstractSafetyRequirement(componentPrototypeCRC);
        if (result == null) result = caseTraceableSpecification(componentPrototypeCRC);
        if (result == null) result = caseAllocatableElement(componentPrototypeCRC);
        if (result == null) result = caseIdentifiable(componentPrototypeCRC);
        if (result == null) result = caseReferrable(componentPrototypeCRC);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CRC:
      {
        CRC crc = (CRC)theEObject;
        T result = caseCRC(crc);
        if (result == null) result = caseSoftwareSafetyRequirement(crc);
        if (result == null) result = caseAbstractQuantifiableSafetyRequirement(crc);
        if (result == null) result = caseAbstractSafetyRequirement(crc);
        if (result == null) result = caseTraceableSpecification(crc);
        if (result == null) result = caseAllocatableElement(crc);
        if (result == null) result = caseIdentifiable(crc);
        if (result == null) result = caseReferrable(crc);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CRC_CONFIG:
      {
        CRCConfig crcConfig = (CRCConfig)theEObject;
        T result = caseCRCConfig(crcConfig);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CRC_ERROR_DETECTION:
      {
        CRCErrorDetection crcErrorDetection = (CRCErrorDetection)theEObject;
        T result = caseCRCErrorDetection(crcErrorDetection);
        if (result == null) result = caseDetect(crcErrorDetection);
        if (result == null) result = caseTactic(crcErrorDetection);
        if (result == null) result = caseIdentifiable(crcErrorDetection);
        if (result == null) result = caseReferrable(crcErrorDetection);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CRC_FAILED:
      {
        CRCFailed crcFailed = (CRCFailed)theEObject;
        T result = caseCRCFailed(crcFailed);
        if (result == null) result = caseSituation(crcFailed);
        if (result == null) result = caseIdentifiable(crcFailed);
        if (result == null) result = caseReferrable(crcFailed);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.INTERFACE_CRC:
      {
        InterfaceCRC interfaceCRC = (InterfaceCRC)theEObject;
        T result = caseInterfaceCRC(interfaceCRC);
        if (result == null) result = caseAutosarCRC(interfaceCRC);
        if (result == null) result = caseCRC(interfaceCRC);
        if (result == null) result = caseSoftwareSafetyRequirement(interfaceCRC);
        if (result == null) result = caseAbstractQuantifiableSafetyRequirement(interfaceCRC);
        if (result == null) result = caseAbstractSafetyRequirement(interfaceCRC);
        if (result == null) result = caseTraceableSpecification(interfaceCRC);
        if (result == null) result = caseAllocatableElement(interfaceCRC);
        if (result == null) result = caseIdentifiable(interfaceCRC);
        if (result == null) result = caseReferrable(interfaceCRC);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.AUTOSAR_COMPARISON:
      {
        AutosarComparison autosarComparison = (AutosarComparison)theEObject;
        T result = caseAutosarComparison(autosarComparison);
        if (result == null) result = caseComparison(autosarComparison);
        if (result == null) result = caseSoftwareSafetyRequirement(autosarComparison);
        if (result == null) result = caseAbstractQuantifiableSafetyRequirement(autosarComparison);
        if (result == null) result = caseAbstractSafetyRequirement(autosarComparison);
        if (result == null) result = caseTraceableSpecification(autosarComparison);
        if (result == null) result = caseAllocatableElement(autosarComparison);
        if (result == null) result = caseIdentifiable(autosarComparison);
        if (result == null) result = caseReferrable(autosarComparison);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.AUTOSAR_COMPARISON_PARAM:
      {
        AutosarComparisonParam autosarComparisonParam = (AutosarComparisonParam)theEObject;
        T result = caseAutosarComparisonParam(autosarComparisonParam);
        if (result == null) result = caseComparisonParameter(autosarComparisonParam);
        if (result == null) result = caseIdentifiable(autosarComparisonParam);
        if (result == null) result = caseReferrable(autosarComparisonParam);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CHROMOSOME_COMPARISON:
      {
        ChromosomeComparison chromosomeComparison = (ChromosomeComparison)theEObject;
        T result = caseChromosomeComparison(chromosomeComparison);
        if (result == null) result = caseComparison(chromosomeComparison);
        if (result == null) result = caseSoftwareSafetyRequirement(chromosomeComparison);
        if (result == null) result = caseAbstractQuantifiableSafetyRequirement(chromosomeComparison);
        if (result == null) result = caseAbstractSafetyRequirement(chromosomeComparison);
        if (result == null) result = caseTraceableSpecification(chromosomeComparison);
        if (result == null) result = caseAllocatableElement(chromosomeComparison);
        if (result == null) result = caseIdentifiable(chromosomeComparison);
        if (result == null) result = caseReferrable(chromosomeComparison);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CHROMOSOME_COMPARISON_PARAMETER:
      {
        ChromosomeComparisonParameter chromosomeComparisonParameter = (ChromosomeComparisonParameter)theEObject;
        T result = caseChromosomeComparisonParameter(chromosomeComparisonParameter);
        if (result == null) result = caseComparisonParameter(chromosomeComparisonParameter);
        if (result == null) result = caseIdentifiable(chromosomeComparisonParameter);
        if (result == null) result = caseReferrable(chromosomeComparisonParameter);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.COMPARISON:
      {
        Comparison comparison = (Comparison)theEObject;
        T result = caseComparison(comparison);
        if (result == null) result = caseSoftwareSafetyRequirement(comparison);
        if (result == null) result = caseAbstractQuantifiableSafetyRequirement(comparison);
        if (result == null) result = caseAbstractSafetyRequirement(comparison);
        if (result == null) result = caseTraceableSpecification(comparison);
        if (result == null) result = caseAllocatableElement(comparison);
        if (result == null) result = caseIdentifiable(comparison);
        if (result == null) result = caseReferrable(comparison);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.COMPARISON_DETECTION:
      {
        ComparisonDetection comparisonDetection = (ComparisonDetection)theEObject;
        T result = caseComparisonDetection(comparisonDetection);
        if (result == null) result = caseDetect(comparisonDetection);
        if (result == null) result = caseTactic(comparisonDetection);
        if (result == null) result = caseIdentifiable(comparisonDetection);
        if (result == null) result = caseReferrable(comparisonDetection);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.COMPARISON_FALSE:
      {
        ComparisonFalse comparisonFalse = (ComparisonFalse)theEObject;
        T result = caseComparisonFalse(comparisonFalse);
        if (result == null) result = caseSituation(comparisonFalse);
        if (result == null) result = caseIdentifiable(comparisonFalse);
        if (result == null) result = caseReferrable(comparisonFalse);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.COMPARISON_PARAMETER:
      {
        ComparisonParameter comparisonParameter = (ComparisonParameter)theEObject;
        T result = caseComparisonParameter(comparisonParameter);
        if (result == null) result = caseIdentifiable(comparisonParameter);
        if (result == null) result = caseReferrable(comparisonParameter);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.COMPARISON_TRUE:
      {
        ComparisonTrue comparisonTrue = (ComparisonTrue)theEObject;
        T result = caseComparisonTrue(comparisonTrue);
        if (result == null) result = caseSituation(comparisonTrue);
        if (result == null) result = caseIdentifiable(comparisonTrue);
        if (result == null) result = caseReferrable(comparisonTrue);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CONSTANT_COMPARISON_PARAMETER:
      {
        ConstantComparisonParameter constantComparisonParameter = (ConstantComparisonParameter)theEObject;
        T result = caseConstantComparisonParameter(constantComparisonParameter);
        if (result == null) result = caseConfigParameterValue(constantComparisonParameter);
        if (result == null) result = caseComparisonParameter(constantComparisonParameter);
        if (result == null) result = caseIdentifiable(constantComparisonParameter);
        if (result == null) result = caseReferrable(constantComparisonParameter);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.AUTOSAR_CONTEXT:
      {
        AutosarContext autosarContext = (AutosarContext)theEObject;
        T result = caseAutosarContext(autosarContext);
        if (result == null) result = caseRangeCheckContext(autosarContext);
        if (result == null) result = caseIdentifiable(autosarContext);
        if (result == null) result = caseReferrable(autosarContext);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.AUTOSAR_CONTEXT_RANGE_CHECK:
      {
        AutosarContextRangeCheck autosarContextRangeCheck = (AutosarContextRangeCheck)theEObject;
        T result = caseAutosarContextRangeCheck(autosarContextRangeCheck);
        if (result == null) result = caseContextRangeCheck(autosarContextRangeCheck);
        if (result == null) result = caseSoftwareSafetyRequirement(autosarContextRangeCheck);
        if (result == null) result = caseAbstractQuantifiableSafetyRequirement(autosarContextRangeCheck);
        if (result == null) result = caseAbstractSafetyRequirement(autosarContextRangeCheck);
        if (result == null) result = caseTraceableSpecification(autosarContextRangeCheck);
        if (result == null) result = caseAllocatableElement(autosarContextRangeCheck);
        if (result == null) result = caseIdentifiable(autosarContextRangeCheck);
        if (result == null) result = caseReferrable(autosarContextRangeCheck);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CONTEXT_PARAMETER:
      {
        ContextParameter contextParameter = (ContextParameter)theEObject;
        T result = caseContextParameter(contextParameter);
        if (result == null) result = caseIdentifiable(contextParameter);
        if (result == null) result = caseReferrable(contextParameter);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CONTEXT_RANGE_CHECK:
      {
        ContextRangeCheck contextRangeCheck = (ContextRangeCheck)theEObject;
        T result = caseContextRangeCheck(contextRangeCheck);
        if (result == null) result = caseSoftwareSafetyRequirement(contextRangeCheck);
        if (result == null) result = caseAbstractQuantifiableSafetyRequirement(contextRangeCheck);
        if (result == null) result = caseAbstractSafetyRequirement(contextRangeCheck);
        if (result == null) result = caseTraceableSpecification(contextRangeCheck);
        if (result == null) result = caseAllocatableElement(contextRangeCheck);
        if (result == null) result = caseIdentifiable(contextRangeCheck);
        if (result == null) result = caseReferrable(contextRangeCheck);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CONTEXT_RANGE_CHECK_DETECTION:
      {
        ContextRangeCheckDetection contextRangeCheckDetection = (ContextRangeCheckDetection)theEObject;
        T result = caseContextRangeCheckDetection(contextRangeCheckDetection);
        if (result == null) result = caseDetect(contextRangeCheckDetection);
        if (result == null) result = caseTactic(contextRangeCheckDetection);
        if (result == null) result = caseIdentifiable(contextRangeCheckDetection);
        if (result == null) result = caseReferrable(contextRangeCheckDetection);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.RANGE_CHECK_CONTEXT:
      {
        RangeCheckContext rangeCheckContext = (RangeCheckContext)theEObject;
        T result = caseRangeCheckContext(rangeCheckContext);
        if (result == null) result = caseIdentifiable(rangeCheckContext);
        if (result == null) result = caseReferrable(rangeCheckContext);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.VALUE_ABOVE_RANGE:
      {
        ValueAboveRange valueAboveRange = (ValueAboveRange)theEObject;
        T result = caseValueAboveRange(valueAboveRange);
        if (result == null) result = caseSituation(valueAboveRange);
        if (result == null) result = caseIdentifiable(valueAboveRange);
        if (result == null) result = caseReferrable(valueAboveRange);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.VALUE_BELOW_RANGE:
      {
        ValueBelowRange valueBelowRange = (ValueBelowRange)theEObject;
        T result = caseValueBelowRange(valueBelowRange);
        if (result == null) result = caseSituation(valueBelowRange);
        if (result == null) result = caseIdentifiable(valueBelowRange);
        if (result == null) result = caseReferrable(valueBelowRange);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CHROMOSOME_CPU_SELF_TEST:
      {
        ChromosomeCpuSelfTest chromosomeCpuSelfTest = (ChromosomeCpuSelfTest)theEObject;
        T result = caseChromosomeCpuSelfTest(chromosomeCpuSelfTest);
        if (result == null) result = caseCpuSelfTest(chromosomeCpuSelfTest);
        if (result == null) result = caseSoftwareSafetyRequirement(chromosomeCpuSelfTest);
        if (result == null) result = caseAbstractQuantifiableSafetyRequirement(chromosomeCpuSelfTest);
        if (result == null) result = caseAbstractSafetyRequirement(chromosomeCpuSelfTest);
        if (result == null) result = caseTraceableSpecification(chromosomeCpuSelfTest);
        if (result == null) result = caseAllocatableElement(chromosomeCpuSelfTest);
        if (result == null) result = caseIdentifiable(chromosomeCpuSelfTest);
        if (result == null) result = caseReferrable(chromosomeCpuSelfTest);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CPU_SELF_TEST:
      {
        CpuSelfTest cpuSelfTest = (CpuSelfTest)theEObject;
        T result = caseCpuSelfTest(cpuSelfTest);
        if (result == null) result = caseSoftwareSafetyRequirement(cpuSelfTest);
        if (result == null) result = caseAbstractQuantifiableSafetyRequirement(cpuSelfTest);
        if (result == null) result = caseAbstractSafetyRequirement(cpuSelfTest);
        if (result == null) result = caseTraceableSpecification(cpuSelfTest);
        if (result == null) result = caseAllocatableElement(cpuSelfTest);
        if (result == null) result = caseIdentifiable(cpuSelfTest);
        if (result == null) result = caseReferrable(cpuSelfTest);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CPU_SELF_TEST_CONFIG:
      {
        CpuSelfTestConfig cpuSelfTestConfig = (CpuSelfTestConfig)theEObject;
        T result = caseCpuSelfTestConfig(cpuSelfTestConfig);
        if (result == null) result = caseIdentifiable(cpuSelfTestConfig);
        if (result == null) result = caseReferrable(cpuSelfTestConfig);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CPU_SELF_TEST_DETECTION:
      {
        CpuSelfTestDetection cpuSelfTestDetection = (CpuSelfTestDetection)theEObject;
        T result = caseCpuSelfTestDetection(cpuSelfTestDetection);
        if (result == null) result = caseDetect(cpuSelfTestDetection);
        if (result == null) result = caseTactic(cpuSelfTestDetection);
        if (result == null) result = caseIdentifiable(cpuSelfTestDetection);
        if (result == null) result = caseReferrable(cpuSelfTestDetection);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CPU_SELF_TEST_FAILED:
      {
        CpuSelfTestFailed cpuSelfTestFailed = (CpuSelfTestFailed)theEObject;
        T result = caseCpuSelfTestFailed(cpuSelfTestFailed);
        if (result == null) result = caseSituation(cpuSelfTestFailed);
        if (result == null) result = caseIdentifiable(cpuSelfTestFailed);
        if (result == null) result = caseReferrable(cpuSelfTestFailed);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.FILTER:
      {
        Filter filter = (Filter)theEObject;
        T result = caseFilter(filter);
        if (result == null) result = caseSoftwareSafetyRequirement(filter);
        if (result == null) result = caseAbstractQuantifiableSafetyRequirement(filter);
        if (result == null) result = caseAbstractSafetyRequirement(filter);
        if (result == null) result = caseTraceableSpecification(filter);
        if (result == null) result = caseAllocatableElement(filter);
        if (result == null) result = caseIdentifiable(filter);
        if (result == null) result = caseReferrable(filter);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.FILTER_BASED_HANDLING:
      {
        FilterBasedHandling filterBasedHandling = (FilterBasedHandling)theEObject;
        T result = caseFilterBasedHandling(filterBasedHandling);
        if (result == null) result = caseHandle(filterBasedHandling);
        if (result == null) result = caseTactic(filterBasedHandling);
        if (result == null) result = caseIdentifiable(filterBasedHandling);
        if (result == null) result = caseReferrable(filterBasedHandling);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.FILTER_ERROR:
      {
        FilterError filterError = (FilterError)theEObject;
        T result = caseFilterError(filterError);
        if (result == null) result = caseSituation(filterError);
        if (result == null) result = caseIdentifiable(filterError);
        if (result == null) result = caseReferrable(filterError);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.FILTER_PARAMETER:
      {
        FilterParameter filterParameter = (FilterParameter)theEObject;
        T result = caseFilterParameter(filterParameter);
        if (result == null) result = caseIdentifiable(filterParameter);
        if (result == null) result = caseReferrable(filterParameter);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.AUTOSAR_GRADIENT_CHECK:
      {
        AutosarGradientCheck autosarGradientCheck = (AutosarGradientCheck)theEObject;
        T result = caseAutosarGradientCheck(autosarGradientCheck);
        if (result == null) result = caseGradientCheck(autosarGradientCheck);
        if (result == null) result = caseSoftwareSafetyRequirement(autosarGradientCheck);
        if (result == null) result = caseAbstractQuantifiableSafetyRequirement(autosarGradientCheck);
        if (result == null) result = caseAbstractSafetyRequirement(autosarGradientCheck);
        if (result == null) result = caseTraceableSpecification(autosarGradientCheck);
        if (result == null) result = caseAllocatableElement(autosarGradientCheck);
        if (result == null) result = caseIdentifiable(autosarGradientCheck);
        if (result == null) result = caseReferrable(autosarGradientCheck);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.GRADIENT_CHECK:
      {
        GradientCheck gradientCheck = (GradientCheck)theEObject;
        T result = caseGradientCheck(gradientCheck);
        if (result == null) result = caseSoftwareSafetyRequirement(gradientCheck);
        if (result == null) result = caseAbstractQuantifiableSafetyRequirement(gradientCheck);
        if (result == null) result = caseAbstractSafetyRequirement(gradientCheck);
        if (result == null) result = caseTraceableSpecification(gradientCheck);
        if (result == null) result = caseAllocatableElement(gradientCheck);
        if (result == null) result = caseIdentifiable(gradientCheck);
        if (result == null) result = caseReferrable(gradientCheck);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.GRADIENT_CHECK_DETECTION:
      {
        GradientCheckDetection gradientCheckDetection = (GradientCheckDetection)theEObject;
        T result = caseGradientCheckDetection(gradientCheckDetection);
        if (result == null) result = caseDetect(gradientCheckDetection);
        if (result == null) result = caseTactic(gradientCheckDetection);
        if (result == null) result = caseIdentifiable(gradientCheckDetection);
        if (result == null) result = caseReferrable(gradientCheckDetection);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.GRADIENT_TOO_HIGH:
      {
        GradientTooHigh gradientTooHigh = (GradientTooHigh)theEObject;
        T result = caseGradientTooHigh(gradientTooHigh);
        if (result == null) result = caseSituation(gradientTooHigh);
        if (result == null) result = caseIdentifiable(gradientTooHigh);
        if (result == null) result = caseReferrable(gradientTooHigh);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.GRADIENT_TOO_LOW:
      {
        GradientTooLow gradientTooLow = (GradientTooLow)theEObject;
        T result = caseGradientTooLow(gradientTooLow);
        if (result == null) result = caseSituation(gradientTooLow);
        if (result == null) result = caseIdentifiable(gradientTooLow);
        if (result == null) result = caseReferrable(gradientTooLow);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CHROMOSOME_APPLICATION_HEALTH_MONITOR:
      {
        ChromosomeApplicationHealthMonitor chromosomeApplicationHealthMonitor = (ChromosomeApplicationHealthMonitor)theEObject;
        T result = caseChromosomeApplicationHealthMonitor(chromosomeApplicationHealthMonitor);
        if (result == null) result = caseChromosomeHealthMonitor(chromosomeApplicationHealthMonitor);
        if (result == null) result = caseHealthMonitor(chromosomeApplicationHealthMonitor);
        if (result == null) result = caseSoftwareSafetyRequirement(chromosomeApplicationHealthMonitor);
        if (result == null) result = caseAbstractQuantifiableSafetyRequirement(chromosomeApplicationHealthMonitor);
        if (result == null) result = caseAbstractSafetyRequirement(chromosomeApplicationHealthMonitor);
        if (result == null) result = caseTraceableSpecification(chromosomeApplicationHealthMonitor);
        if (result == null) result = caseAllocatableElement(chromosomeApplicationHealthMonitor);
        if (result == null) result = caseIdentifiable(chromosomeApplicationHealthMonitor);
        if (result == null) result = caseReferrable(chromosomeApplicationHealthMonitor);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CHROMOSOME_COMPONENT_MODE_CONDITION:
      {
        ChromosomeComponentModeCondition chromosomeComponentModeCondition = (ChromosomeComponentModeCondition)theEObject;
        T result = caseChromosomeComponentModeCondition(chromosomeComponentModeCondition);
        if (result == null) result = caseHealthMonitorErrorCondition(chromosomeComponentModeCondition);
        if (result == null) result = caseSituation(chromosomeComponentModeCondition);
        if (result == null) result = caseIdentifiable(chromosomeComponentModeCondition);
        if (result == null) result = caseReferrable(chromosomeComponentModeCondition);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CHROMOSOME_ERROR_EVENT_CONDITION:
      {
        ChromosomeErrorEventCondition chromosomeErrorEventCondition = (ChromosomeErrorEventCondition)theEObject;
        T result = caseChromosomeErrorEventCondition(chromosomeErrorEventCondition);
        if (result == null) result = caseHealthMonitorErrorCondition(chromosomeErrorEventCondition);
        if (result == null) result = caseSituation(chromosomeErrorEventCondition);
        if (result == null) result = caseIdentifiable(chromosomeErrorEventCondition);
        if (result == null) result = caseReferrable(chromosomeErrorEventCondition);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CHROMOSOME_ERROR_HANDLER:
      {
        ChromosomeErrorHandler chromosomeErrorHandler = (ChromosomeErrorHandler)theEObject;
        T result = caseChromosomeErrorHandler(chromosomeErrorHandler);
        if (result == null) result = caseHandle(chromosomeErrorHandler);
        if (result == null) result = caseTactic(chromosomeErrorHandler);
        if (result == null) result = caseIdentifiable(chromosomeErrorHandler);
        if (result == null) result = caseReferrable(chromosomeErrorHandler);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CHROMOSOME_HEALTH_MONITOR:
      {
        ChromosomeHealthMonitor chromosomeHealthMonitor = (ChromosomeHealthMonitor)theEObject;
        T result = caseChromosomeHealthMonitor(chromosomeHealthMonitor);
        if (result == null) result = caseHealthMonitor(chromosomeHealthMonitor);
        if (result == null) result = caseSoftwareSafetyRequirement(chromosomeHealthMonitor);
        if (result == null) result = caseAbstractQuantifiableSafetyRequirement(chromosomeHealthMonitor);
        if (result == null) result = caseAbstractSafetyRequirement(chromosomeHealthMonitor);
        if (result == null) result = caseTraceableSpecification(chromosomeHealthMonitor);
        if (result == null) result = caseAllocatableElement(chromosomeHealthMonitor);
        if (result == null) result = caseIdentifiable(chromosomeHealthMonitor);
        if (result == null) result = caseReferrable(chromosomeHealthMonitor);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CHROMOSOME_HEALTH_MONITOR_NOTIFICATION:
      {
        CHROMOSOMEHealthMonitorNotification chromosomeHealthMonitorNotification = (CHROMOSOMEHealthMonitorNotification)theEObject;
        T result = caseCHROMOSOMEHealthMonitorNotification(chromosomeHealthMonitorNotification);
        if (result == null) result = caseSoftwareSafetyRequirement(chromosomeHealthMonitorNotification);
        if (result == null) result = caseAbstractQuantifiableSafetyRequirement(chromosomeHealthMonitorNotification);
        if (result == null) result = caseAbstractSafetyRequirement(chromosomeHealthMonitorNotification);
        if (result == null) result = caseTraceableSpecification(chromosomeHealthMonitorNotification);
        if (result == null) result = caseAllocatableElement(chromosomeHealthMonitorNotification);
        if (result == null) result = caseIdentifiable(chromosomeHealthMonitorNotification);
        if (result == null) result = caseReferrable(chromosomeHealthMonitorNotification);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CHROMOSOME_NODE_HEALTH_MONITOR:
      {
        ChromosomeNodeHealthMonitor chromosomeNodeHealthMonitor = (ChromosomeNodeHealthMonitor)theEObject;
        T result = caseChromosomeNodeHealthMonitor(chromosomeNodeHealthMonitor);
        if (result == null) result = caseChromosomeHealthMonitor(chromosomeNodeHealthMonitor);
        if (result == null) result = caseHealthMonitor(chromosomeNodeHealthMonitor);
        if (result == null) result = caseSoftwareSafetyRequirement(chromosomeNodeHealthMonitor);
        if (result == null) result = caseAbstractQuantifiableSafetyRequirement(chromosomeNodeHealthMonitor);
        if (result == null) result = caseAbstractSafetyRequirement(chromosomeNodeHealthMonitor);
        if (result == null) result = caseTraceableSpecification(chromosomeNodeHealthMonitor);
        if (result == null) result = caseAllocatableElement(chromosomeNodeHealthMonitor);
        if (result == null) result = caseIdentifiable(chromosomeNodeHealthMonitor);
        if (result == null) result = caseReferrable(chromosomeNodeHealthMonitor);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HEALTH_MONITOR:
      {
        HealthMonitor healthMonitor = (HealthMonitor)theEObject;
        T result = caseHealthMonitor(healthMonitor);
        if (result == null) result = caseSoftwareSafetyRequirement(healthMonitor);
        if (result == null) result = caseAbstractQuantifiableSafetyRequirement(healthMonitor);
        if (result == null) result = caseAbstractSafetyRequirement(healthMonitor);
        if (result == null) result = caseTraceableSpecification(healthMonitor);
        if (result == null) result = caseAllocatableElement(healthMonitor);
        if (result == null) result = caseIdentifiable(healthMonitor);
        if (result == null) result = caseReferrable(healthMonitor);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HEALTH_MONITOR_ERROR_CONDITION:
      {
        HealthMonitorErrorCondition healthMonitorErrorCondition = (HealthMonitorErrorCondition)theEObject;
        T result = caseHealthMonitorErrorCondition(healthMonitorErrorCondition);
        if (result == null) result = caseSituation(healthMonitorErrorCondition);
        if (result == null) result = caseIdentifiable(healthMonitorErrorCondition);
        if (result == null) result = caseReferrable(healthMonitorErrorCondition);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HEALTH_MONITORING:
      {
        HealthMonitoring healthMonitoring = (HealthMonitoring)theEObject;
        T result = caseHealthMonitoring(healthMonitoring);
        if (result == null) result = caseDetect(healthMonitoring);
        if (result == null) result = caseTactic(healthMonitoring);
        if (result == null) result = caseIdentifiable(healthMonitoring);
        if (result == null) result = caseReferrable(healthMonitoring);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CHROMOSOME_HEARTBEAT_RECEIVER:
      {
        ChromosomeHeartbeatReceiver chromosomeHeartbeatReceiver = (ChromosomeHeartbeatReceiver)theEObject;
        T result = caseChromosomeHeartbeatReceiver(chromosomeHeartbeatReceiver);
        if (result == null) result = caseHeartbeatReceiver(chromosomeHeartbeatReceiver);
        if (result == null) result = caseSoftwareSafetyRequirement(chromosomeHeartbeatReceiver);
        if (result == null) result = caseAbstractQuantifiableSafetyRequirement(chromosomeHeartbeatReceiver);
        if (result == null) result = caseAbstractSafetyRequirement(chromosomeHeartbeatReceiver);
        if (result == null) result = caseTraceableSpecification(chromosomeHeartbeatReceiver);
        if (result == null) result = caseAllocatableElement(chromosomeHeartbeatReceiver);
        if (result == null) result = caseIdentifiable(chromosomeHeartbeatReceiver);
        if (result == null) result = caseReferrable(chromosomeHeartbeatReceiver);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CHROMOSOME_HEARTBEAT_SENDER:
      {
        ChromosomeHeartbeatSender chromosomeHeartbeatSender = (ChromosomeHeartbeatSender)theEObject;
        T result = caseChromosomeHeartbeatSender(chromosomeHeartbeatSender);
        if (result == null) result = caseHeartbeatSender(chromosomeHeartbeatSender);
        if (result == null) result = caseSoftwareSafetyRequirement(chromosomeHeartbeatSender);
        if (result == null) result = caseAbstractQuantifiableSafetyRequirement(chromosomeHeartbeatSender);
        if (result == null) result = caseAbstractSafetyRequirement(chromosomeHeartbeatSender);
        if (result == null) result = caseTraceableSpecification(chromosomeHeartbeatSender);
        if (result == null) result = caseAllocatableElement(chromosomeHeartbeatSender);
        if (result == null) result = caseIdentifiable(chromosomeHeartbeatSender);
        if (result == null) result = caseReferrable(chromosomeHeartbeatSender);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HEARTBEAT:
      {
        Heartbeat heartbeat = (Heartbeat)theEObject;
        T result = caseHeartbeat(heartbeat);
        if (result == null) result = caseSoftwareSafetyRequirement(heartbeat);
        if (result == null) result = caseAbstractQuantifiableSafetyRequirement(heartbeat);
        if (result == null) result = caseAbstractSafetyRequirement(heartbeat);
        if (result == null) result = caseTraceableSpecification(heartbeat);
        if (result == null) result = caseAllocatableElement(heartbeat);
        if (result == null) result = caseIdentifiable(heartbeat);
        if (result == null) result = caseReferrable(heartbeat);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HEARTBEAT_CONFIG:
      {
        HeartbeatConfig heartbeatConfig = (HeartbeatConfig)theEObject;
        T result = caseHeartbeatConfig(heartbeatConfig);
        if (result == null) result = caseIdentifiable(heartbeatConfig);
        if (result == null) result = caseReferrable(heartbeatConfig);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HEART_BEAT_DEADLINE_MISSED:
      {
        HeartBeatDeadlineMissed heartBeatDeadlineMissed = (HeartBeatDeadlineMissed)theEObject;
        T result = caseHeartBeatDeadlineMissed(heartBeatDeadlineMissed);
        if (result == null) result = caseSituation(heartBeatDeadlineMissed);
        if (result == null) result = caseIdentifiable(heartBeatDeadlineMissed);
        if (result == null) result = caseReferrable(heartBeatDeadlineMissed);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HEART_BEAT_DETECTION:
      {
        HeartBeatDetection heartBeatDetection = (HeartBeatDetection)theEObject;
        T result = caseHeartBeatDetection(heartBeatDetection);
        if (result == null) result = caseDetect(heartBeatDetection);
        if (result == null) result = caseTactic(heartBeatDetection);
        if (result == null) result = caseIdentifiable(heartBeatDetection);
        if (result == null) result = caseReferrable(heartBeatDetection);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HEARTBEAT_RECEIVER:
      {
        HeartbeatReceiver heartbeatReceiver = (HeartbeatReceiver)theEObject;
        T result = caseHeartbeatReceiver(heartbeatReceiver);
        if (result == null) result = caseSoftwareSafetyRequirement(heartbeatReceiver);
        if (result == null) result = caseAbstractQuantifiableSafetyRequirement(heartbeatReceiver);
        if (result == null) result = caseAbstractSafetyRequirement(heartbeatReceiver);
        if (result == null) result = caseTraceableSpecification(heartbeatReceiver);
        if (result == null) result = caseAllocatableElement(heartbeatReceiver);
        if (result == null) result = caseIdentifiable(heartbeatReceiver);
        if (result == null) result = caseReferrable(heartbeatReceiver);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HEARTBEAT_SENDER:
      {
        HeartbeatSender heartbeatSender = (HeartbeatSender)theEObject;
        T result = caseHeartbeatSender(heartbeatSender);
        if (result == null) result = caseSoftwareSafetyRequirement(heartbeatSender);
        if (result == null) result = caseAbstractQuantifiableSafetyRequirement(heartbeatSender);
        if (result == null) result = caseAbstractSafetyRequirement(heartbeatSender);
        if (result == null) result = caseTraceableSpecification(heartbeatSender);
        if (result == null) result = caseAllocatableElement(heartbeatSender);
        if (result == null) result = caseIdentifiable(heartbeatSender);
        if (result == null) result = caseReferrable(heartbeatSender);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CHROMOSOME_MEMORY_TEST:
      {
        ChromosomeMemoryTest chromosomeMemoryTest = (ChromosomeMemoryTest)theEObject;
        T result = caseChromosomeMemoryTest(chromosomeMemoryTest);
        if (result == null) result = caseMemorySelfTest(chromosomeMemoryTest);
        if (result == null) result = caseSoftwareSafetyRequirement(chromosomeMemoryTest);
        if (result == null) result = caseAbstractQuantifiableSafetyRequirement(chromosomeMemoryTest);
        if (result == null) result = caseAbstractSafetyRequirement(chromosomeMemoryTest);
        if (result == null) result = caseTraceableSpecification(chromosomeMemoryTest);
        if (result == null) result = caseAllocatableElement(chromosomeMemoryTest);
        if (result == null) result = caseIdentifiable(chromosomeMemoryTest);
        if (result == null) result = caseReferrable(chromosomeMemoryTest);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.MEMORY_RANGE:
      {
        MemoryRange memoryRange = (MemoryRange)theEObject;
        T result = caseMemoryRange(memoryRange);
        if (result == null) result = caseIdentifiable(memoryRange);
        if (result == null) result = caseReferrable(memoryRange);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.MEMORY_SELF_TEST:
      {
        MemorySelfTest memorySelfTest = (MemorySelfTest)theEObject;
        T result = caseMemorySelfTest(memorySelfTest);
        if (result == null) result = caseSoftwareSafetyRequirement(memorySelfTest);
        if (result == null) result = caseAbstractQuantifiableSafetyRequirement(memorySelfTest);
        if (result == null) result = caseAbstractSafetyRequirement(memorySelfTest);
        if (result == null) result = caseTraceableSpecification(memorySelfTest);
        if (result == null) result = caseAllocatableElement(memorySelfTest);
        if (result == null) result = caseIdentifiable(memorySelfTest);
        if (result == null) result = caseReferrable(memorySelfTest);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.MEMORY_SELF_TEST_CONFIG:
      {
        MemorySelfTestConfig memorySelfTestConfig = (MemorySelfTestConfig)theEObject;
        T result = caseMemorySelfTestConfig(memorySelfTestConfig);
        if (result == null) result = caseIdentifiable(memorySelfTestConfig);
        if (result == null) result = caseReferrable(memorySelfTestConfig);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.MEMORY_SELF_TEST_FAILED:
      {
        MemorySelfTestFailed memorySelfTestFailed = (MemorySelfTestFailed)theEObject;
        T result = caseMemorySelfTestFailed(memorySelfTestFailed);
        if (result == null) result = caseSituation(memorySelfTestFailed);
        if (result == null) result = caseIdentifiable(memorySelfTestFailed);
        if (result == null) result = caseReferrable(memorySelfTestFailed);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.MEMORY_SELF_TESTING:
      {
        MemorySelfTesting memorySelfTesting = (MemorySelfTesting)theEObject;
        T result = caseMemorySelfTesting(memorySelfTesting);
        if (result == null) result = caseDetect(memorySelfTesting);
        if (result == null) result = caseTactic(memorySelfTesting);
        if (result == null) result = caseIdentifiable(memorySelfTesting);
        if (result == null) result = caseReferrable(memorySelfTesting);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CHROMOSOME_VOTER:
      {
        ChromosomeVoter chromosomeVoter = (ChromosomeVoter)theEObject;
        T result = caseChromosomeVoter(chromosomeVoter);
        if (result == null) result = caseVoter(chromosomeVoter);
        if (result == null) result = caseSoftwareSafetyRequirement(chromosomeVoter);
        if (result == null) result = caseAbstractQuantifiableSafetyRequirement(chromosomeVoter);
        if (result == null) result = caseAbstractSafetyRequirement(chromosomeVoter);
        if (result == null) result = caseTraceableSpecification(chromosomeVoter);
        if (result == null) result = caseAllocatableElement(chromosomeVoter);
        if (result == null) result = caseIdentifiable(chromosomeVoter);
        if (result == null) result = caseReferrable(chromosomeVoter);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CHROMOSOME_VOTER_PARAMETER:
      {
        ChromosomeVoterParameter chromosomeVoterParameter = (ChromosomeVoterParameter)theEObject;
        T result = caseChromosomeVoterParameter(chromosomeVoterParameter);
        if (result == null) result = caseVoterParameter(chromosomeVoterParameter);
        if (result == null) result = caseIdentifiable(chromosomeVoterParameter);
        if (result == null) result = caseReferrable(chromosomeVoterParameter);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.VOTER:
      {
        Voter voter = (Voter)theEObject;
        T result = caseVoter(voter);
        if (result == null) result = caseSoftwareSafetyRequirement(voter);
        if (result == null) result = caseAbstractQuantifiableSafetyRequirement(voter);
        if (result == null) result = caseAbstractSafetyRequirement(voter);
        if (result == null) result = caseTraceableSpecification(voter);
        if (result == null) result = caseAllocatableElement(voter);
        if (result == null) result = caseIdentifiable(voter);
        if (result == null) result = caseReferrable(voter);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.VOTER_CONFIG:
      {
        VoterConfig voterConfig = (VoterConfig)theEObject;
        T result = caseVoterConfig(voterConfig);
        if (result == null) result = caseIdentifiable(voterConfig);
        if (result == null) result = caseReferrable(voterConfig);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.VOTER_NO_CONSENSUS:
      {
        VoterNoConsensus voterNoConsensus = (VoterNoConsensus)theEObject;
        T result = caseVoterNoConsensus(voterNoConsensus);
        if (result == null) result = caseSituation(voterNoConsensus);
        if (result == null) result = caseIdentifiable(voterNoConsensus);
        if (result == null) result = caseReferrable(voterNoConsensus);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.VOTER_PARAMETER:
      {
        VoterParameter voterParameter = (VoterParameter)theEObject;
        T result = caseVoterParameter(voterParameter);
        if (result == null) result = caseIdentifiable(voterParameter);
        if (result == null) result = caseReferrable(voterParameter);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.VOTER_VALUE_MISMATCH:
      {
        VoterValueMismatch voterValueMismatch = (VoterValueMismatch)theEObject;
        T result = caseVoterValueMismatch(voterValueMismatch);
        if (result == null) result = caseSituation(voterValueMismatch);
        if (result == null) result = caseIdentifiable(voterValueMismatch);
        if (result == null) result = caseReferrable(voterValueMismatch);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.VOTING:
      {
        Voting voting = (Voting)theEObject;
        T result = caseVoting(voting);
        if (result == null) result = caseHandle(voting);
        if (result == null) result = caseTactic(voting);
        if (result == null) result = caseIdentifiable(voting);
        if (result == null) result = caseReferrable(voting);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.BOOLEAN_CONFIG_PARAMETER_VALUE:
      {
        BooleanConfigParameterValue booleanConfigParameterValue = (BooleanConfigParameterValue)theEObject;
        T result = caseBooleanConfigParameterValue(booleanConfigParameterValue);
        if (result == null) result = caseConfigParameterValue(booleanConfigParameterValue);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CODE_GENERATION_CONFIGURATION:
      {
        CodeGenerationConfiguration codeGenerationConfiguration = (CodeGenerationConfiguration)theEObject;
        T result = caseCodeGenerationConfiguration(codeGenerationConfiguration);
        if (result == null) result = caseIdentifiable(codeGenerationConfiguration);
        if (result == null) result = caseReferrable(codeGenerationConfiguration);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CONFIG_PARAMETER:
      {
        ConfigParameter configParameter = (ConfigParameter)theEObject;
        T result = caseConfigParameter(configParameter);
        if (result == null) result = caseIdentifiable(configParameter);
        if (result == null) result = caseReferrable(configParameter);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.CONFIG_PARAMETER_VALUE:
      {
        ConfigParameterValue configParameterValue = (ConfigParameterValue)theEObject;
        T result = caseConfigParameterValue(configParameterValue);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.FLOAT_CONFIG_PARAMETER_VALUE:
      {
        FloatConfigParameterValue floatConfigParameterValue = (FloatConfigParameterValue)theEObject;
        T result = caseFloatConfigParameterValue(floatConfigParameterValue);
        if (result == null) result = caseConfigParameterValue(floatConfigParameterValue);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.IDENTIFIER_CONFIG_PARAMETER_VALUE:
      {
        IdentifierConfigParameterValue identifierConfigParameterValue = (IdentifierConfigParameterValue)theEObject;
        T result = caseIdentifierConfigParameterValue(identifierConfigParameterValue);
        if (result == null) result = caseConfigParameterValue(identifierConfigParameterValue);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.INTEGER_CONFIG_PARAMETER_VALUE:
      {
        IntegerConfigParameterValue integerConfigParameterValue = (IntegerConfigParameterValue)theEObject;
        T result = caseIntegerConfigParameterValue(integerConfigParameterValue);
        if (result == null) result = caseConfigParameterValue(integerConfigParameterValue);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.STRING_CONFIG_PARAMETER_VALUE:
      {
        StringConfigParameterValue stringConfigParameterValue = (StringConfigParameterValue)theEObject;
        T result = caseStringConfigParameterValue(stringConfigParameterValue);
        if (result == null) result = caseConfigParameterValue(stringConfigParameterValue);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HARDWARE_SOFTWARE_INTERFACE_ELEMENT:
      {
        HardwareSoftwareInterfaceElement hardwareSoftwareInterfaceElement = (HardwareSoftwareInterfaceElement)theEObject;
        T result = caseHardwareSoftwareInterfaceElement(hardwareSoftwareInterfaceElement);
        if (result == null) result = caseIdentifiable(hardwareSoftwareInterfaceElement);
        if (result == null) result = caseReferrable(hardwareSoftwareInterfaceElement);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case Safe10Package.HARDWARE_SOFTWARE_INTERFACE_SPECIFICATION:
      {
        HardwareSoftwareInterfaceSpecification hardwareSoftwareInterfaceSpecification = (HardwareSoftwareInterfaceSpecification)theEObject;
        T result = caseHardwareSoftwareInterfaceSpecification(hardwareSoftwareInterfaceSpecification);
        if (result == null) result = caseIdentifiable(hardwareSoftwareInterfaceSpecification);
        if (result == null) result = caseReferrable(hardwareSoftwareInterfaceSpecification);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      default: return defaultCase(theEObject);
    }
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Filter Expression</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Filter Expression</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseFilterExpression(FilterExpression object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Formula Expression</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Formula Expression</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseFormulaExpression(FormulaExpression object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Abstract Reference</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Abstract Reference</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAbstractReference(AbstractReference object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Autosar Reference</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Autosar Reference</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAutosarReference(AutosarReference object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>CHROMOSOME Reference</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>CHROMOSOME Reference</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseCHROMOSOMEReference(CHROMOSOMEReference object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>East Adl Reference</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>East Adl Reference</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseEastAdlReference(EastAdlReference object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Application</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Application</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseApplication(Application object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Component</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Component</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseComponent(Component object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Component Mode Instance Ref</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Component Mode Instance Ref</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseComponentModeInstanceRef(ComponentModeInstanceRef object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Node</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Node</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseNode(Node object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>System</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>System</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseSystem(org.safe.metamodel.safe10.System object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Topic</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Topic</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseTopic(Topic object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Multi Level Safety Extension</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Multi Level Safety Extension</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseMultiLevelSafetyExtension(MultiLevelSafetyExtension object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Safety Extension</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Safety Extension</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseSafetyExtension(SafetyExtension object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Single Level Safety Extension</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Single Level Safety Extension</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseSingleLevelSafetyExtension(SingleLevelSafetyExtension object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Functional Safety Extension</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Functional Safety Extension</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseFunctionalSafetyExtension(FunctionalSafetyExtension object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Hazardand Risk Safety Extension</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Hazardand Risk Safety Extension</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHazardandRiskSafetyExtension(HazardandRiskSafetyExtension object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Autosar Hardware Safety Extension</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Autosar Hardware Safety Extension</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAutosarHardwareSafetyExtension(AutosarHardwareSafetyExtension object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Autosar Safety Extension</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Autosar Safety Extension</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAutosarSafetyExtension(AutosarSafetyExtension object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Autosar System Safety Extension</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Autosar System Safety Extension</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAutosarSystemSafetyExtension(AutosarSystemSafetyExtension object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Autosar Vfb Safety Extension</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Autosar Vfb Safety Extension</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAutosarVfbSafetyExtension(AutosarVfbSafetyExtension object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Chromosome Application Safety Extension</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Chromosome Application Safety Extension</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseChromosomeApplicationSafetyExtension(ChromosomeApplicationSafetyExtension object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Chromosome Safe Extension</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Chromosome Safe Extension</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseChromosomeSafeExtension(ChromosomeSafeExtension object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Chromosome System Safety Extension</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Chromosome System Safety Extension</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseChromosomeSystemSafetyExtension(ChromosomeSystemSafetyExtension object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Implementation Safety Extension</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Implementation Safety Extension</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseImplementationSafetyExtension(ImplementationSafetyExtension object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Design Level Safety Extension</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Design Level Safety Extension</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseDesignLevelSafetyExtension(DesignLevelSafetyExtension object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Hardware Safety Extension</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Hardware Safety Extension</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHardwareSafetyExtension(HardwareSafetyExtension object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Software Safety Extension</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Software Safety Extension</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseSoftwareSafetyExtension(SoftwareSafetyExtension object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Technical Safety Extension</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Technical Safety Extension</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseTechnicalSafetyExtension(TechnicalSafetyExtension object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Packageable Element</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Packageable Element</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T casePackageableElement(PackageableElement object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Referrable</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Referrable</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseReferrable(Referrable object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>SAFE</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>SAFE</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseSAFE(SAFE object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>SAFE Element</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>SAFE Element</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseSAFEElement(SAFEElement object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>SAFE Package</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>SAFE Package</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseSAFEPackage(SAFEPackage object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Identifiable</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Identifiable</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseIdentifiable(Identifiable object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Autosar Abstract Component Instance Ref</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Autosar Abstract Component Instance Ref</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAutosarAbstractComponentInstanceRef(AutosarAbstractComponentInstanceRef object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Autosar Abstract Port In Component Instance Ref</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Autosar Abstract Port In Component Instance Ref</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAutosarAbstractPortInComponentInstanceRef(AutosarAbstractPortInComponentInstanceRef object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Autosar Client Server Operation Instance Ref</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Autosar Client Server Operation Instance Ref</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAutosarClientServerOperationInstanceRef(AutosarClientServerOperationInstanceRef object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Autosar Component In Composition Instance Ref</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Autosar Component In Composition Instance Ref</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAutosarComponentInCompositionInstanceRef(AutosarComponentInCompositionInstanceRef object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Autosar Instance Ref</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Autosar Instance Ref</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAutosarInstanceRef(AutosarInstanceRef object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Autosar Mode In Port From Component In Composition Instance Ref</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Autosar Mode In Port From Component In Composition Instance Ref</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAutosarModeInPortFromComponentInCompositionInstanceRef(AutosarModeInPortFromComponentInCompositionInstanceRef object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Autosar Port In Composition Instance Ref</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Autosar Port In Composition Instance Ref</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAutosarPortInCompositionInstanceRef(AutosarPortInCompositionInstanceRef object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Autosar Undefined Instance Ref</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Autosar Undefined Instance Ref</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAutosarUndefinedInstanceRef(AutosarUndefinedInstanceRef object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Autosar Variable Data Prototype Instance Ref</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Autosar Variable Data Prototype Instance Ref</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAutosarVariableDataPrototypeInstanceRef(AutosarVariableDataPrototypeInstanceRef object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Restrictable</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Restrictable</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseRestrictable(Restrictable object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Restriction</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Restriction</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseRestriction(Restriction object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Variant</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Variant</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseVariant(Variant object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Error Model</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Error Model</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseErrorModel(ErrorModel object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Error Model Instance Ref</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Error Model Instance Ref</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseErrorModelInstanceRef(ErrorModelInstanceRef object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Error Model Prototype analysis Function Target</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Error Model Prototype analysis Function Target</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseErrorModelPrototype_analysisFunctionTarget(ErrorModelPrototype_analysisFunctionTarget object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Error Model Prototype design Function Target</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Error Model Prototype design Function Target</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseErrorModelPrototype_designFunctionTarget(ErrorModelPrototype_designFunctionTarget object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Error Model Prototype hw Target</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Error Model Prototype hw Target</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseErrorModelPrototype_hwTarget(ErrorModelPrototype_hwTarget object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Fault Failure Port function Target</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Fault Failure Port function Target</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseFaultFailurePort_functionTarget(FaultFailurePort_functionTarget object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Fault Failure Port hw Pin Target</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Fault Failure Port hw Pin Target</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseFaultFailurePort_hwPinTarget(FaultFailurePort_hwPinTarget object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Fault Failure Port hw Port Target</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Fault Failure Port hw Port Target</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseFaultFailurePort_hwPortTarget(FaultFailurePort_hwPortTarget object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Malfunction Instance Ref</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Malfunction Instance Ref</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseMalfunctionInstanceRef(MalfunctionInstanceRef object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Abstract Error Behavior</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Abstract Error Behavior</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAbstractErrorBehavior(AbstractErrorBehavior object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>East ADL Error Behavior</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>East ADL Error Behavior</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseEastADLErrorBehavior(EastADLErrorBehavior object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Failure Logic Formula</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Failure Logic Formula</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseFailureLogicFormula(FailureLogicFormula object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Native Error Behavior</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Native Error Behavior</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseNativeErrorBehavior(NativeErrorBehavior object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>EMP Analysis</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>EMP Analysis</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseEMPAnalysis(EMPAnalysis object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>EMP Bsw Module</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>EMP Bsw Module</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseEMPBswModule(EMPBswModule object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>EMP Design</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>EMP Design</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseEMPDesign(EMPDesign object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>EMP Hw Component</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>EMP Hw Component</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseEMPHwComponent(EMPHwComponent object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>EMP Reference</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>EMP Reference</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseEMPReference(EMPReference object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>EMP Sw Component</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>EMP Sw Component</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseEMPSwComponent(EMPSwComponent object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>EM Type Analysis</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>EM Type Analysis</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseEMTypeAnalysis(EMTypeAnalysis object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>EM Type Application Environment</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>EM Type Application Environment</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseEMTypeApplicationEnvironment(EMTypeApplicationEnvironment object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>EM Type Bsw Module</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>EM Type Bsw Module</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseEMTypeBswModule(EMTypeBswModule object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>EM Type Design</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>EM Type Design</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseEMTypeDesign(EMTypeDesign object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>EM Type Hw Component</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>EM Type Hw Component</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseEMTypeHwComponent(EMTypeHwComponent object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>EM Type Sw Component</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>EM Type Sw Component</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseEMTypeSwComponent(EMTypeSwComponent object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Error Model Prototype</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Error Model Prototype</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseErrorModelPrototype(ErrorModelPrototype object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Error Model Type</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Error Model Type</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseErrorModelType(ErrorModelType object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Fault Failure Propagation Link</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Fault Failure Propagation Link</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseFaultFailurePropagationLink(FaultFailurePropagationLink object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Failure Rate</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Failure Rate</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseFailureRate(FailureRate object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Quantitative Error Model</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Quantitative Error Model</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseQuantitativeErrorModel(QuantitativeErrorModel object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Malfunction Prototype</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Malfunction Prototype</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseMalfunctionPrototype(MalfunctionPrototype object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Malfunction Type</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Malfunction Type</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseMalfunctionType(MalfunctionType object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>MFP Bsw Port</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>MFP Bsw Port</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseMFPBswPort(MFPBswPort object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>MFP Function Port</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>MFP Function Port</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseMFPFunctionPort(MFPFunctionPort object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>MFP Hardware Pin</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>MFP Hardware Pin</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseMFPHardwarePin(MFPHardwarePin object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>MFP Hardware Port</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>MFP Hardware Port</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseMFPHardwarePort(MFPHardwarePort object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>MFP Operation</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>MFP Operation</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseMFPOperation(MFPOperation object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>MFP Swc Port</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>MFP Swc Port</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseMFPSwcPort(MFPSwcPort object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>MFP Variable</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>MFP Variable</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseMFPVariable(MFPVariable object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>MT Composite</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>MT Composite</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseMTComposite(MTComposite object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>MT Composite Element Prototype</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>MT Composite Element Prototype</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseMTCompositeElementPrototype(MTCompositeElementPrototype object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>MT Primitive</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>MT Primitive</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseMTPrimitive(MTPrimitive object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Error Behavior Mapping</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Error Behavior Mapping</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseErrorBehaviorMapping(ErrorBehaviorMapping object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Error Model Mapping</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Error Model Mapping</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseErrorModelMapping(ErrorModelMapping object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Malfunction Mapping</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Malfunction Mapping</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseMalfunctionMapping(MalfunctionMapping object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Formula Documentation</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Formula Documentation</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseFormulaDocumentation(FormulaDocumentation object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>HW Failure Class Contribution Formula</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>HW Failure Class Contribution Formula</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHWFailureClassContributionFormula(HWFailureClassContributionFormula object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>HWFM Single Contribution Formula</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>HWFM Single Contribution Formula</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHWFMSingleContributionFormula(HWFMSingleContributionFormula object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>HW Lambda Part Formula</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>HW Lambda Part Formula</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHWLambdaPartFormula(HWLambdaPartFormula object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>HW Latent Fault Metric Formula</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>HW Latent Fault Metric Formula</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHWLatentFaultMetricFormula(HWLatentFaultMetricFormula object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>HWPMHF Formula</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>HWPMHF Formula</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHWPMHFFormula(HWPMHFFormula object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>HW Single Point Fault Metric Formula</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>HW Single Point Fault Metric Formula</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHWSinglePointFaultMetricFormula(HWSinglePointFaultMetricFormula object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Hardware Failure Analysis</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Hardware Failure Analysis</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHardwareFailureAnalysis(HardwareFailureAnalysis object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Hardware Component Failure</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Hardware Component Failure</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHardwareComponentFailure(HardwareComponentFailure object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>HW Failure Rate</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>HW Failure Rate</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHWFailureRate(HWFailureRate object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>HW Failure Mode</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>HW Failure Mode</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHWFailureMode(HWFailureMode object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>HW Fault</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>HW Fault</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHWFault(HWFault object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>HW Component Prototype Scope</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>HW Component Prototype Scope</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHWComponentPrototypeScope(HWComponentPrototypeScope object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Hw Component Scope Instance Ref</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Hw Component Scope Instance Ref</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHwComponentScopeInstanceRef(HwComponentScopeInstanceRef object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>HW Component Quantified FM From Part</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>HW Component Quantified FM From Part</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHWComponentQuantifiedFMFromPart(HWComponentQuantifiedFMFromPart object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>HW Element Prototype Scope</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>HW Element Prototype Scope</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHWElementPrototypeScope(HWElementPrototypeScope object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>HW Part Failure</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>HW Part Failure</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHWPartFailure(HWPartFailure object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>HW Part Failure Analysis</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>HW Part Failure Analysis</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHWPartFailureAnalysis(HWPartFailureAnalysis object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>HW Part Failure Mode</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>HW Part Failure Mode</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHWPartFailureMode(HWPartFailureMode object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>HW Part Failure Rate</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>HW Part Failure Rate</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHWPartFailureRate(HWPartFailureRate object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>HW Element Scope Instance Ref</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>HW Element Scope Instance Ref</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHWElementScopeInstanceRef(HWElementScopeInstanceRef object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>HW Architectural Metrics</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>HW Architectural Metrics</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHWArchitecturalMetrics(HWArchitecturalMetrics object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>HWFM Single Contribution</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>HWFM Single Contribution</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHWFMSingleContribution(HWFMSingleContribution object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>HW Probabilistic Value</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>HW Probabilistic Value</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHWProbabilisticValue(HWProbabilisticValue object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>HW Quantitative Failure Analysis</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>HW Quantitative Failure Analysis</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHWQuantitativeFailureAnalysis(HWQuantitativeFailureAnalysis object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>HW Latent Fault Metric</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>HW Latent Fault Metric</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHWLatentFaultMetric(HWLatentFaultMetric object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>HW Single Point Fault Metric</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>HW Single Point Fault Metric</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHWSinglePointFaultMetric(HWSinglePointFaultMetric object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>HW Element Failure Rate Class</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>HW Element Failure Rate Class</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHWElementFailureRateClass(HWElementFailureRateClass object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>HW Failure Class Container</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>HW Failure Class Container</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHWFailureClassContainer(HWFailureClassContainer object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>HWPMHF</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>HWPMHF</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHWPMHF(HWPMHF object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Actor</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Actor</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseActor(Actor object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Controllability Reference</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Controllability Reference</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseControllabilityReference(ControllabilityReference object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Hazard</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Hazard</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHazard(Hazard object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Hazardous Event</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Hazardous Event</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHazardousEvent(HazardousEvent object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Item</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Item</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseItem(Item object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Item Function Description</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Item Function Description</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseItemFunctionDescription(ItemFunctionDescription object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Operating Mode</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Operating Mode</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseOperatingMode(OperatingMode object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Operational Situation</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Operational Situation</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseOperationalSituation(OperationalSituation object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Risk Description</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Risk Description</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseRiskDescription(RiskDescription object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Safe State</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Safe State</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseSafeState(SafeState object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Abstract Quantifiable Safety Requirement</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Abstract Quantifiable Safety Requirement</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAbstractQuantifiableSafetyRequirement(AbstractQuantifiableSafetyRequirement object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Abstract Safety Requirement</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Abstract Safety Requirement</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAbstractSafetyRequirement(AbstractSafetyRequirement object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Allocatable Element</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Allocatable Element</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAllocatableElement(AllocatableElement object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Allocation Targets</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Allocation Targets</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAllocationTargets(AllocationTargets object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Functional Safety Requirement</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Functional Safety Requirement</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseFunctionalSafetyRequirement(FunctionalSafetyRequirement object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Hardware Safety Requirement</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Hardware Safety Requirement</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHardwareSafetyRequirement(HardwareSafetyRequirement object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Quantified Diagnostic Coverage Property</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Quantified Diagnostic Coverage Property</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseQuantifiedDiagnosticCoverageProperty(QuantifiedDiagnosticCoverageProperty object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Quantified HW Property</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Quantified HW Property</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseQuantifiedHWProperty(QuantifiedHWProperty object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Requirements Link</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Requirements Link</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseRequirementsLink(RequirementsLink object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Requirements Releationship</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Requirements Releationship</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseRequirementsReleationship(RequirementsReleationship object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Safety Concept</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Safety Concept</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseSafetyConcept(SafetyConcept object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Satisfy</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Satisfy</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseSatisfy(Satisfy object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Software Safety Requirement</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Software Safety Requirement</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseSoftwareSafetyRequirement(SoftwareSafetyRequirement object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Technical Safety Requirement</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Technical Safety Requirement</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseTechnicalSafetyRequirement(TechnicalSafetyRequirement object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Traceable Specification</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Traceable Specification</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseTraceableSpecification(TraceableSpecification object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Verify</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Verify</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseVerify(Verify object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Warning And Degradation</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Warning And Degradation</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseWarningAndDegradation(WarningAndDegradation object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Warning And Degradation Handle</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Warning And Degradation Handle</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseWarningAndDegradationHandle(WarningAndDegradationHandle object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Assumption</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Assumption</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAssumption(Assumption object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Context</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Context</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseContext(Context object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Goal</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Goal</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseGoal(Goal object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Justification</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Justification</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseJustification(Justification object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Safety Case</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Safety Case</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseSafetyCase(SafetyCase object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Solution</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Solution</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseSolution(Solution object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Strategy</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Strategy</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseStrategy(Strategy object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Analysis Report</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Analysis Report</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAnalysisReport(AnalysisReport object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Design Specification</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Design Specification</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseDesignSpecification(DesignSpecification object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Field Test Protocol</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Field Test Protocol</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseFieldTestProtocol(FieldTestProtocol object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>FMEA Report</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>FMEA Report</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseFMEAReport(FMEAReport object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Test Protocol</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Test Protocol</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseTestProtocol(TestProtocol object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Unit Test Protocol</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Unit Test Protocol</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseUnitTestProtocol(UnitTestProtocol object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Avoid</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Avoid</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAvoid(Avoid object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Detect</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Detect</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseDetect(Detect object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Handle</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Handle</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHandle(Handle object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Situation</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Situation</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseSituation(Situation object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Tactic</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Tactic</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseTactic(Tactic object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>AUTOSAR Runnable Entity Sequence Constraint</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>AUTOSAR Runnable Entity Sequence Constraint</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAUTOSARRunnableEntitySequenceConstraint(AUTOSARRunnableEntitySequenceConstraint object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>AUTOSAR Sequence Constraint</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>AUTOSAR Sequence Constraint</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAUTOSARSequenceConstraint(AUTOSARSequenceConstraint object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Control Block</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Control Block</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseControlBlock(ControlBlock object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Control Flow Error</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Control Flow Error</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseControlFlowError(ControlFlowError object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Control Flow Error Detection</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Control Flow Error Detection</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseControlFlowErrorDetection(ControlFlowErrorDetection object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Control Flow Monitor</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Control Flow Monitor</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseControlFlowMonitor(ControlFlowMonitor object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Input Block</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Input Block</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseInputBlock(InputBlock object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Operation Block</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Operation Block</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseOperationBlock(OperationBlock object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Output Block</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Output Block</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseOutputBlock(OutputBlock object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Runnable Entity Sequence Element</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Runnable Entity Sequence Element</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseRunnableEntitySequenceElement(RunnableEntitySequenceElement object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Sequence Block</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Sequence Block</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseSequenceBlock(SequenceBlock object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Aliveness Checkpoint Too Early</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Aliveness Checkpoint Too Early</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAlivenessCheckpointTooEarly(AlivenessCheckpointTooEarly object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Aliveness Checkpoint Too Late</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Aliveness Checkpoint Too Late</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAlivenessCheckpointTooLate(AlivenessCheckpointTooLate object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Aliveness Checkpoint Too Often</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Aliveness Checkpoint Too Often</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAlivenessCheckpointTooOften(AlivenessCheckpointTooOften object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Aliveness Monitor</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Aliveness Monitor</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAlivenessMonitor(AlivenessMonitor object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Autosar Aliveness Monitor</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Autosar Aliveness Monitor</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAutosarAlivenessMonitor(AutosarAlivenessMonitor object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Autosar Check Point</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Autosar Check Point</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAutosarCheckPoint(AutosarCheckPoint object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Check Point</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Check Point</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseCheckPoint(CheckPoint object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Software Aliveness Detection</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Software Aliveness Detection</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseSoftwareAlivenessDetection(SoftwareAlivenessDetection object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Actuator Error</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Actuator Error</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseActuatorError(ActuatorError object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Actuator Error Detection</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Actuator Error Detection</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseActuatorErrorDetection(ActuatorErrorDetection object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Actuator Monitor</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Actuator Monitor</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseActuatorMonitor(ActuatorMonitor object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Autosar Actuator Monitor</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Autosar Actuator Monitor</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAutosarActuatorMonitor(AutosarActuatorMonitor object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Autosar Evaluation Function</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Autosar Evaluation Function</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAutosarEvaluationFunction(AutosarEvaluationFunction object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Evaluation Function</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Evaluation Function</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseEvaluationFunction(EvaluationFunction object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Autosar CRC</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Autosar CRC</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAutosarCRC(AutosarCRC object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Component Prototype CRC</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Component Prototype CRC</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseComponentPrototypeCRC(ComponentPrototypeCRC object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>CRC</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>CRC</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseCRC(CRC object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>CRC Config</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>CRC Config</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseCRCConfig(CRCConfig object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>CRC Error Detection</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>CRC Error Detection</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseCRCErrorDetection(CRCErrorDetection object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>CRC Failed</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>CRC Failed</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseCRCFailed(CRCFailed object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Interface CRC</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Interface CRC</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseInterfaceCRC(InterfaceCRC object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Autosar Comparison</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Autosar Comparison</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAutosarComparison(AutosarComparison object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Autosar Comparison Param</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Autosar Comparison Param</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAutosarComparisonParam(AutosarComparisonParam object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Chromosome Comparison</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Chromosome Comparison</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseChromosomeComparison(ChromosomeComparison object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Chromosome Comparison Parameter</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Chromosome Comparison Parameter</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseChromosomeComparisonParameter(ChromosomeComparisonParameter object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Comparison</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Comparison</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseComparison(Comparison object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Comparison Detection</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Comparison Detection</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseComparisonDetection(ComparisonDetection object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Comparison False</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Comparison False</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseComparisonFalse(ComparisonFalse object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Comparison Parameter</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Comparison Parameter</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseComparisonParameter(ComparisonParameter object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Comparison True</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Comparison True</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseComparisonTrue(ComparisonTrue object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Constant Comparison Parameter</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Constant Comparison Parameter</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseConstantComparisonParameter(ConstantComparisonParameter object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Autosar Context</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Autosar Context</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAutosarContext(AutosarContext object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Autosar Context Range Check</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Autosar Context Range Check</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAutosarContextRangeCheck(AutosarContextRangeCheck object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Context Parameter</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Context Parameter</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseContextParameter(ContextParameter object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Context Range Check</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Context Range Check</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseContextRangeCheck(ContextRangeCheck object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Context Range Check Detection</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Context Range Check Detection</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseContextRangeCheckDetection(ContextRangeCheckDetection object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Range Check Context</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Range Check Context</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseRangeCheckContext(RangeCheckContext object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Value Above Range</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Value Above Range</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseValueAboveRange(ValueAboveRange object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Value Below Range</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Value Below Range</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseValueBelowRange(ValueBelowRange object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Chromosome Cpu Self Test</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Chromosome Cpu Self Test</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseChromosomeCpuSelfTest(ChromosomeCpuSelfTest object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Cpu Self Test</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Cpu Self Test</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseCpuSelfTest(CpuSelfTest object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Cpu Self Test Config</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Cpu Self Test Config</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseCpuSelfTestConfig(CpuSelfTestConfig object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Cpu Self Test Detection</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Cpu Self Test Detection</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseCpuSelfTestDetection(CpuSelfTestDetection object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Cpu Self Test Failed</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Cpu Self Test Failed</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseCpuSelfTestFailed(CpuSelfTestFailed object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Filter</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Filter</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseFilter(Filter object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Filter Based Handling</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Filter Based Handling</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseFilterBasedHandling(FilterBasedHandling object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Filter Error</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Filter Error</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseFilterError(FilterError object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Filter Parameter</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Filter Parameter</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseFilterParameter(FilterParameter object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Autosar Gradient Check</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Autosar Gradient Check</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAutosarGradientCheck(AutosarGradientCheck object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Gradient Check</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Gradient Check</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseGradientCheck(GradientCheck object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Gradient Check Detection</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Gradient Check Detection</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseGradientCheckDetection(GradientCheckDetection object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Gradient Too High</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Gradient Too High</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseGradientTooHigh(GradientTooHigh object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Gradient Too Low</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Gradient Too Low</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseGradientTooLow(GradientTooLow object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Chromosome Application Health Monitor</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Chromosome Application Health Monitor</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseChromosomeApplicationHealthMonitor(ChromosomeApplicationHealthMonitor object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Chromosome Component Mode Condition</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Chromosome Component Mode Condition</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseChromosomeComponentModeCondition(ChromosomeComponentModeCondition object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Chromosome Error Event Condition</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Chromosome Error Event Condition</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseChromosomeErrorEventCondition(ChromosomeErrorEventCondition object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Chromosome Error Handler</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Chromosome Error Handler</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseChromosomeErrorHandler(ChromosomeErrorHandler object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Chromosome Health Monitor</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Chromosome Health Monitor</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseChromosomeHealthMonitor(ChromosomeHealthMonitor object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>CHROMOSOME Health Monitor Notification</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>CHROMOSOME Health Monitor Notification</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseCHROMOSOMEHealthMonitorNotification(CHROMOSOMEHealthMonitorNotification object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Chromosome Node Health Monitor</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Chromosome Node Health Monitor</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseChromosomeNodeHealthMonitor(ChromosomeNodeHealthMonitor object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Health Monitor</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Health Monitor</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHealthMonitor(HealthMonitor object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Health Monitor Error Condition</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Health Monitor Error Condition</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHealthMonitorErrorCondition(HealthMonitorErrorCondition object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Health Monitoring</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Health Monitoring</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHealthMonitoring(HealthMonitoring object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Chromosome Heartbeat Receiver</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Chromosome Heartbeat Receiver</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseChromosomeHeartbeatReceiver(ChromosomeHeartbeatReceiver object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Chromosome Heartbeat Sender</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Chromosome Heartbeat Sender</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseChromosomeHeartbeatSender(ChromosomeHeartbeatSender object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Heartbeat</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Heartbeat</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHeartbeat(Heartbeat object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Heartbeat Config</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Heartbeat Config</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHeartbeatConfig(HeartbeatConfig object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Heart Beat Deadline Missed</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Heart Beat Deadline Missed</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHeartBeatDeadlineMissed(HeartBeatDeadlineMissed object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Heart Beat Detection</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Heart Beat Detection</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHeartBeatDetection(HeartBeatDetection object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Heartbeat Receiver</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Heartbeat Receiver</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHeartbeatReceiver(HeartbeatReceiver object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Heartbeat Sender</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Heartbeat Sender</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHeartbeatSender(HeartbeatSender object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Chromosome Memory Test</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Chromosome Memory Test</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseChromosomeMemoryTest(ChromosomeMemoryTest object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Memory Range</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Memory Range</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseMemoryRange(MemoryRange object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Memory Self Test</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Memory Self Test</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseMemorySelfTest(MemorySelfTest object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Memory Self Test Config</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Memory Self Test Config</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseMemorySelfTestConfig(MemorySelfTestConfig object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Memory Self Test Failed</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Memory Self Test Failed</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseMemorySelfTestFailed(MemorySelfTestFailed object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Memory Self Testing</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Memory Self Testing</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseMemorySelfTesting(MemorySelfTesting object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Chromosome Voter</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Chromosome Voter</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseChromosomeVoter(ChromosomeVoter object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Chromosome Voter Parameter</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Chromosome Voter Parameter</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseChromosomeVoterParameter(ChromosomeVoterParameter object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Voter</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Voter</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseVoter(Voter object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Voter Config</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Voter Config</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseVoterConfig(VoterConfig object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Voter No Consensus</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Voter No Consensus</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseVoterNoConsensus(VoterNoConsensus object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Voter Parameter</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Voter Parameter</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseVoterParameter(VoterParameter object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Voter Value Mismatch</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Voter Value Mismatch</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseVoterValueMismatch(VoterValueMismatch object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Voting</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Voting</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseVoting(Voting object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Boolean Config Parameter Value</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Boolean Config Parameter Value</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseBooleanConfigParameterValue(BooleanConfigParameterValue object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Code Generation Configuration</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Code Generation Configuration</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseCodeGenerationConfiguration(CodeGenerationConfiguration object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Config Parameter</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Config Parameter</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseConfigParameter(ConfigParameter object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Config Parameter Value</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Config Parameter Value</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseConfigParameterValue(ConfigParameterValue object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Float Config Parameter Value</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Float Config Parameter Value</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseFloatConfigParameterValue(FloatConfigParameterValue object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Identifier Config Parameter Value</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Identifier Config Parameter Value</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseIdentifierConfigParameterValue(IdentifierConfigParameterValue object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Integer Config Parameter Value</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Integer Config Parameter Value</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseIntegerConfigParameterValue(IntegerConfigParameterValue object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>String Config Parameter Value</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>String Config Parameter Value</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseStringConfigParameterValue(StringConfigParameterValue object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Hardware Software Interface Element</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Hardware Software Interface Element</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHardwareSoftwareInterfaceElement(HardwareSoftwareInterfaceElement object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Hardware Software Interface Specification</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Hardware Software Interface Specification</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseHardwareSoftwareInterfaceSpecification(HardwareSoftwareInterfaceSpecification object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>EObject</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch, but this is the last case anyway.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>EObject</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject)
   * @generated
   */
  public T defaultCase(EObject object)
  {
    return null;
  }

} //Safe10Switch
